@@ -23,7 +23,9 @@ along with this program. If not, see <https://www.gnu.org/licenses/>.
 """
 from __future__ import annotations
 
-from PyQt5.QtCore import QT_TRANSLATE_NOOP, QCoreApplication
+from typing import Final
+
+from PyQt6.QtCore import QT_TRANSLATE_NOOP, QCoreApplication
 
 from novelwriter.enum import (
     nwBuildFmt, nwComment, nwItemClass, nwItemLayout, nwOutline, nwStatusShape
@@ -99,7 +101,7 @@ class nwShortcode:
     FOOTNOTE_B = "[footnote:"
     FIELD_B    = "[field:"
 
-    COMMENT_STYLES = {
+    COMMENT_STYLES: Final[dict[nwComment, str]] = {
         nwComment.FOOTNOTE: "[footnote:{0}]",
         nwComment.COMMENT:  "[comment:{0}]",
     }
@@ -110,13 +112,13 @@ class nwShortcode:
 class nwStyles:
 
     H_VALID = ("H0", "H1", "H2", "H3", "H4")
-    H_LEVEL = {"H0": 0, "H1": 1, "H2": 2, "H3": 3, "H4": 4}
-    H_SIZES = {0: 2.50, 1: 2.00, 2: 1.75, 3: 1.50, 4: 1.25}
+    H_LEVEL: Final[dict[str, int]] = {"H0": 0, "H1": 1, "H2": 2, "H3": 3, "H4": 4}
+    H_SIZES: Final[dict[int, float]] = {0: 2.50, 1: 2.00, 2: 1.75, 3: 1.50, 4: 1.25}
 
     T_NORMAL = 1.0
     T_SMALL  = 0.8
 
-    T_LABEL = {
+    T_LABEL: Final[dict[str, str]] = {
         "H0": QT_TRANSLATE_NOOP("Constant", "Title"),
         "H1": QT_TRANSLATE_NOOP("Constant", "Heading 1 (Partition)"),
         "H2": QT_TRANSLATE_NOOP("Constant", "Heading 2 (Chapter)"),
@@ -125,7 +127,7 @@ class nwStyles:
         "TT": QT_TRANSLATE_NOOP("Constant", "Text Paragraph"),
         "SP": QT_TRANSLATE_NOOP("Constant", "Scene Separator"),
     }
-    T_MARGIN = {
+    T_MARGIN: Final[dict[str, tuple[float, float]]] = {
         "H0": (1.50, 0.60),  # Title margins (top, bottom)
         "H1": (1.50, 0.60),  # Heading 1 margins (top, bottom)
         "H2": (1.50, 0.60),  # Heading 2 margins (top, bottom)
@@ -174,20 +176,24 @@ class nwKeyWords:
     MENTION_KEY = "@mention"
 
     # Note: The order here affects the order of menu entries
-    ALL_KEYS = [
+    ALL_KEYS: Final[list[str]] = [
         TAG_KEY, POV_KEY, FOCUS_KEY, CHAR_KEY, PLOT_KEY, TIME_KEY, WORLD_KEY,
         OBJECT_KEY, ENTITY_KEY, CUSTOM_KEY, STORY_KEY, MENTION_KEY,
     ]
-    CAN_CREATE = [
+    CAN_CREATE: Final[list[str]] = [
         POV_KEY, FOCUS_KEY, CHAR_KEY, PLOT_KEY, TIME_KEY, WORLD_KEY,
         OBJECT_KEY, ENTITY_KEY, CUSTOM_KEY,
     ]
+    CAN_LOOKUP: Final[list[str]] = [
+        POV_KEY, FOCUS_KEY, CHAR_KEY, PLOT_KEY, TIME_KEY, WORLD_KEY,
+        OBJECT_KEY, ENTITY_KEY, CUSTOM_KEY, STORY_KEY, MENTION_KEY,
+    ]
 
     # Set of Valid Keys
-    VALID_KEYS = set(ALL_KEYS)
+    VALID_KEYS: Final[set[str]] = set(ALL_KEYS)
 
     # Map from Keys to Item Class
-    KEY_CLASS = {
+    KEY_CLASS: Final[dict[str, nwItemClass]] = {
         POV_KEY:     nwItemClass.CHARACTER,
         FOCUS_KEY:   nwItemClass.CHARACTER,
         CHAR_KEY:    nwItemClass.CHARACTER,
@@ -203,7 +209,7 @@ class nwKeyWords:
 
 class nwLists:
 
-    USER_CLASSES = [
+    USER_CLASSES: Final[list[nwItemClass]] = [
         nwItemClass.CHARACTER,
         nwItemClass.PLOT,
         nwItemClass.WORLD,
@@ -229,7 +235,7 @@ class nwStats:
     WORDS_TITLE  = "titleWords"
 
     # Note: The order here affects the order of menu entries
-    ALL_FIELDS = [
+    ALL_FIELDS: Final[list[str]] = [
         WORDS, WORDS_TEXT, WORDS_TITLE,
         CHARS, CHARS_TEXT, CHARS_TITLE,
         WCHARS_ALL, WCHARS_TEXT, WCHARS_TITLE,
@@ -239,7 +245,7 @@ class nwStats:
 
 class nwLabels:
 
-    CLASS_NAME = {
+    CLASS_NAME: Final[dict[nwItemClass, str]] = {
         nwItemClass.NO_CLASS:  QT_TRANSLATE_NOOP("Constant", "None"),
         nwItemClass.NOVEL:     QT_TRANSLATE_NOOP("Constant", "Novel"),
         nwItemClass.PLOT:      QT_TRANSLATE_NOOP("Constant", "Plot"),
@@ -253,7 +259,7 @@ class nwLabels:
         nwItemClass.TEMPLATE:  QT_TRANSLATE_NOOP("Constant", "Templates"),
         nwItemClass.TRASH:     QT_TRANSLATE_NOOP("Constant", "Trash"),
     }
-    CLASS_ICON = {
+    CLASS_ICON: Final[dict[nwItemClass, str]] = {
         nwItemClass.NO_CLASS:  "cls_none",
         nwItemClass.NOVEL:     "cls_novel",
         nwItemClass.PLOT:      "cls_plot",
@@ -267,12 +273,12 @@ class nwLabels:
         nwItemClass.TEMPLATE:  "cls_template",
         nwItemClass.TRASH:     "cls_trash",
     }
-    LAYOUT_NAME = {
+    LAYOUT_NAME: Final[dict[nwItemLayout, str]] = {
         nwItemLayout.NO_LAYOUT: QT_TRANSLATE_NOOP("Constant", "None"),
         nwItemLayout.DOCUMENT:  QT_TRANSLATE_NOOP("Constant", "Novel Document"),
         nwItemLayout.NOTE:      QT_TRANSLATE_NOOP("Constant", "Project Note"),
     }
-    ITEM_DESCRIPTION = {
+    ITEM_DESCRIPTION: Final[dict[str, str]] = {
         "none":     QT_TRANSLATE_NOOP("Constant", "None"),
         "root":     QT_TRANSLATE_NOOP("Constant", "Root Folder"),
         "folder":   QT_TRANSLATE_NOOP("Constant", "Folder"),
@@ -283,11 +289,11 @@ class nwLabels:
         "doc_h4":   QT_TRANSLATE_NOOP("Constant", "Novel Section"),
         "note":     QT_TRANSLATE_NOOP("Constant", "Project Note"),
     }
-    ACTIVE_NAME = {
+    ACTIVE_NAME: Final[dict[str, str]] = {
         "checked":   QT_TRANSLATE_NOOP("Constant", "Active"),
         "unchecked": QT_TRANSLATE_NOOP("Constant", "Inactive"),
     }
-    KEY_NAME = {
+    KEY_NAME: Final[dict[str, str]] = {
         nwKeyWords.TAG_KEY:     QT_TRANSLATE_NOOP("Constant", "Tag"),
         nwKeyWords.POV_KEY:     QT_TRANSLATE_NOOP("Constant", "Point of View"),
         nwKeyWords.FOCUS_KEY:   QT_TRANSLATE_NOOP("Constant", "Focus"),
@@ -301,7 +307,7 @@ class nwLabels:
         nwKeyWords.STORY_KEY:   QT_TRANSLATE_NOOP("Constant", "Story"),
         nwKeyWords.MENTION_KEY: QT_TRANSLATE_NOOP("Constant", "Mentions"),
     }
-    KEY_SHORTCUT = {
+    KEY_SHORTCUT: Final[dict[str, str]] = {
         nwKeyWords.TAG_KEY:     "Ctrl+K, G",
         nwKeyWords.POV_KEY:     "Ctrl+K, V",
         nwKeyWords.FOCUS_KEY:   "Ctrl+K, F",
@@ -315,7 +321,7 @@ class nwLabels:
         nwKeyWords.STORY_KEY:   "Ctrl+K, N",
         nwKeyWords.MENTION_KEY: "Ctrl+K, M",
     }
-    OUTLINE_COLS = {
+    OUTLINE_COLS: Final[dict[nwOutline, str]] = {
         nwOutline.TITLE:   QT_TRANSLATE_NOOP("Constant", "Title"),
         nwOutline.LEVEL:   QT_TRANSLATE_NOOP("Constant", "Level"),
         nwOutline.LABEL:   QT_TRANSLATE_NOOP("Constant", "Document"),
@@ -337,7 +343,7 @@ class nwLabels:
         nwOutline.MENTION: KEY_NAME[nwKeyWords.MENTION_KEY],
         nwOutline.SYNOP:   QT_TRANSLATE_NOOP("Constant", "Synopsis"),
     }
-    STATS_NAME = {
+    STATS_NAME: Final[dict[str, str]] = {
         nwStats.CHARS:        QT_TRANSLATE_NOOP("Stats", "Characters"),
         nwStats.CHARS_TEXT:   QT_TRANSLATE_NOOP("Stats", "Characters in Text"),
         nwStats.CHARS_TITLE:  QT_TRANSLATE_NOOP("Stats", "Characters in Headings"),
@@ -350,7 +356,11 @@ class nwLabels:
         nwStats.WORDS_TEXT:   QT_TRANSLATE_NOOP("Stats", "Words in Text"),
         nwStats.WORDS_TITLE:  QT_TRANSLATE_NOOP("Stats", "Words in Headings"),
     }
-    BUILD_FMT = {
+    STATS_DISPLAY: Final[dict[str, str]] = {
+        nwStats.CHARS: QT_TRANSLATE_NOOP("Stats", "Characters: {0} ({1})"),
+        nwStats.WORDS: QT_TRANSLATE_NOOP("Stats", "Words: {0} ({1})"),
+    }
+    BUILD_FMT: Final[dict[nwBuildFmt, str]] = {
         nwBuildFmt.ODT:    QT_TRANSLATE_NOOP("Constant", "Open Document (.odt)"),
         nwBuildFmt.FODT:   QT_TRANSLATE_NOOP("Constant", "Flat Open Document (.fodt)"),
         nwBuildFmt.DOCX:   QT_TRANSLATE_NOOP("Constant", "Microsoft Word Document (.docx)"),
@@ -362,7 +372,7 @@ class nwLabels:
         nwBuildFmt.J_HTML: QT_TRANSLATE_NOOP("Constant", "JSON + HTML 5 (.json)"),
         nwBuildFmt.J_NWD:  QT_TRANSLATE_NOOP("Constant", "JSON + novelWriter Markup (.json)"),
     }
-    BUILD_EXT = {
+    BUILD_EXT: Final[dict[nwBuildFmt, str]] = {
         nwBuildFmt.ODT:    ".odt",
         nwBuildFmt.FODT:   ".fodt",
         nwBuildFmt.DOCX:   ".docx",
@@ -374,7 +384,7 @@ class nwLabels:
         nwBuildFmt.J_HTML: ".json",
         nwBuildFmt.J_NWD:  ".json",
     }
-    SHAPES_PLAIN = {
+    SHAPES_PLAIN: Final[dict[nwStatusShape, str]] = {
         nwStatusShape.SQUARE:   QT_TRANSLATE_NOOP("Constant", "Square"),
         nwStatusShape.TRIANGLE: QT_TRANSLATE_NOOP("Constant", "Triangle"),
         nwStatusShape.NABLA:    QT_TRANSLATE_NOOP("Constant", "Nabla"),
@@ -384,42 +394,42 @@ class nwLabels:
         nwStatusShape.STAR:     QT_TRANSLATE_NOOP("Constant", "Star"),
         nwStatusShape.PACMAN:   QT_TRANSLATE_NOOP("Constant", "Pacman"),
     }
-    SHAPES_CIRCLE = {
+    SHAPES_CIRCLE: Final[dict[nwStatusShape, str]] = {
         nwStatusShape.CIRCLE_Q: QT_TRANSLATE_NOOP("Constant", "1/4 Circle"),
         nwStatusShape.CIRCLE_H: QT_TRANSLATE_NOOP("Constant", "Half Circle"),
         nwStatusShape.CIRCLE_T: QT_TRANSLATE_NOOP("Constant", "3/4 Circle"),
         nwStatusShape.CIRCLE:   QT_TRANSLATE_NOOP("Constant", "Full Circle"),
     }
-    SHAPES_BARS = {
+    SHAPES_BARS: Final[dict[nwStatusShape, str]] = {
         nwStatusShape.BARS_1: QT_TRANSLATE_NOOP("Constant", "1 Bar"),
         nwStatusShape.BARS_2: QT_TRANSLATE_NOOP("Constant", "2 Bars"),
         nwStatusShape.BARS_3: QT_TRANSLATE_NOOP("Constant", "3 Bars"),
         nwStatusShape.BARS_4: QT_TRANSLATE_NOOP("Constant", "4 Bars"),
     }
-    SHAPES_BLOCKS = {
+    SHAPES_BLOCKS: Final[dict[nwStatusShape, str]] = {
         nwStatusShape.BLOCK_1: QT_TRANSLATE_NOOP("Constant", "1 Block"),
         nwStatusShape.BLOCK_2: QT_TRANSLATE_NOOP("Constant", "2 Blocks"),
         nwStatusShape.BLOCK_3: QT_TRANSLATE_NOOP("Constant", "3 Blocks"),
         nwStatusShape.BLOCK_4: QT_TRANSLATE_NOOP("Constant", "4 Blocks"),
     }
-    FILE_FILTERS = {
+    FILE_FILTERS: Final[dict[str, str]] = {
         "*.txt": QT_TRANSLATE_NOOP("Constant", "Text files"),
         "*.md":  QT_TRANSLATE_NOOP("Constant", "Markdown files"),
         "*.nwd": QT_TRANSLATE_NOOP("Constant", "novelWriter files"),
         "*.csv": QT_TRANSLATE_NOOP("Constant", "CSV files"),
         "*":     QT_TRANSLATE_NOOP("Constant", "All files"),
     }
-    UNIT_NAME = {
+    UNIT_NAME: Final[dict[str, str]] = {
         "mm": QT_TRANSLATE_NOOP("Constant", "Millimetres"),
         "cm": QT_TRANSLATE_NOOP("Constant", "Centimetres"),
         "in": QT_TRANSLATE_NOOP("Constant", "Inches"),
     }
-    UNIT_SCALE = {
+    UNIT_SCALE: Final[dict[str, float]] = {
         "mm": 1.0,
         "cm": 10.0,
         "in": 25.4,
     }
-    PAPER_NAME = {
+    PAPER_NAME: Final[dict[str, str]] = {
         "A4":     QT_TRANSLATE_NOOP("Constant", "A4"),
         "A5":     QT_TRANSLATE_NOOP("Constant", "A5"),
         "A6":     QT_TRANSLATE_NOOP("Constant", "A6"),
@@ -427,7 +437,7 @@ class nwLabels:
         "Letter": QT_TRANSLATE_NOOP("Constant", "US Letter"),
         "Custom": QT_TRANSLATE_NOOP("Constant", "Custom"),
     }
-    PAPER_SIZE = {
+    PAPER_SIZE: Final[dict[str, tuple[float, float]]] = {
         "A4":     (210.0, 297.0),
         "A5":     (148.0, 210.0),
         "A6":     (105.0, 148.0),
@@ -435,6 +445,18 @@ class nwLabels:
         "Letter": (215.9, 279.4),
         "Custom": (-1.0, -1.0),
     }
+    THEME_COLORS: Final[dict[str, str]] = {
+        "theme":   QT_TRANSLATE_NOOP("Constant", "Theme Colours"),
+        "default": QT_TRANSLATE_NOOP("Constant", "Foreground Colour"),
+        "faded":   QT_TRANSLATE_NOOP("Constant", "Faded Colour"),
+        "red":     QT_TRANSLATE_NOOP("Constant", "Red"),
+        "orange":  QT_TRANSLATE_NOOP("Constant", "Orange"),
+        "yellow":  QT_TRANSLATE_NOOP("Constant", "Yellow"),
+        "green":   QT_TRANSLATE_NOOP("Constant", "Green"),
+        "aqua":    QT_TRANSLATE_NOOP("Constant", "Aqua"),
+        "blue":    QT_TRANSLATE_NOOP("Constant", "Blue"),
+        "purple":  QT_TRANSLATE_NOOP("Constant", "Purple"),
+    }
 
 
 class nwHeadFmt:
@@ -450,7 +472,7 @@ class nwHeadFmt:
     CHAR_POV   = "{Char:POV}"
     CHAR_FOCUS = "{Char:Focus}"
 
-    PAGE_HEADERS = [
+    PAGE_HEADERS: Final[list[str]] = [
         TITLE, CH_NUM, CH_WORD, CH_ROMU, CH_ROML, SC_NUM, SC_ABS,
         CHAR_POV, CHAR_FOCUS
     ]
@@ -466,7 +488,7 @@ class nwQuotes:
     """Allowed quotation marks.
     Source: https://en.wikipedia.org/wiki/Quotation_mark
     """
-    SYMBOLS = {
+    SYMBOLS: Final[dict[str, str]] = {
         "\u0027": QT_TRANSLATE_NOOP("Constant", "Straight single quotation mark"),
         "\u0022": QT_TRANSLATE_NOOP("Constant", "Straight double quotation mark"),
 
@@ -491,6 +513,19 @@ class nwQuotes:
         "\u300f": QT_TRANSLATE_NOOP("Constant", "Right white corner bracket"),
     }
 
+    DASHES: Final[dict[str, str]] = {
+        "":       QT_TRANSLATE_NOOP("Constant", "None"),
+        "\u2013": QT_TRANSLATE_NOOP("Constant", "Short dash"),
+        "\u2014": QT_TRANSLATE_NOOP("Constant", "Long dash"),
+        "\u2015": QT_TRANSLATE_NOOP("Constant", "Horizontal bar"),
+    }
+
+    ALLOWED: Final[list[str]] = [
+        "\u0027", "\u0022", "\u2018", "\u2019", "\u201a", "\u201b", "\u201c", "\u201d", "\u201e",
+        "\u201f", "\u2e42", "\u2039", "\u203a", "\u00ab", "\u00bb", "\u300c", "\u300d", "\u300e",
+        "\u300f", "\u2013", "\u2014", "\u2015",
+    ]
+
 
 class nwUnicode:
     """Supported unicode character constants and their HTML equivalents."""
@@ -551,21 +586,14 @@ class nwUnicode:
     U_TIMES  = "\u00d7"  # Multiplication sign
     U_DIVIDE = "\u00f7"  # Division sign
 
-    # Arrows
-    U_UTRI   = "\u25b2"  # Up-pointing triangle
-    U_UTRIS  = "\u25b4"  # Up-pointing triangle, small
-    U_RTRI   = "\u25b6"  # Right-pointing triangle
-    U_RTRIS  = "\u25b8"  # Right-pointing triangle, small
-    U_DTRI   = "\u25bc"  # Down-pointing triangle
-    U_DTRIS  = "\u25be"  # Down-pointing triangle, small
-    U_LTRI   = "\u25c0"  # Left-pointing triangle
-    U_LTRIS  = "\u25c2"  # Left-pointing triangle, small
-
     # Special
     U_UNKN   = "\ufffd"  # Unknown character
     U_NAC1   = "\ufffe"  # Not a character
     U_NAC2   = "\uffff"  # Not a character
 
+    # Placeholders
+    U_LBREAK = "\u21b2"  # Downwards Arrow With Tip Leftwards
+
     # HTML Equivalents
     # ================
 
@@ -620,20 +648,20 @@ class nwUnicode:
     H_TIMES  = "&times;"
     H_DIVIDE = "&divide;"
 
-    # Arrows
-    H_UTRI   = "&#9650;"
-    H_UTRIS  = "&#9652;"
-    H_RTRI   = "&#9654;"
-    H_RTRIS  = "&#9656;"
-    H_DTRI   = "&#9660;"
-    H_DTRIS  = "&#9662;"
-    H_LTRI   = "&#9664;"
-    H_LTRIS  = "&#9666;"
+    # Unicode symbols expected to be used on the UI
+    UI_SYMBOLS: Final[list[str]] = [
+        U_QUOT, U_APOS, U_LAQUO, U_RAQUO, U_LSQUO, U_RSQUO, U_SBQUO, U_SUQUO,
+        U_LDQUO, U_RDQUO, U_BDQUO, U_UDQUO, U_LSAQUO, U_RSAQUO, U_BDRQUO,
+        U_LCQUO, U_RCQUO, U_LWCQUO, U_RWCQUO, U_FGDASH, U_ENDASH, U_EMDASH,
+        U_HBAR, U_HELLIP, U_MAPOS, U_PRIME, U_DPRIME, U_NBSP, U_THSP, U_THNBSP,
+        U_ENSP, U_EMSP, U_MMSP, U_CHECK, U_CROSS, U_BULL, U_TRBULL, U_HYBULL,
+        U_FLOWER, U_PERMIL, U_DEGREE, U_MINUS, U_TIMES, U_DIVIDE, U_LBREAK,
+    ]
 
 
-class nwHtmlUnicode():
+class nwHtmlUnicode:
 
-    U_TO_H = {
+    U_TO_H: Final[dict[str, str]] = {
         # Quotes
         nwUnicode.U_QUOT:   nwUnicode.H_QUOT,
         nwUnicode.U_APOS:   nwUnicode.H_APOS,
