@@ -27,8 +27,6 @@ import logging
 
 from typing import TYPE_CHECKING, Any
 
-from PyQt5.QtGui import QFont, QIcon
-
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import (
     checkInt, isHandle, isItemClass, isItemLayout, isItemType, simplified,
@@ -37,7 +35,9 @@ from novelwriter.common import (
 from novelwriter.constants import nwLabels, nwStyles, trConst
 from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    from PyQt6.QtGui import QFont, QIcon
+
     from novelwriter.core.project import NWProject
 
 logger = logging.getLogger(__name__)
@@ -53,10 +53,10 @@ class NWItem:
     """
 
     __slots__ = (
-        "_project", "_name", "_handle", "_parent", "_root", "_order",
-        "_type", "_class", "_layout", "_status", "_import", "_active",
-        "_expanded", "_heading", "_charCount", "_wordCount",
-        "_paraCount", "_cursorPos", "_initCount",
+        "_active", "_charCount", "_charInit", "_class", "_cursorPos",
+        "_expanded", "_handle", "_heading", "_import", "_layout", "_name",
+        "_order", "_paraCount", "_parent", "_project", "_root", "_status",
+        "_type", "_wordCount", "_wordInit",
     )
 
     def __init__(self, project: NWProject, handle: str) -> None:
@@ -81,7 +81,8 @@ class NWItem:
         self._wordCount = 0     # Current word count
         self._paraCount = 0     # Current paragraph count
         self._cursorPos = 0     # Last cursor position
-        self._initCount = 0     # Initial word count
+        self._wordInit  = 0     # Initial character count
+        self._charInit  = 0     # Initial word count
 
         return
 
@@ -164,9 +165,13 @@ class NWItem:
     def paraCount(self) -> int:
         return self._paraCount
 
+    @property
+    def mainCount(self) -> int:
+        return self._charCount if CONFIG.useCharCount else self._wordCount
+
     @property
     def initCount(self) -> int:
-        return self._initCount
+        return self._wordInit if CONFIG.useCharCount else self._charInit
 
     @property
     def cursorPos(self) -> int:
@@ -257,32 +262,34 @@ class NWItem:
             self._paraCount = 0
             self._cursorPos = 0
 
-        self._initCount = self._wordCount
+        self._wordInit = self._charCount
+        self._charInit = self._wordCount
 
         return True
 
     @classmethod
     def duplicate(cls, source: NWItem, handle: str) -> NWItem:
         """Make a copy of an item."""
-        cls = NWItem(source._project, handle)
-        cls._name      = source._name
-        cls._parent    = source._parent
-        cls._root      = source._root
-        cls._order     = source._order
-        cls._type      = source._type
-        cls._class     = source._class
-        cls._layout    = source._layout
-        cls._status    = source._status
-        cls._import    = source._import
-        cls._active    = source._active
-        cls._expanded  = source._expanded
-        cls._heading   = source._heading
-        cls._charCount = source._charCount
-        cls._wordCount = source._wordCount
-        cls._paraCount = source._paraCount
-        cls._cursorPos = source._cursorPos
-        cls._initCount = source._initCount
-        return cls
+        new = cls(source._project, handle)
+        new._name       = source._name
+        new._parent     = source._parent
+        new._root       = source._root
+        new._order      = source._order
+        new._type       = source._type
+        new._class      = source._class
+        new._layout     = source._layout
+        new._status     = source._status
+        new._import     = source._import
+        new._active     = source._active
+        new._expanded   = source._expanded
+        new._heading    = source._heading
+        new._charCount  = source._charCount
+        new._wordCount  = source._wordCount
+        new._paraCount  = source._paraCount
+        new._cursorPos  = source._cursorPos
+        new._wordInit = source._wordInit
+        new._charInit = source._charInit
+        return new
 
     ##
     #  Action Methods
@@ -293,6 +300,12 @@ class NWItem:
         self._project.tree.refreshItems([self._handle])
         return
 
+    def notifyNovelStructureChange(self) -> None:
+        """Notify that the structure of a novel has changed."""
+        if self._root and self._class == nwItemClass.NOVEL:
+            self._project.tree.novelStructureChanged(self._root)
+        return
+
     ##
     #  Lookup Methods
     ##
@@ -350,11 +363,12 @@ class NWItem:
         """
         if self.isFileType():
             key = "checked" if self._active else "unchecked"
+            color = "green" if self._active else "red"
             text = trConst(nwLabels.ACTIVE_NAME[key])
-            icon = SHARED.theme.getIcon(key)
+            icon = SHARED.theme.getIcon(key, color)
         else:
             text = ""
-            icon = SHARED.theme.getIcon("noncheckable")
+            icon = SHARED.theme.getIcon("noncheckable", "faded")
         return text, icon
 
     ##
@@ -421,7 +435,11 @@ class NWItem:
         """
         if self._parent is not None:
             # Only update for child items
-            self.setClass(itemClass)
+            if itemClass != self._class:
+                self.setClass(itemClass)
+                if self._type == nwItemType.FILE:
+                    # Notify the index of the class change
+                    self._project.index.refreshHandle(self._handle)
 
         if self._layout == nwItemLayout.NO_LAYOUT:
             # If no layout is set, pick one
