@@ -27,16 +27,17 @@ from __future__ import annotations
 import json
 import logging
 
-from collections.abc import Iterator
 from pathlib import Path
 from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import QLocale
+from PyQt6.QtCore import QLocale
 
 from novelwriter.constants import nwFiles
 from novelwriter.error import logException
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    from collections.abc import Iterator
+
     from novelwriter.core.project import NWProject
 
 logger = logging.getLogger(__name__)
