@@ -26,14 +26,14 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtCore import Qt, pyqtSlot
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import Qt, pyqtSlot
+from PyQt6.QtWidgets import (
     QAbstractItemView, QDialogButtonBox, QGridLayout, QLabel, QListWidget,
     QListWidgetItem, QVBoxLayout, QWidget
 )
 
-from novelwriter import CONFIG, SHARED
-from novelwriter.extensions.configlayout import NColourLabel
+from novelwriter import SHARED
+from novelwriter.extensions.configlayout import NColorLabel
 from novelwriter.extensions.modified import NDialog
 from novelwriter.extensions.switch import NSwitch
 from novelwriter.types import QtAccepted, QtDialogCancel, QtDialogOk, QtDialogReset, QtUserRole
@@ -56,33 +56,31 @@ class GuiDocMerge(NDialog):
 
         self.headLabel = QLabel(self.tr("Documents to Merge"), self)
         self.headLabel.setFont(SHARED.theme.guiFontB)
-        self.helpLabel = NColourLabel(
+        self.helpLabel = NColorLabel(
             self.tr("Drag and drop items to change the order, or uncheck to exclude."),
             self, color=SHARED.theme.helpText, wrap=True
         )
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        hSp = CONFIG.pxInt(12)
-        vSp = CONFIG.pxInt(8)
-        bSp = CONFIG.pxInt(12)
 
         self.listBox = QListWidget(self)
         self.listBox.setIconSize(iSz)
-        self.listBox.setMinimumWidth(CONFIG.pxInt(400))
-        self.listBox.setMinimumHeight(CONFIG.pxInt(180))
+        self.listBox.setMinimumWidth(400)
+        self.listBox.setMinimumHeight(180)
         self.listBox.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
         self.listBox.setSelectionMode(QAbstractItemView.SelectionMode.SingleSelection)
         self.listBox.setDragDropMode(QAbstractItemView.DragDropMode.InternalMove)
 
         # Merge Options
-        self.trashLabel = QLabel(self.tr("Move merged items to Trash"), self)
         self.trashSwitch = NSwitch(self, height=iPx)
+        self.trashLabel = QLabel(self.tr("Move merged items to Trash"), self)
+        self.trashLabel.setBuddy(self.trashSwitch)
 
         self.optBox = QGridLayout()
         self.optBox.addWidget(self.trashLabel,  0, 0)
         self.optBox.addWidget(self.trashSwitch, 0, 1)
-        self.optBox.setHorizontalSpacing(hSp)
+        self.optBox.setHorizontalSpacing(12)
         self.optBox.setColumnStretch(2, 1)
 
         # Buttons
@@ -91,18 +89,19 @@ class GuiDocMerge(NDialog):
         self.buttonBox.rejected.connect(self.reject)
 
         self.resetButton = self.buttonBox.addButton(QtDialogReset)
-        self.resetButton.clicked.connect(self._resetList)
+        if self.resetButton:
+            self.resetButton.clicked.connect(self._resetList)
 
         # Assemble
         self.outerBox = QVBoxLayout()
         self.outerBox.setSpacing(0)
         self.outerBox.addWidget(self.headLabel)
         self.outerBox.addWidget(self.helpLabel)
-        self.outerBox.addSpacing(vSp)
+        self.outerBox.addSpacing(8)
         self.outerBox.addWidget(self.listBox)
-        self.outerBox.addSpacing(vSp)
+        self.outerBox.addSpacing(8)
         self.outerBox.addLayout(self.optBox)
-        self.outerBox.addSpacing(bSp)
+        self.outerBox.addSpacing(12)
         self.outerBox.addWidget(self.buttonBox)
         self.setLayout(self.outerBox)
 
@@ -133,11 +132,11 @@ class GuiDocMerge(NDialog):
     @classmethod
     def getData(cls, parent: QWidget, handle: str, items: list[str]) -> tuple[dict, bool]:
         """Pop the dialog and return the result."""
-        cls = GuiDocMerge(parent, handle, items)
-        cls.exec()
-        data = cls.data()
-        accepted = cls.result() == QtAccepted
-        cls.softDelete()
+        dialog = cls(parent, handle, items)
+        dialog.exec()
+        data = dialog.data()
+        accepted = dialog.result() == QtAccepted
+        dialog.softDelete()
         return data, accepted
 
     ##
@@ -148,9 +147,9 @@ class GuiDocMerge(NDialog):
     def _resetList(self) -> None:
         """Reset the content of the list box to its original state."""
         logger.debug("Resetting list box content")
-        sHandle = self._data.get("sHandle", None)
-        itemList = self._data.get("origItems", [])
-        self._loadContent(sHandle, itemList)
+        if sHandle := self._data.get("sHandle"):
+            itemList = self._data.get("origItems", [])
+            self._loadContent(sHandle, itemList)
         return
 
     ##
