@@ -25,9 +25,8 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtWidgets import QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, QVBoxLayout, QWidget
+from PyQt6.QtWidgets import QDialogButtonBox, QHBoxLayout, QLabel, QLineEdit, QVBoxLayout, QWidget
 
-from novelwriter import CONFIG
 from novelwriter.extensions.modified import NDialog
 from novelwriter.types import QtAccepted, QtDialogCancel, QtDialogOk
 
@@ -43,15 +42,15 @@ class GuiEditLabel(NDialog):
         self.setObjectName("GuiEditLabel")
         self.setWindowTitle(self.tr("Item Label"))
 
-        mVd = CONFIG.pxInt(220)
-        mSp = CONFIG.pxInt(12)
-
         # Item Label
-        self.labelValue = QLineEdit(self)
-        self.labelValue.setMinimumWidth(mVd)
-        self.labelValue.setMaxLength(200)
-        self.labelValue.setText(text)
-        self.labelValue.selectAll()
+        self.edtValue = QLineEdit(self)
+        self.edtValue.setMinimumWidth(220)
+        self.edtValue.setMaxLength(200)
+        self.edtValue.setText(text)
+        self.edtValue.selectAll()
+
+        self.lblValue = QLabel(self.tr("Label"), self)
+        self.lblValue.setBuddy(self.lblValue)
 
         # Buttons
         self.buttonBox = QDialogButtonBox(QtDialogOk | QtDialogCancel, self)
@@ -60,12 +59,12 @@ class GuiEditLabel(NDialog):
 
         # Assemble
         self.innerBox = QHBoxLayout()
-        self.innerBox.addWidget(QLabel(self.tr("Label"), self), 0)
-        self.innerBox.addWidget(self.labelValue, 1)
-        self.innerBox.setSpacing(mSp)
+        self.innerBox.addWidget(self.lblValue, 0)
+        self.innerBox.addWidget(self.edtValue, 1)
+        self.innerBox.setSpacing(12)
 
         self.outerBox = QVBoxLayout()
-        self.outerBox.setSpacing(mSp)
+        self.outerBox.setSpacing(12)
         self.outerBox.addLayout(self.innerBox, 1)
         self.outerBox.addWidget(self.buttonBox, 0)
 
@@ -81,14 +80,14 @@ class GuiEditLabel(NDialog):
 
     @property
     def itemLabel(self) -> str:
-        return self.labelValue.text()
+        return self.edtValue.text()
 
     @classmethod
     def getLabel(cls, parent: QWidget, text: str) -> tuple[str, bool]:
         """Pop the dialog and return the result."""
-        cls = GuiEditLabel(parent, text=text)
-        cls.exec()
-        label = cls.itemLabel
-        accepted = cls.result() == QtAccepted
-        cls.softDelete()
+        dialog = cls(parent, text=text)
+        dialog.exec()
+        label = dialog.itemLabel
+        accepted = dialog.result() == QtAccepted
+        dialog.softDelete()
         return label, accepted
