@@ -26,18 +26,19 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtCore import Qt, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QCloseEvent, QKeyEvent, QKeySequence
-from PyQt5.QtWidgets import (
-    QCompleter, QDialogButtonBox, QFileDialog, QHBoxLayout, QLineEdit,
+from PyQt6.QtCore import Qt, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QAction, QCloseEvent, QKeyEvent, QKeySequence
+from PyQt6.QtWidgets import (
+    QCompleter, QDialogButtonBox, QFileDialog, QHBoxLayout, QLineEdit, QMenu,
     QPushButton, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import compact, describeFont, uniqueCompact
-from novelwriter.constants import nwUnicode
+from novelwriter.common import compact, describeFont, processDialogSymbols, uniqueCompact
+from novelwriter.config import DEF_GUI, DEF_ICONS, DEF_SYNTAX, DEF_TREECOL
+from novelwriter.constants import nwLabels, nwQuotes, nwUnicode, trConst
 from novelwriter.dialogs.quotes import GuiQuoteSelect
-from novelwriter.extensions.configlayout import NColourLabel, NScrollableForm
+from novelwriter.extensions.configlayout import NColorLabel, NScrollableForm
 from novelwriter.extensions.modified import (
     NComboBox, NDialog, NDoubleSpinBox, NIconToolButton, NSpinBox
 )
@@ -58,27 +59,28 @@ class GuiPreferences(NDialog):
         logger.debug("Create: GuiPreferences")
         self.setObjectName("GuiPreferences")
         self.setWindowTitle(self.tr("Preferences"))
-        self.setMinimumSize(CONFIG.pxInt(600), CONFIG.pxInt(500))
-        self.resize(*CONFIG.preferencesWinSize)
+        self.setMinimumSize(600, 500)
+        self.resize(*CONFIG.prefsWinSize)
 
         # Title
-        self.titleLabel = NColourLabel(
+        self.titleLabel = NColorLabel(
             self.tr("Preferences"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE, indent=CONFIG.pxInt(4)
+            scale=NColorLabel.HEADER_SCALE, indent=4,
         )
 
         # Search Box
+        self.searchAction = QAction(SHARED.theme.getIcon("search"), "")
+        self.searchAction.triggered.connect(self._gotoSearch)
+
         self.searchText = QLineEdit(self)
         self.searchText.setPlaceholderText(self.tr("Search"))
-        self.searchText.setMinimumWidth(CONFIG.pxInt(200))
-        self.searchAction = self.searchText.addAction(
-            SHARED.theme.getIcon("search"), QLineEdit.ActionPosition.TrailingPosition
-        )
-        self.searchAction.triggered.connect(self._gotoSearch)
+        self.searchText.setMinimumWidth(200)
+        self.searchText.addAction(self.searchAction, QLineEdit.ActionPosition.TrailingPosition)
 
         # SideBar
         self.sidebar = NPagedSideBar(self)
         self.sidebar.setLabelColor(SHARED.theme.helpText)
+        self.sidebar.setAccessibleName(self.titleLabel.text())
         self.sidebar.buttonClicked.connect(self._sidebarClicked)
 
         # Form
@@ -105,7 +107,7 @@ class GuiPreferences(NDialog):
         self.outerBox.addLayout(self.searchBox)
         self.outerBox.addLayout(self.mainBox)
         self.outerBox.addWidget(self.buttonBox)
-        self.outerBox.setSpacing(CONFIG.pxInt(8))
+        self.outerBox.setSpacing(8)
 
         self.setLayout(self.outerBox)
         self.setSizeGripEnabled(True)
@@ -134,8 +136,6 @@ class GuiPreferences(NDialog):
         section = 0
         iSz = SHARED.theme.baseIconSize
         boxFixed = 6*SHARED.theme.textNWidth
-        minWidth = CONFIG.pxInt(200)
-        fontWidth = CONFIG.pxInt(162)
 
         # Temporary Variables
         self._guiFont = CONFIG.guiFont
@@ -154,7 +154,7 @@ class GuiPreferences(NDialog):
 
         # Display Language
         self.guiLocale = NComboBox(self)
-        self.guiLocale.setMinimumWidth(minWidth)
+        self.guiLocale.setMinimumWidth(200)
         for lang, name in CONFIG.listLanguages(CONFIG.LANG_NW):
             self.guiLocale.addItem(name, lang)
         self.guiLocale.setCurrentData(CONFIG.guiLocale, "en_GB")
@@ -166,20 +166,32 @@ class GuiPreferences(NDialog):
 
         # Colour Theme
         self.guiTheme = NComboBox(self)
-        self.guiTheme.setMinimumWidth(minWidth)
+        self.guiTheme.setMinimumWidth(200)
         for theme, name in SHARED.theme.listThemes():
             self.guiTheme.addItem(name, theme)
-        self.guiTheme.setCurrentData(CONFIG.guiTheme, "default")
+        self.guiTheme.setCurrentData(CONFIG.guiTheme, DEF_GUI)
 
         self.mainForm.addRow(
             self.tr("Colour theme"), self.guiTheme,
-            self.tr("General colour theme and icons."), stretch=(3, 2)
+            self.tr("User interface colour theme."), stretch=(3, 2)
+        )
+
+        # Icon Theme
+        self.iconTheme = NComboBox(self)
+        self.iconTheme.setMinimumWidth(200)
+        for theme, name in SHARED.theme.iconCache.listThemes():
+            self.iconTheme.addItem(name, theme)
+        self.iconTheme.setCurrentData(CONFIG.iconTheme, DEF_ICONS)
+
+        self.mainForm.addRow(
+            self.tr("Icon theme"), self.iconTheme,
+            self.tr("User interface icon theme."), stretch=(3, 2)
         )
 
         # Application Font Family
         self.guiFont = QLineEdit(self)
         self.guiFont.setReadOnly(True)
-        self.guiFont.setMinimumWidth(fontWidth)
+        self.guiFont.setMinimumWidth(162)
         self.guiFont.setText(describeFont(self._guiFont))
         self.guiFont.setCursorPosition(0)
         self.guiFontButton = NIconToolButton(self, iSz, "font")
@@ -214,6 +226,14 @@ class GuiPreferences(NDialog):
             self.tr("Turn off to use the Qt font dialog, which may have more options.")
         )
 
+        # Use Character Count
+        self.useCharCount = NSwitch(self)
+        self.useCharCount.setChecked(CONFIG.useCharCount)
+        self.mainForm.addRow(
+            self.tr("Prefer character count over word count"), self.useCharCount,
+            self.tr("Display character count instead where available.")
+        )
+
         # Document Style
         # ==============
 
@@ -224,10 +244,10 @@ class GuiPreferences(NDialog):
 
         # Document Colour Theme
         self.guiSyntax = NComboBox(self)
-        self.guiSyntax.setMinimumWidth(CONFIG.pxInt(200))
+        self.guiSyntax.setMinimumWidth(200)
         for syntax, name in SHARED.theme.listSyntax():
             self.guiSyntax.addItem(name, syntax)
-        self.guiSyntax.setCurrentData(CONFIG.guiSyntax, "default_light")
+        self.guiSyntax.setCurrentData(CONFIG.guiSyntax, DEF_SYNTAX)
 
         self.mainForm.addRow(
             self.tr("Document colour theme"), self.guiSyntax,
@@ -237,7 +257,7 @@ class GuiPreferences(NDialog):
         # Document Font Family
         self.textFont = QLineEdit(self)
         self.textFont.setReadOnly(True)
-        self.textFont.setMinimumWidth(fontWidth)
+        self.textFont.setMinimumWidth(162)
         self.textFont.setText(describeFont(CONFIG.textFont))
         self.textFont.setCursorPosition(0)
         self.textFontButton = NIconToolButton(self, iSz, "font")
@@ -248,14 +268,6 @@ class GuiPreferences(NDialog):
             button=self.textFontButton
         )
 
-        # Emphasise Labels
-        self.emphLabels = NSwitch(self)
-        self.emphLabels.setChecked(CONFIG.emphLabels)
-        self.mainForm.addRow(
-            self.tr("Emphasise partition and chapter labels"), self.emphLabels,
-            self.tr("Makes them stand out in the project tree."),
-        )
-
         # Document Path
         self.showFullPath = NSwitch(self)
         self.showFullPath.setChecked(CONFIG.showFullPath)
@@ -271,6 +283,42 @@ class GuiPreferences(NDialog):
             self.tr("Include project notes in status bar word count"), self.incNotesWCount
         )
 
+        # Project View
+        # ============
+
+        title = self.tr("Project View")
+        section += 1
+        self.sidebar.addButton(title, section)
+        self.mainForm.addGroupLabel(title, section)
+
+        # Tree Icon Colours
+        self.iconColTree = NComboBox(self)
+        self.iconColTree.setMinimumWidth(200)
+        for key, label in nwLabels.THEME_COLORS.items():
+            self.iconColTree.addItem(trConst(label), key)
+        self.iconColTree.setCurrentData(CONFIG.iconColTree, DEF_TREECOL)
+
+        self.mainForm.addRow(
+            self.tr("Project tree icon colours"), self.iconColTree,
+            self.tr("Override colours for project icons."), stretch=(3, 2)
+        )
+
+        # Keep Theme Colours on Documents
+        self.iconColDocs = NSwitch(self)
+        self.iconColDocs.setChecked(CONFIG.iconColDocs)
+        self.mainForm.addRow(
+            self.tr("Keep theme colours on documents"), self.iconColDocs,
+            self.tr("Only override icon colours for folders.")
+        )
+
+        # Emphasise Labels
+        self.emphLabels = NSwitch(self)
+        self.emphLabels.setChecked(CONFIG.emphLabels)
+        self.mainForm.addRow(
+            self.tr("Emphasise partition and chapter labels"), self.emphLabels,
+            self.tr("Makes them stand out in the project tree."),
+        )
+
         # Behaviour
         # =========
 
@@ -393,7 +441,7 @@ class GuiPreferences(NDialog):
         self.textWidth.setSingleStep(10)
         self.textWidth.setValue(CONFIG.textWidth)
         self.mainForm.addRow(
-            self.tr("Maximum text width in \"Normal Mode\""), self.textWidth,
+            self.tr('Maximum text width in "Normal Mode"'), self.textWidth,
             self.tr("Set to 0 to disable this feature."), unit=self.tr("px")
         )
 
@@ -404,7 +452,7 @@ class GuiPreferences(NDialog):
         self.focusWidth.setSingleStep(10)
         self.focusWidth.setValue(CONFIG.focusWidth)
         self.mainForm.addRow(
-            self.tr("Maximum text width in \"Focus Mode\""), self.focusWidth,
+            self.tr('Maximum text width in "Focus Mode"'), self.focusWidth,
             self.tr("The maximum width cannot be disabled."), unit=self.tr("px")
         )
 
@@ -412,7 +460,7 @@ class GuiPreferences(NDialog):
         self.hideFocusFooter = NSwitch(self)
         self.hideFocusFooter.setChecked(CONFIG.hideFocusFooter)
         self.mainForm.addRow(
-            self.tr("Hide document footer in \"Focus Mode\""), self.hideFocusFooter,
+            self.tr('Hide document footer in "Focus Mode"'), self.hideFocusFooter,
             self.tr("Hide the information bar in the document editor.")
         )
 
@@ -458,7 +506,7 @@ class GuiPreferences(NDialog):
 
         # Spell Checking
         self.spellLanguage = NComboBox(self)
-        self.spellLanguage.setMinimumWidth(minWidth)
+        self.spellLanguage.setMinimumWidth(200)
 
         if CONFIG.hasEnchant:
             for tag, language in SHARED.spelling.listDictionaries():
@@ -483,6 +531,18 @@ class GuiPreferences(NDialog):
             self.tr("Apply formatting to word under cursor if no selection is made.")
         )
 
+        # Cursor Width
+        self.cursorWidth = NSpinBox(self)
+        self.cursorWidth.setMinimum(1)
+        self.cursorWidth.setMaximum(20)
+        self.cursorWidth.setSingleStep(1)
+        self.cursorWidth.setValue(CONFIG.cursorWidth)
+        self.mainForm.addRow(
+            self.tr("Cursor width"), self.cursorWidth,
+            self.tr("The width of the text cursor of the editor."),
+            unit=self.tr("px")
+        )
+
         # Show Tabs and Spaces
         self.showTabsNSpaces = NSwitch(self)
         self.showTabsNSpaces.setChecked(CONFIG.showTabsNSpaces)
@@ -509,7 +569,7 @@ class GuiPreferences(NDialog):
         self.scrollPastEnd = NSwitch(self)
         self.scrollPastEnd.setChecked(CONFIG.scrollPastEnd)
         self.mainForm.addRow(
-            self.tr("Scroll past end of the document"), self.scrollPastEnd,
+            self.tr("Scroll past the end of the document"), self.scrollPastEnd,
             self.tr("Also centres the cursor when scrolling.")
         )
 
@@ -540,6 +600,7 @@ class GuiPreferences(NDialog):
         self.sidebar.addButton(title, section)
         self.mainForm.addGroupLabel(title, section)
 
+        # Dialogue Quotes
         self.dialogStyle = NComboBox(self)
         self.dialogStyle.addItem(self.tr("None"), 0)
         self.dialogStyle.addItem(self.tr("Single Quotes"), 1)
@@ -551,6 +612,15 @@ class GuiPreferences(NDialog):
             self.tr("Applies to the selected quote styles.")
         )
 
+        # Open-Ended Dialogue
+        self.allowOpenDial = NSwitch(self)
+        self.allowOpenDial.setChecked(CONFIG.allowOpenDial)
+        self.mainForm.addRow(
+            self.tr("Allow open-ended dialogue"), self.allowOpenDial,
+            self.tr("Highlight dialogue line with no closing quote.")
+        )
+
+        # Alternative Dialogue
         self.altDialogOpen = QLineEdit(self)
         self.altDialogOpen.setMaxLength(4)
         self.altDialogOpen.setFixedWidth(boxFixed)
@@ -568,43 +638,50 @@ class GuiPreferences(NDialog):
             self.tr("Custom highlighting of dialogue text.")
         )
 
-        self.allowOpenDial = NSwitch(self)
-        self.allowOpenDial.setChecked(CONFIG.allowOpenDial)
-        self.mainForm.addRow(
-            self.tr("Allow open-ended dialogue"), self.allowOpenDial,
-            self.tr("Highlight dialogue line with no closing quote.")
-        )
+        # Dialogue Line
+        self.mnLineSymbols = QMenu(self)
+        for symbol in nwQuotes.ALLOWED:
+            label = trConst(nwQuotes.SYMBOLS.get(symbol, nwQuotes.DASHES.get(symbol, "None")))
+            self.mnLineSymbols.addAction(
+                f"[ {symbol } ] {label}",
+                lambda symbol=symbol: self._insertDialogLineSymbol(symbol)
+            )
 
         self.dialogLine = QLineEdit(self)
-        self.dialogLine.setMaxLength(4)
-        self.dialogLine.setFixedWidth(boxFixed)
+        self.dialogLine.setMinimumWidth(100)
         self.dialogLine.setAlignment(QtAlignCenter)
-        self.dialogLine.setText(CONFIG.dialogLine)
+        self.dialogLine.setText(" ".join(CONFIG.dialogLine))
+
+        self.dialogLineButton = NIconToolButton(self, iSz, "add", "green")
+        self.dialogLineButton.setMenu(self.mnLineSymbols)
+
         self.mainForm.addRow(
             self.tr("Dialogue line symbols"), self.dialogLine,
-            self.tr("Lines starting with any of these symbols are dialogue.")
+            self.tr("Lines starting with any of these symbols are dialogue."),
+            button=self.dialogLineButton
         )
 
-        self.narratorBreak = QLineEdit(self)
-        self.narratorBreak.setMaxLength(1)
-        self.narratorBreak.setFixedWidth(boxFixed)
-        self.narratorBreak.setAlignment(QtAlignCenter)
-        self.narratorBreak.setText(CONFIG.narratorBreak)
+        # Narrator Break
+        self.narratorBreak = NComboBox(self)
+        self.narratorDialog = NComboBox(self)
+        for key, value in nwQuotes.DASHES.items():
+            label = trConst(value)
+            self.narratorBreak.addItem(label, key)
+            self.narratorDialog.addItem(label, key)
+
+        self.narratorBreak.setCurrentData(CONFIG.narratorBreak, "")
+        self.narratorDialog.setCurrentData(CONFIG.narratorDialog, "")
+
         self.mainForm.addRow(
             self.tr("Narrator break symbol"), self.narratorBreak,
             self.tr("Symbol to indicate a narrator break in dialogue.")
         )
-
-        self.narratorDialog = QLineEdit(self)
-        self.narratorDialog.setMaxLength(1)
-        self.narratorDialog.setFixedWidth(boxFixed)
-        self.narratorDialog.setAlignment(QtAlignCenter)
-        self.narratorDialog.setText(CONFIG.narratorDialog)
         self.mainForm.addRow(
             self.tr("Alternating dialogue/narration symbol"), self.narratorDialog,
             self.tr("Alternates dialogue highlighting within any paragraph.")
         )
 
+        # Emphasis
         self.highlightEmph = NSwitch(self)
         self.highlightEmph.setChecked(CONFIG.highlightEmph)
         self.mainForm.addRow(
@@ -612,6 +689,7 @@ class GuiPreferences(NDialog):
             self.tr("Applies to the document editor only.")
         )
 
+        # Additional Spaces
         self.showMultiSpaces = NSwitch(self)
         self.showMultiSpaces.setChecked(CONFIG.showMultiSpaces)
         self.mainForm.addRow(
@@ -627,8 +705,6 @@ class GuiPreferences(NDialog):
         self.sidebar.addButton(title, section)
         self.mainForm.addGroupLabel(title, section)
 
-        boxWidth = CONFIG.pxInt(150)
-
         # Auto-Replace as You Type Main Switch
         self.doReplace = NSwitch(self)
         self.doReplace.setChecked(CONFIG.doReplace)
@@ -677,7 +753,7 @@ class GuiPreferences(NDialog):
         # Pad Before
         self.fmtPadBefore = QLineEdit(self)
         self.fmtPadBefore.setMaxLength(32)
-        self.fmtPadBefore.setMinimumWidth(boxWidth)
+        self.fmtPadBefore.setMinimumWidth(150)
         self.fmtPadBefore.setText(CONFIG.fmtPadBefore)
         self.mainForm.addRow(
             self.tr("Insert non-breaking space before"), self.fmtPadBefore,
@@ -687,7 +763,7 @@ class GuiPreferences(NDialog):
         # Pad After
         self.fmtPadAfter = QLineEdit(self)
         self.fmtPadAfter.setMaxLength(32)
-        self.fmtPadAfter.setMinimumWidth(boxWidth)
+        self.fmtPadAfter.setMinimumWidth(150)
         self.fmtPadAfter.setText(CONFIG.fmtPadAfter)
         self.mainForm.addRow(
             self.tr("Insert non-breaking space after"), self.fmtPadAfter,
@@ -849,6 +925,14 @@ class GuiPreferences(NDialog):
         self.askBeforeBackup.setEnabled(state)
         return
 
+    @pyqtSlot(str)
+    def _insertDialogLineSymbol(self, symbol: str) -> None:
+        """Insert a symbol in the dialogue line box."""
+        current = self.dialogLine.text()
+        values = processDialogSymbols(f"{current} {symbol}")
+        self.dialogLine.setText(" ".join(values))
+        return
+
     @pyqtSlot(bool)
     def _toggleAutoReplaceMain(self, state: bool) -> None:
         """Toggle switches controlled by the auto replace switch."""
@@ -908,33 +992,49 @@ class GuiPreferences(NDialog):
         refreshTree  = False
 
         # Appearance
-        guiLocale = self.guiLocale.currentData()
-        guiTheme  = self.guiTheme.currentData()
+        guiLocale    = self.guiLocale.currentData()
+        guiTheme     = self.guiTheme.currentData()
+        iconTheme    = self.iconTheme.currentData()
+        useCharCount = self.useCharCount.isChecked()
 
         updateTheme  |= CONFIG.guiTheme != guiTheme
+        updateTheme  |= CONFIG.iconTheme != iconTheme
         needsRestart |= CONFIG.guiLocale != guiLocale
         needsRestart |= CONFIG.guiFont != self._guiFont
+        refreshTree  |= CONFIG.useCharCount != useCharCount
 
-        CONFIG.guiLocale   = guiLocale
-        CONFIG.guiTheme    = guiTheme
-        CONFIG.hideVScroll = self.hideVScroll.isChecked()
-        CONFIG.hideHScroll = self.hideHScroll.isChecked()
-        CONFIG.nativeFont  = self.nativeFont.isChecked()
+        CONFIG.guiLocale    = guiLocale
+        CONFIG.guiTheme     = guiTheme
+        CONFIG.iconTheme    = iconTheme
+        CONFIG.hideVScroll  = self.hideVScroll.isChecked()
+        CONFIG.hideHScroll  = self.hideHScroll.isChecked()
+        CONFIG.nativeFont   = self.nativeFont.isChecked()
+        CONFIG.useCharCount = useCharCount
         CONFIG.setGuiFont(self._guiFont)
 
         # Document Style
-        guiSyntax  = self.guiSyntax.currentData()
-        emphLabels = self.emphLabels.isChecked()
+        guiSyntax = self.guiSyntax.currentData()
 
         updateSyntax |= CONFIG.guiSyntax != guiSyntax
-        refreshTree  |= CONFIG.emphLabels != emphLabels
 
         CONFIG.guiSyntax      = guiSyntax
-        CONFIG.emphLabels     = emphLabels
         CONFIG.showFullPath   = self.showFullPath.isChecked()
         CONFIG.incNotesWCount = self.incNotesWCount.isChecked()
         CONFIG.setTextFont(self._textFont)
 
+        # Project View
+        iconColTree = self.iconColTree.currentData()
+        iconColDocs = self.iconColDocs.isChecked()
+        emphLabels = self.emphLabels.isChecked()
+
+        updateTheme |= CONFIG.iconColTree != iconColTree
+        updateTheme |= CONFIG.iconColDocs != iconColDocs
+        refreshTree |= CONFIG.emphLabels != emphLabels
+
+        CONFIG.iconColTree = iconColTree
+        CONFIG.iconColDocs = iconColDocs
+        CONFIG.emphLabels     = emphLabels
+
         # Behaviour
         CONFIG.autoSaveDoc   = self.autoSaveDoc.value()
         CONFIG.autoSaveProj  = self.autoSaveProj.value()
@@ -960,6 +1060,7 @@ class GuiPreferences(NDialog):
         # Text Editing
         CONFIG.spellLanguage   = self.spellLanguage.currentData()
         CONFIG.autoSelect      = self.autoSelect.isChecked()
+        CONFIG.cursorWidth     = self.cursorWidth.value()
         CONFIG.showTabsNSpaces = self.showTabsNSpaces.isChecked()
         CONFIG.showLineEndings = self.showLineEndings.isChecked()
 
@@ -971,9 +1072,9 @@ class GuiPreferences(NDialog):
         # Text Highlighting
         dialogueStyle   = self.dialogStyle.currentData()
         allowOpenDial   = self.allowOpenDial.isChecked()
-        dialogueLine    = uniqueCompact(self.dialogLine.text())
-        narratorBreak   = self.narratorBreak.text().strip()
-        narratorDialog  = self.narratorDialog.text().strip()
+        dialogueLine    = processDialogSymbols(self.dialogLine.text())
+        narratorBreak   = self.narratorBreak.currentData()
+        narratorDialog  = self.narratorDialog.currentData()
         altDialogOpen   = compact(self.altDialogOpen.text())
         altDialogClose  = compact(self.altDialogClose.text())
         highlightEmph   = self.highlightEmph.isChecked()
