@@ -29,20 +29,20 @@ import logging
 
 from pathlib import Path
 
-from PyQt5.QtCore import Qt, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QCloseEvent, QColor
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import Qt, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QCloseEvent, QColor
+from PyQt6.QtWidgets import (
     QAbstractItemView, QApplication, QColorDialog, QDialogButtonBox,
     QFileDialog, QGridLayout, QHBoxLayout, QLineEdit, QMenu, QStackedWidget,
     QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import formatFileFilter, qtLambda, simplified
+from novelwriter.common import formatFileFilter, qtAddAction, qtLambda, simplified
 from novelwriter.constants import nwLabels, trConst
 from novelwriter.core.status import NWStatus, StatusEntry
 from novelwriter.enum import nwStatusShape
-from novelwriter.extensions.configlayout import NColourLabel, NFixedPage, NScrollableForm
+from novelwriter.extensions.configlayout import NColorLabel, NFixedPage, NScrollableForm
 from novelwriter.extensions.modified import NComboBox, NDialog, NIconToolButton
 from novelwriter.extensions.pagedsidebar import NPagedSideBar
 from novelwriter.extensions.switch import NSwitch
@@ -71,21 +71,22 @@ class GuiProjectSettings(NDialog):
         self.setWindowTitle(self.tr("Project Settings"))
 
         options = SHARED.project.options
-        self.setMinimumSize(CONFIG.pxInt(500), CONFIG.pxInt(400))
+        self.setMinimumSize(500, 400)
         self.resize(
-            CONFIG.pxInt(options.getInt("GuiProjectSettings", "winWidth", CONFIG.pxInt(650))),
-            CONFIG.pxInt(options.getInt("GuiProjectSettings", "winHeight", CONFIG.pxInt(500)))
+            options.getInt("GuiProjectSettings", "winWidth", 650),
+            options.getInt("GuiProjectSettings", "winHeight", 500),
         )
 
         # Title
-        self.titleLabel = NColourLabel(
+        self.titleLabel = NColorLabel(
             self.tr("Project Settings"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE, indent=CONFIG.pxInt(4)
+            scale=NColorLabel.HEADER_SCALE, indent=4,
         )
 
         # SideBar
         self.sidebar = NPagedSideBar(self)
         self.sidebar.setLabelColor(SHARED.theme.helpText)
+        self.sidebar.setAccessibleName(self.titleLabel.text())
         self.sidebar.addButton(self.tr("Settings"), self.PAGE_SETTINGS)
         self.sidebar.addButton(self.tr("Status"), self.PAGE_STATUS)
         self.sidebar.addButton(self.tr("Importance"), self.PAGE_IMPORT)
@@ -125,7 +126,7 @@ class GuiProjectSettings(NDialog):
         self.outerBox.addLayout(self.topBox)
         self.outerBox.addLayout(self.mainBox)
         self.outerBox.addWidget(self.buttonBox)
-        self.outerBox.setSpacing(CONFIG.pxInt(8))
+        self.outerBox.setSpacing(8)
 
         self.setLayout(self.outerBox)
         self.setSizeGripEnabled(True)
@@ -210,16 +211,14 @@ class GuiProjectSettings(NDialog):
 
     def _saveSettings(self) -> None:
         """Save GUI settings."""
-        winWidth    = CONFIG.rpxInt(self.width())
-        winHeight   = CONFIG.rpxInt(self.height())
-        statusColW  = CONFIG.rpxInt(self.statusPage.columnWidth())
-        importColW  = CONFIG.rpxInt(self.importPage.columnWidth())
-        replaceColW = CONFIG.rpxInt(self.replacePage.columnWidth())
+        statusColW  = self.statusPage.columnWidth()
+        importColW  = self.importPage.columnWidth()
+        replaceColW = self.replacePage.columnWidth()
 
         logger.debug("Saving State: GuiProjectSettings")
         options = SHARED.project.options
-        options.setValue("GuiProjectSettings", "winWidth", winWidth)
-        options.setValue("GuiProjectSettings", "winHeight", winHeight)
+        options.setValue("GuiProjectSettings", "winWidth", self.width())
+        options.setValue("GuiProjectSettings", "winHeight", self.height())
         options.setValue("GuiProjectSettings", "statusColW", statusColW)
         options.setValue("GuiProjectSettings", "importColW", importColW)
         options.setValue("GuiProjectSettings", "replaceColW", replaceColW)
@@ -232,7 +231,6 @@ class _SettingsPage(NScrollableForm):
     def __init__(self, parent: QWidget) -> None:
         super().__init__(parent=parent)
 
-        xW = CONFIG.pxInt(200)
         data = SHARED.project.data
         self.setHelpTextStyle(SHARED.theme.helpText)
         self.setRowIndent(0)
@@ -240,7 +238,7 @@ class _SettingsPage(NScrollableForm):
         # Project Name
         self.projName = QLineEdit(self)
         self.projName.setMaxLength(200)
-        self.projName.setMinimumWidth(xW)
+        self.projName.setMinimumWidth(200)
         self.projName.setText(data.name)
         self.addRow(
             self.tr("Project name"), self.projName,
@@ -251,7 +249,7 @@ class _SettingsPage(NScrollableForm):
         # Project Author
         self.projAuthor = QLineEdit(self)
         self.projAuthor.setMaxLength(200)
-        self.projAuthor.setMinimumWidth(xW)
+        self.projAuthor.setMinimumWidth(200)
         self.projAuthor.setText(data.author)
         self.addRow(
             self.tr("Author(s)"), self.projAuthor,
@@ -262,7 +260,7 @@ class _SettingsPage(NScrollableForm):
         # Project Language
         projLang = data.language or CONFIG.guiLocale
         self.projLang = NComboBox(self)
-        self.projLang.setMinimumWidth(xW)
+        self.projLang.setMinimumWidth(200)
         for tag, language in CONFIG.listLanguages(CONFIG.LANG_PROJ):
             self.projLang.addItem(language, tag)
         self.projLang.setCurrentData(projLang, projLang)
@@ -274,7 +272,7 @@ class _SettingsPage(NScrollableForm):
 
         # Spell Check Language
         self.spellLang = NComboBox(self)
-        self.spellLang.setMinimumWidth(xW)
+        self.spellLang.setMinimumWidth(200)
         self.spellLang.addItem(self.tr("Default"), "None")
         if CONFIG.hasEnchant:
             for tag, language in SHARED.spelling.listDictionaries():
@@ -323,9 +321,7 @@ class _StatusPage(NFixedPage):
             pageLabel = self.tr("Project Note Importance Levels")
             colSetting = "importColW"
 
-        wCol0 = CONFIG.pxInt(
-            SHARED.project.options.getInt("GuiProjectSettings", colSetting, 130)
-        )
+        wCol0 = SHARED.project.options.getInt("GuiProjectSettings", colSetting, 130)
 
         self._changed = False
         self._color = QColor(100, 100, 100)
@@ -334,7 +330,6 @@ class _StatusPage(NFixedPage):
 
         self._iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        bPd = CONFIG.pxInt(4)
 
         iColor = self.palette().text().color()
 
@@ -345,9 +340,9 @@ class _StatusPage(NFixedPage):
         self.trSelColor  = self.tr("Select Colour")
 
         # Title
-        self.pageTitle = NColourLabel(
+        self.pageTitle = NColorLabel(
             pageLabel, self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE
+            scale=NColorLabel.HEADER_SCALE
         )
 
         # List Box
@@ -355,6 +350,7 @@ class _StatusPage(NFixedPage):
         self.listBox.setHeaderLabels([self.tr("Label"), self.tr("Usage")])
         self.listBox.setColumnWidth(self.C_LABEL, wCol0)
         self.listBox.setIndentation(0)
+        self.listBox.setAccessibleName(pageLabel)
         self.listBox.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
         self.listBox.setSelectionMode(QAbstractItemView.SelectionMode.SingleSelection)
         self.listBox.itemSelectionChanged.connect(self._onSelectionChanged)
@@ -363,27 +359,27 @@ class _StatusPage(NFixedPage):
             self._addItem(key, StatusEntry.duplicate(entry))
 
         # List Controls
-        self.addButton = NIconToolButton(self, iSz, "add")
+        self.addButton = NIconToolButton(self, iSz, "add", "green")
         self.addButton.setToolTip(self.tr("Add Label"))
         self.addButton.clicked.connect(self._onItemCreate)
 
-        self.delButton = NIconToolButton(self, iSz, "remove")
+        self.delButton = NIconToolButton(self, iSz, "remove", "red")
         self.delButton.setToolTip(self.tr("Delete Label"))
         self.delButton.clicked.connect(self._onItemDelete)
 
-        self.upButton = NIconToolButton(self, iSz, "up")
+        self.upButton = NIconToolButton(self, iSz, "chevron_up", "blue")
         self.upButton.setToolTip(self.tr("Move Up"))
         self.upButton.clicked.connect(qtLambda(self._moveItem, -1))
 
-        self.downButton = NIconToolButton(self, iSz, "down")
+        self.downButton = NIconToolButton(self, iSz, "chevron_down", "blue")
         self.downButton.setToolTip(self.tr("Move Down"))
         self.downButton.clicked.connect(qtLambda(self._moveItem, 1))
 
-        self.importButton = NIconToolButton(self, iSz, "import")
+        self.importButton = NIconToolButton(self, iSz, "import", "green")
         self.importButton.setToolTip(self.tr("Import Labels"))
         self.importButton.clicked.connect(self._importLabels)
 
-        self.exportButton = NIconToolButton(self, iSz, "export")
+        self.exportButton = NIconToolButton(self, iSz, "export", "blue")
         self.exportButton.setToolTip(self.tr("Export Labels"))
         self.exportButton.clicked.connect(self._exportLabels)
 
@@ -395,7 +391,7 @@ class _StatusPage(NFixedPage):
         self.labelText.textEdited.connect(self._onNameEdit)
 
         buttonStyle = (
-            f"QToolButton {{padding: 0 {bPd}px;}} "
+            "QToolButton {padding: 0 4px;} "
             "QToolButton::menu-indicator {image: none;}"
         )
 
@@ -404,14 +400,17 @@ class _StatusPage(NFixedPage):
         self.colorButton.setSizePolicy(QtSizeMinimum, QtSizeMinimumExpanding)
         self.colorButton.setStyleSheet(buttonStyle)
         self.colorButton.setEnabled(False)
-        self.colorButton.clicked.connect(self._onColourSelect)
+        self.colorButton.clicked.connect(self._onColorSelect)
 
-        def buildMenu(menu: QMenu, items: dict[nwStatusShape, str]) -> None:
-            for shape, label in items.items():
-                icon = NWStatus.createIcon(self._iPx, iColor, shape)
-                action = menu.addAction(icon, trConst(label))
-                action.triggered.connect(qtLambda(self._selectShape, shape))
-                self._icons[shape] = icon
+        def buildMenu(menu: QMenu | None, items: dict[nwStatusShape, str]) -> None:
+            if menu is not None:
+                for shape, label in items.items():
+                    icon = NWStatus.createIcon(self._iPx, iColor, shape)
+                    action = qtAddAction(menu, trConst(label))
+                    action.setIcon(icon)
+                    action.triggered.connect(qtLambda(self._selectShape, shape))
+                    menu.addAction(action)
+                    self._icons[shape] = icon
 
         self.shapeMenu = QMenu(self)
         buildMenu(self.shapeMenu, nwLabels.SHAPES_PLAIN)
@@ -498,7 +497,7 @@ class _StatusPage(NFixedPage):
         return
 
     @pyqtSlot()
-    def _onColourSelect(self) -> None:
+    def _onColorSelect(self) -> None:
         """Open a dialog to select the status icon colour."""
         if (color := QColorDialog.getColor(self._color, self, self.trSelColor)).isValid():
             self._color = color
@@ -676,15 +675,12 @@ class _ReplacePage(NFixedPage):
         self._changed = False
 
         iSz = SHARED.theme.baseIconSize
-
-        wCol0 = CONFIG.pxInt(
-            SHARED.project.options.getInt("GuiProjectSettings", "replaceColW", 130)
-        )
+        wCol0 = SHARED.project.options.getInt("GuiProjectSettings", "replaceColW", 130)
 
         # Title
-        self.pageTitle = NColourLabel(
+        self.pageTitle = NColorLabel(
             self.tr("Text Auto-Replace for Preview and Build"), self,
-            color=SHARED.theme.helpText, scale=NColourLabel.HEADER_SCALE
+            color=SHARED.theme.helpText, scale=NColorLabel.HEADER_SCALE
         )
 
         # List Box
@@ -692,22 +688,23 @@ class _ReplacePage(NFixedPage):
         self.listBox.setHeaderLabels([self.tr("Keyword"), self.tr("Replace With")])
         self.listBox.setColumnWidth(self.C_KEY, wCol0)
         self.listBox.setIndentation(0)
+        self.listBox.setAccessibleName(self.pageTitle.text())
         self.listBox.setSelectionBehavior(QAbstractItemView.SelectionBehavior.SelectRows)
         self.listBox.setSelectionMode(QAbstractItemView.SelectionMode.SingleSelection)
         self.listBox.itemSelectionChanged.connect(self._onSelectionChanged)
 
         for aKey, aVal in SHARED.project.data.autoReplace.items():
-            newItem = QTreeWidgetItem(["<%s>" % aKey, aVal])
+            newItem = QTreeWidgetItem([f"<{aKey}>", aVal])
             self.listBox.addTopLevelItem(newItem)
 
         self.listBox.sortByColumn(self.C_KEY, Qt.SortOrder.AscendingOrder)
         self.listBox.setSortingEnabled(True)
 
         # List Controls
-        self.addButton = NIconToolButton(self, iSz, "add")
+        self.addButton = NIconToolButton(self, iSz, "add", "green")
         self.addButton.clicked.connect(self._onEntryCreated)
 
-        self.delButton = NIconToolButton(self, iSz, "remove")
+        self.delButton = NIconToolButton(self, iSz, "remove", "red")
         self.delButton.clicked.connect(self._onEntryDeleted)
 
         # Edit Form
