@@ -26,10 +26,10 @@ from __future__ import annotations
 import logging
 
 from pathlib import Path
+from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import Qt, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QCloseEvent
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import Qt, pyqtSignal, pyqtSlot
+from PyQt6.QtWidgets import (
     QAbstractItemView, QApplication, QDialogButtonBox, QFileDialog,
     QHBoxLayout, QLineEdit, QListWidget, QVBoxLayout, QWidget
 )
@@ -37,10 +37,13 @@ from PyQt5.QtWidgets import (
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import formatFileFilter
 from novelwriter.core.spellcheck import UserDictionary
-from novelwriter.extensions.configlayout import NColourLabel
+from novelwriter.extensions.configlayout import NColorLabel
 from novelwriter.extensions.modified import NDialog, NIconToolButton
 from novelwriter.types import QtDialogClose, QtDialogSave
 
+if TYPE_CHECKING:
+    from PyQt6.QtGui import QCloseEvent
+
 logger = logging.getLogger(__name__)
 
 
@@ -56,28 +59,25 @@ class GuiWordList(NDialog):
         self.setWindowTitle(self.tr("Project Word List"))
 
         iSz = SHARED.theme.baseIconSize
-        mS = CONFIG.pxInt(250)
-        wW = CONFIG.pxInt(320)
-        wH = CONFIG.pxInt(340)
 
-        self.setMinimumWidth(mS)
-        self.setMinimumHeight(mS)
+        self.setMinimumWidth(250)
+        self.setMinimumHeight(250)
         self.resize(
-            CONFIG.pxInt(SHARED.project.options.getInt("GuiWordList", "winWidth",  wW)),
-            CONFIG.pxInt(SHARED.project.options.getInt("GuiWordList", "winHeight", wH))
+            SHARED.project.options.getInt("GuiWordList", "winWidth",  320),
+            SHARED.project.options.getInt("GuiWordList", "winHeight", 340),
         )
 
         # Header
-        self.headLabel = NColourLabel(
+        self.headLabel = NColorLabel(
             self.tr("Project Word List"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE
+            scale=NColorLabel.HEADER_SCALE
         )
 
-        self.importButton = NIconToolButton(self, iSz, "import")
+        self.importButton = NIconToolButton(self, iSz, "import", "green")
         self.importButton.setToolTip(self.tr("Import words from text file"))
         self.importButton.clicked.connect(self._importWords)
 
-        self.exportButton = NIconToolButton(self, iSz, "export")
+        self.exportButton = NIconToolButton(self, iSz, "export", "blue")
         self.exportButton.setToolTip(self.tr("Export words to text file"))
         self.exportButton.clicked.connect(self._exportWords)
 
@@ -95,11 +95,11 @@ class GuiWordList(NDialog):
         # Add/Remove Form
         self.newEntry = QLineEdit(self)
 
-        self.addButton = NIconToolButton(self, iSz, "add")
+        self.addButton = NIconToolButton(self, iSz, "add", "green")
         self.addButton.setToolTip(self.tr("Add Word"))
         self.addButton.clicked.connect(self._doAdd)
 
-        self.delButton = NIconToolButton(self, iSz, "remove")
+        self.delButton = NIconToolButton(self, iSz, "remove", "red")
         self.delButton.setToolTip(self.tr("Remove Word"))
         self.delButton.clicked.connect(self._doDelete)
 
@@ -118,9 +118,9 @@ class GuiWordList(NDialog):
         self.outerBox.addLayout(self.headerBox, 0)
         self.outerBox.addWidget(self.listBox, 1)
         self.outerBox.addLayout(self.editBox, 0)
-        self.outerBox.addSpacing(CONFIG.pxInt(12))
+        self.outerBox.addSpacing(12)
         self.outerBox.addWidget(self.buttonBox, 0)
-        self.outerBox.setSpacing(CONFIG.pxInt(4))
+        self.outerBox.setSpacing(4)
 
         self.setLayout(self.outerBox)
 
@@ -230,14 +230,10 @@ class GuiWordList(NDialog):
 
     def _saveGuiSettings(self) -> None:
         """Save GUI settings."""
-        winWidth  = CONFIG.rpxInt(self.width())
-        winHeight = CONFIG.rpxInt(self.height())
-
         logger.debug("Saving State: GuiWordList")
         pOptions = SHARED.project.options
-        pOptions.setValue("GuiWordList", "winWidth",  winWidth)
-        pOptions.setValue("GuiWordList", "winHeight", winHeight)
-
+        pOptions.setValue("GuiWordList", "winWidth",  self.width())
+        pOptions.setValue("GuiWordList", "winHeight", self.height())
         return
 
     def _addWord(self, word: str) -> None:
@@ -249,8 +245,7 @@ class GuiWordList(NDialog):
 
     def _listWords(self) -> list[str]:
         """List all words in the list box."""
-        result = []
-        for i in range(self.listBox.count()):
-            if (item := self.listBox.item(i)) and (word := item.text().strip()):
-                result.append(word)
-        return result
+        return [
+            word for i in range(self.listBox.count())
+            if (item := self.listBox.item(i)) and (word := item.text().strip())
+        ]
