@@ -29,14 +29,14 @@ import sys
 
 from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import Qt, pyqtSlot
-from PyQt5.QtGui import QFont, QFontDatabase
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import Qt, pyqtSlot
+from PyQt6.QtGui import QFont, QFontDatabase
+from PyQt6.QtWidgets import (
     QApplication, QDialog, QDialogButtonBox, QGridLayout, QLabel,
     QPlainTextEdit, QStyle, QWidget
 )
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from types import TracebackType
 
 logger = logging.getLogger(__name__)
@@ -46,7 +46,7 @@ def logException() -> None:
     """Log the content of an exception message."""
     exType, exValue, _ = sys.exc_info()
     if exType is not None:
-        logger.error(f"{exType.__name__}: {str(exValue)}", stacklevel=2)
+        logger.error(f"{exType.__name__}: {exValue!s}", stacklevel=2)
     return
 
 
@@ -54,7 +54,7 @@ def formatException(exc: BaseException) -> str:
     """Format an exception as a string the same way the default
     exception handler does.
     """
-    return f"{type(exc).__name__}: {str(exc)}"
+    return f"{type(exc).__name__}: {exc!s}"
 
 
 class NWErrorMessage(QDialog):
@@ -65,11 +65,11 @@ class NWErrorMessage(QDialog):
 
         # Widgets
         self.msgIcon = QLabel()
-        self.msgIcon.setPixmap(
-            QApplication.style().standardIcon(
-                QStyle.StandardPixmap.SP_MessageBoxCritical
-            ).pixmap(64, 64)
-        )
+        if style := QApplication.style():
+            self.msgIcon.setPixmap(
+                style.standardIcon(QStyle.StandardPixmap.SP_MessageBoxCritical).pixmap(64, 64)
+            )
+
         self.msgHead = QLabel()
         self.msgHead.setOpenExternalLinks(True)
         self.msgHead.setWordWrap(True)
@@ -118,7 +118,7 @@ class NWErrorMessage(QDialog):
         """
         from traceback import format_tb
 
-        from PyQt5.QtCore import PYQT_VERSION_STR, QT_VERSION_STR, QSysInfo
+        from PyQt6.QtCore import PYQT_VERSION_STR, QT_VERSION_STR, QSysInfo
 
         from novelwriter import __version__
         from novelwriter.constants import nwConst
@@ -144,16 +144,16 @@ class NWErrorMessage(QDialog):
 
         try:
             txtTrace = "\n".join(format_tb(exTrace))
-            self.msgBody.setPlainText((
+            self.msgBody.setPlainText(
                 "Environment:\n"
                 f"novelWriter Version: {__version__}\n"
                 f"Host OS: {sys.platform} ({kernelVersion})\n"
                 f"Python: {sys.version.split()[0]} ({sys.hexversion:#x})\n"
                 f"Qt: {QT_VERSION_STR}, PyQt: {PYQT_VERSION_STR}\n"
                 f"enchant: {enchantVersion}\n\n"
-                f"{exType.__name__}:\n{str(exValue)}\n\n"
+                f"{exType.__name__}:\n{exValue!s}\n\n"
                 f"Traceback:\n{txtTrace}\n"
-            ))
+            )
         except Exception:
             self.msgBody.setPlainText("Failed to generate error report ...")
 
@@ -174,7 +174,7 @@ def exceptionHandler(exType: type, exValue: BaseException, exTrace: TracebackTyp
     """Function to catch unhandled global exceptions."""
     from traceback import print_tb
 
-    from PyQt5.QtWidgets import QApplication
+    from PyQt6.QtWidgets import QApplication
 
     logger.critical("%s: %s", exType.__name__, str(exValue))
     print_tb(exTrace)
