@@ -26,9 +26,9 @@ from __future__ import annotations
 
 from math import ceil
 
-from PyQt5.QtCore import QRect
-from PyQt5.QtGui import QBrush, QColor, QPainter, QPaintEvent, QPen
-from PyQt5.QtWidgets import QProgressBar, QWidget
+from PyQt6.QtCore import QRect
+from PyQt6.QtGui import QBrush, QColor, QPainter, QPaintEvent, QPen
+from PyQt6.QtWidgets import QProgressBar, QWidget
 
 from novelwriter.types import (
     QtAlignCenter, QtPaintAntiAlias, QtRoundCap, QtSizeFixed, QtSolidLine,
@@ -44,8 +44,8 @@ class NProgressCircle(QProgressBar):
     """
 
     __slots__ = (
-        "_text", "_point", "_dRect", "_cRect", "_dPen", "_dBrush",
-        "_cPen", "_bPen", "_tColor"
+        "_bPen", "_cPen", "_cRect", "_dBrush", "_dPen", "_dRect", "_point",
+        "_tColor", "_text",
     )
 
     def __init__(self, parent: QWidget, size: int, point: int) -> None:
@@ -56,7 +56,7 @@ class NProgressCircle(QProgressBar):
         self._cRect = QRect(point, point, size - 2*point, size - 2*point)
         self._dPen = QPen(QtTransparent)
         self._dBrush = QBrush(QtTransparent)
-        self.setColours(
+        self.setColors(
             track=self.palette().alternateBase().color(),
             bar=self.palette().highlight().color(),
             text=self.palette().text().color()
@@ -66,8 +66,10 @@ class NProgressCircle(QProgressBar):
         self.setFixedHeight(size)
         return
 
-    def setColours(self, back: QColor | None = None, track: QColor | None = None,
-                   bar: QColor | None = None, text: QColor | None = None) -> None:
+    def setColors(
+        self, back: QColor | None = None, track: QColor | None = None,
+        bar: QColor | None = None, text: QColor | None = None
+    ) -> None:
         """Set the colours of the widget."""
         if isinstance(back, QColor):
             self._dPen = QPen(back)
