@@ -29,21 +29,25 @@ import re
 import xml.etree.ElementTree as ET
 
 from datetime import datetime
-from pathlib import Path
-from typing import NamedTuple
+from typing import TYPE_CHECKING, NamedTuple
 from zipfile import ZIP_DEFLATED, ZipFile
 
-from PyQt5.QtCore import QMargins, QSize
-from PyQt5.QtGui import QColor
+from PyQt6.QtCore import QMargins, QSize
 
 from novelwriter import __version__
 from novelwriter.common import firstFloat, xmlElement, xmlSubElem
 from novelwriter.constants import nwHeadFmt, nwStyles
-from novelwriter.core.project import NWProject
-from novelwriter.formats.shared import BlockFmt, BlockTyp, T_Formats, TextFmt
+from novelwriter.formats.shared import BlockFmt, BlockTyp, T_Formats, TextFmt, stripEscape
 from novelwriter.formats.tokenizer import Tokenizer
 from novelwriter.types import QtHexRgb
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from PyQt6.QtGui import QColor
+
+    from novelwriter.core.project import NWProject
+
 logger = logging.getLogger(__name__)
 
 # RegEx
@@ -212,9 +216,9 @@ class ToDocX(Tokenizer):
         self._pageMargins = QMargins(_mmToSz(left), _mmToSz(top), _mmToSz(right), _mmToSz(bottom))
         return
 
-    def setHeaderFormat(self, format: str, offset: int) -> None:
+    def setHeaderFormat(self, value: str, offset: int) -> None:
         """Set the document header format."""
-        self._headerFormat = format.strip()
+        self._headerFormat = value.strip()
         self._pageOffset = offset
         return
 
@@ -476,7 +480,7 @@ class ToDocX(Tokenizer):
             xmlSubElem(rPr, _wTag("color"), attrib={W_VAL: _docXCol(color)})
 
         if isinstance(text, str):
-            for segment in RX_TEXT.split(text):
+            for segment in RX_TEXT.split(stripEscape(text)):
                 if segment == "\n":
                     xmlSubElem(xR, _wTag("br"))
                 elif segment == "\t":
@@ -1052,9 +1056,9 @@ class ToDocX(Tokenizer):
 class DocXParagraph:
 
     __slots__ = (
-        "_content", "_style", "_textAlign",
-        "_topMargin", "_bottomMargin", "_leftMargin", "_rightMargin",
-        "_indentFirst", "_breakBefore", "_breakAfter", "_footnoteRef",
+        "_bottomMargin", "_breakAfter", "_breakBefore", "_content",
+        "_footnoteRef", "_indentFirst", "_leftMargin", "_rightMargin",
+        "_style", "_textAlign", "_topMargin",
     )
 
     def __init__(self) -> None:
