@@ -25,26 +25,31 @@ from __future__ import annotations
 
 import logging
 
-from pathlib import Path
+from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import QMarginsF, QSizeF
-from PyQt5.QtGui import (
-    QColor, QFont, QFontDatabase, QPageSize, QTextBlockFormat, QTextCharFormat,
-    QTextCursor, QTextDocument, QTextFrameFormat
+from PyQt6.QtCore import QMarginsF, QSizeF
+from PyQt6.QtGui import (
+    QColor, QFont, QFontDatabase, QPageLayout, QPageSize, QTextBlockFormat,
+    QTextCharFormat, QTextCursor, QTextDocument, QTextFrameFormat
 )
-from PyQt5.QtPrintSupport import QPrinter
+from PyQt6.QtPrintSupport import QPrinter
 
 from novelwriter import __version__
 from novelwriter.constants import nwStyles, nwUnicode
-from novelwriter.core.project import NWProject
-from novelwriter.formats.shared import BlockFmt, BlockTyp, T_Formats, TextFmt
+from novelwriter.formats.shared import BlockFmt, BlockTyp, T_Formats, TextFmt, stripEscape
 from novelwriter.formats.tokenizer import HEADINGS, Tokenizer
 from novelwriter.types import (
     QtAlignAbsolute, QtAlignCenter, QtAlignJustify, QtAlignLeft, QtAlignRight,
-    QtKeepAnchor, QtMoveAnchor, QtPageBreakAfter, QtPageBreakBefore,
-    QtPropLineHeight, QtTransparent, QtVAlignNormal, QtVAlignSub, QtVAlignSuper
+    QtKeepAnchor, QtMoveAnchor, QtPageBreakAfter, QtPageBreakAuto,
+    QtPageBreakBefore, QtPropLineHeight, QtTransparent, QtVAlignNormal,
+    QtVAlignSub, QtVAlignSuper
 )
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from novelwriter.core.project import NWProject
+
 logger = logging.getLogger(__name__)
 
 T_TextStyle = tuple[QTextBlockFormat, QTextCharFormat]
@@ -129,10 +134,9 @@ class ToQTextDocument(Tokenizer):
         super().initDocument()
 
         if pdf:
-            fontDB = QFontDatabase()
             family = self._textFont.family()
             style = self._textFont.styleName()
-            self._dpi = 1200 if fontDB.isScalable(family, style) else 72
+            self._dpi = 1200 if QFontDatabase.isScalable(family, style) else 72
 
         self._document.setUndoRedoEnabled(False)
         self._document.blockSignals(True)
@@ -250,8 +254,10 @@ class ToQTextDocument(Tokenizer):
 
             elif tType in HEADINGS:
                 bFmt, cFmt = self._genHeadStyle(tType, tMeta, bFmt)
-                newBlock(cursor, bFmt)
-                cursor.insertText(tText, cFmt)
+                for tPart in tText.split("\n"):
+                    newBlock(cursor, bFmt)
+                    cursor.insertText(tPart, cFmt)
+                    bFmt.setPageBreakPolicy(QtPageBreakAuto)
 
             elif tType == BlockTyp.SEP:
                 newBlock(cursor, bFmt)
@@ -270,7 +276,6 @@ class ToQTextDocument(Tokenizer):
 
     def saveDocument(self, path: Path) -> None:
         """Save the document as a PDF file."""
-        m = self._pageMargins
         logger.info("Writing PDF at %d DPI", self._dpi)
 
         printer = QPrinter(QPrinter.PrinterMode.HighResolution)
@@ -279,11 +284,13 @@ class ToQTextDocument(Tokenizer):
         printer.setResolution(self._dpi)
         printer.setOutputFormat(QPrinter.OutputFormat.PdfFormat)
         printer.setPageSize(self._pageSize)
-        printer.setPageMargins(m.left(), m.top(), m.right(), m.bottom(), QPrinter.Unit.Millimeter)
+        printer.setPageMargins(self._pageMargins, QPageLayout.Unit.Millimeter)
         printer.setOutputFileName(str(path))
 
-        self._document.documentLayout().setPaintDevice(printer)
-        self._document.setPageSize(QSizeF(printer.pageRect().size()))
+        if layout := self._document.documentLayout():
+            layout.setPaintDevice(printer)
+
+        self._document.setPageSize(printer.pageRect(QPrinter.Unit.DevicePixel).size())
         self._document.print(printer)
 
         return
@@ -339,7 +346,7 @@ class ToQTextDocument(Tokenizer):
         for pos, fmt, data in tFmt:
 
             # Insert buffer with previous format
-            cursor.insertText(temp[start:pos], cFmt)
+            cursor.insertText(stripEscape(temp[start:pos]), cFmt)
 
             # Construct next format
             if fmt == TextFmt.B_B:
@@ -421,13 +428,12 @@ class ToQTextDocument(Tokenizer):
                 if field := data.partition(":")[2]:
                     self._usedFields.append((cursor.position(), field))
                     cursor.insertText("0", cFmt)
-                pass
 
             # Move pos for next pass
             start = pos
 
         # Insert whatever is left in the buffer
-        cursor.insertText(temp[start:], cFmt)
+        cursor.insertText(stripEscape(temp[start:]), cFmt)
 
         return
 
@@ -462,7 +468,8 @@ class ToQTextDocument(Tokenizer):
             cursor.insertFrame(fFmt)
             cursor.setBlockFormat(bFmt)
             cursor.insertText(self._project.localLookup("New Page"), cFmt)
-            cursor.swap(self._document.rootFrame().lastCursorPosition())
+            if root := self._document.rootFrame():
+                cursor.swap(root.lastCursorPosition())
 
         return
 
