@@ -30,22 +30,22 @@ import logging
 
 from enum import Enum
 
-from PyQt5.QtCore import QPoint, Qt, QUrl, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import (
+from PyQt6.QtCore import QPoint, Qt, QUrl, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import (
     QCursor, QDesktopServices, QDragEnterEvent, QDragMoveEvent, QDropEvent,
     QMouseEvent, QPalette, QResizeEvent, QTextCursor
 )
-from PyQt5.QtWidgets import (
-    QAction, QApplication, QFrame, QHBoxLayout, QMenu, QTextBrowser,
-    QToolButton, QWidget
+from PyQt6.QtWidgets import (
+    QApplication, QFrame, QHBoxLayout, QMenu, QTextBrowser, QToolButton,
+    QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import decodeMimeHandles, qtLambda
+from novelwriter.common import decodeMimeHandles, qtAddAction, qtLambda
 from novelwriter.constants import nwConst, nwStyles, nwUnicode
-from novelwriter.enum import nwChange, nwDocAction, nwDocMode, nwItemType
+from novelwriter.enum import nwChange, nwComment, nwDocAction, nwDocMode, nwItemType
 from novelwriter.error import logException
-from novelwriter.extensions.configlayout import NColourLabel
+from novelwriter.extensions.configlayout import NColorLabel
 from novelwriter.extensions.eventfilters import WheelEventFilter
 from novelwriter.extensions.modified import NIconToolButton
 from novelwriter.formats.shared import TextDocumentTheme
@@ -79,7 +79,7 @@ class GuiDocViewer(QTextBrowser):
         self._docTheme = TextDocumentTheme()
 
         # Settings
-        self.setMinimumWidth(CONFIG.pxInt(300))
+        self.setMinimumWidth(300)
         self.setAutoFillBackground(True)
         self.setOpenLinks(False)
         self.setOpenExternalLinks(False)
@@ -124,8 +124,7 @@ class GuiDocViewer(QTextBrowser):
     @property
     def scrollPosition(self) -> int:
         """Return the scrollbar position."""
-        vBar = self.verticalScrollBar()
-        if vBar.isVisible():
+        if (vBar := self.verticalScrollBar()) and vBar.isVisible():
             return vBar.value()
         return 0
 
@@ -155,36 +154,40 @@ class GuiDocViewer(QTextBrowser):
         self.docFooter.updateFont()
 
         # Set the widget colours to match syntax theme
-        mainPalette = self.palette()
-        mainPalette.setColor(QPalette.ColorRole.Window, SHARED.theme.colBack)
-        mainPalette.setColor(QPalette.ColorRole.Base, SHARED.theme.colBack)
-        mainPalette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
-        self.setPalette(mainPalette)
+        syntax = SHARED.theme.syntaxTheme
 
-        docPalette = self.viewport().palette()
-        docPalette.setColor(QPalette.ColorRole.Base, SHARED.theme.colBack)
-        docPalette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
-        self.viewport().setPalette(docPalette)
-        self.docHeader.matchColours()
-        self.docFooter.matchColours()
+        palette = self.palette()
+        palette.setColor(QPalette.ColorRole.Window, syntax.back)
+        palette.setColor(QPalette.ColorRole.Base, syntax.back)
+        palette.setColor(QPalette.ColorRole.Text, syntax.text)
+        self.setPalette(palette)
+
+        if viewport := self.viewport():
+            palette = viewport.palette()
+            palette.setColor(QPalette.ColorRole.Base, syntax.back)
+            palette.setColor(QPalette.ColorRole.Text, syntax.text)
+            viewport.setPalette(palette)
+            self.docHeader.matchColors()
+            self.docFooter.matchColors()
 
         # Update theme colours
-        self._docTheme.text      = SHARED.theme.colText
-        self._docTheme.highlight = SHARED.theme.colMark
-        self._docTheme.head      = SHARED.theme.colHead
-        self._docTheme.link      = SHARED.theme.colLink
-        self._docTheme.comment   = SHARED.theme.colHidden
-        self._docTheme.note      = SHARED.theme.colNote
-        self._docTheme.code      = SHARED.theme.colCode
-        self._docTheme.modifier  = SHARED.theme.colMod
-        self._docTheme.keyword   = SHARED.theme.colKey
-        self._docTheme.tag       = SHARED.theme.colTag
-        self._docTheme.optional  = SHARED.theme.colOpt
-        self._docTheme.dialog    = SHARED.theme.colDialN
-        self._docTheme.altdialog = SHARED.theme.colDialA
+        self._docTheme.text      = syntax.text
+        self._docTheme.highlight = syntax.mark
+        self._docTheme.head      = syntax.head
+        self._docTheme.link      = syntax.link
+        self._docTheme.comment   = syntax.hidden
+        self._docTheme.note      = syntax.note
+        self._docTheme.code      = syntax.code
+        self._docTheme.modifier  = syntax.mod
+        self._docTheme.keyword   = syntax.key
+        self._docTheme.tag       = syntax.tag
+        self._docTheme.optional  = syntax.opt
+        self._docTheme.dialog    = syntax.dialN
+        self._docTheme.altdialog = syntax.dialA
 
         # Set default text margins
-        self.document().setDocumentMargin(0)
+        if document := self.document():
+            document.setDocumentMargin(0)
 
         # Scroll bars
         if CONFIG.hideVScroll:
@@ -198,7 +201,7 @@ class GuiDocViewer(QTextBrowser):
             self.setHorizontalScrollBarPolicy(QtScrollAsNeeded)
 
         # Refresh the tab stops
-        self.setTabStopDistance(CONFIG.getTabWidth())
+        self.setTabStopDistance(CONFIG.tabWidth)
 
         # If we have a document open, we should reload it in case the font changed
         self.reloadText()
@@ -215,7 +218,9 @@ class GuiDocViewer(QTextBrowser):
         logger.debug("Generating preview for item '%s'", tHandle)
         QApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
 
-        sPos = self.verticalScrollBar().value()
+        vBar = self.verticalScrollBar()
+        sPos = vBar.value() if vBar else 0
+
         qDoc = ToQTextDocument(SHARED.project)
         qDoc.setJustify(CONFIG.doJustify)
         qDoc.setDialogHighlight(True)
@@ -223,8 +228,11 @@ class GuiDocViewer(QTextBrowser):
         qDoc.setTheme(self._docTheme)
         qDoc.initDocument()
         qDoc.setKeywords(True)
-        qDoc.setComments(CONFIG.viewComments)
-        qDoc.setSynopsis(CONFIG.viewSynopsis)
+        qDoc.setCommentType(nwComment.NOTE, CONFIG.viewComments)
+        qDoc.setCommentType(nwComment.STORY, CONFIG.viewComments)
+        qDoc.setCommentType(nwComment.PLAIN, CONFIG.viewComments)
+        qDoc.setCommentType(nwComment.SYNOPSIS, CONFIG.viewSynopsis)
+        qDoc.setCommentType(nwComment.SHORT, CONFIG.viewSynopsis)
 
         # Be extra careful here to prevent crashes when first opening a
         # project as a crash here leaves no way of recovering.
@@ -248,11 +256,11 @@ class GuiDocViewer(QTextBrowser):
 
         self.setDocumentTitle(tHandle)
         self.setDocument(qDoc.document)
-        self.setTabStopDistance(CONFIG.getTabWidth())
+        self.setTabStopDistance(CONFIG.tabWidth)
 
-        if self._docHandle == tHandle:
+        if self._docHandle == tHandle and vBar:
             # This is a refresh, so we set the scrollbar back to where it was
-            self.verticalScrollBar().setValue(sPos)
+            vBar.setValue(sPos)
 
         self._docHandle = tHandle
         SHARED.project.data.setLastHandle(tHandle, "viewer")
@@ -306,13 +314,13 @@ class GuiDocViewer(QTextBrowser):
         """Automatically adjust the margins so the text is centred."""
         wW = self.width()
         wH = self.height()
-        cM = CONFIG.getTextMargin()
+        cM = CONFIG.textMargin
 
         vBar = self.verticalScrollBar()
-        sW = vBar.width() if vBar.isVisible() else 0
+        sW = vBar.width() if vBar and vBar.isVisible() else 0
 
         hBar = self.horizontalScrollBar()
-        sH = hBar.height() if hBar.isVisible() else 0
+        sH = hBar.height() if hBar and hBar.isVisible() else 0
 
         tM = cM
         if CONFIG.textWidth > 0:
@@ -337,8 +345,7 @@ class GuiDocViewer(QTextBrowser):
 
     def setScrollPosition(self, pos: int) -> None:
         """Set the scrollbar position."""
-        vBar = self.verticalScrollBar()
-        if vBar.isVisible():
+        if (vBar := self.verticalScrollBar()) and vBar.isVisible():
             vBar.setValue(pos)
         return
 
@@ -400,30 +407,27 @@ class GuiDocViewer(QTextBrowser):
         ctxMenu = QMenu(self)
 
         if userSelection:
-            mnuCopy = QAction(self.tr("Copy"), ctxMenu)
-            mnuCopy.triggered.connect(qtLambda(self.docAction, nwDocAction.COPY))
-            ctxMenu.addAction(mnuCopy)
-
+            action = qtAddAction(ctxMenu, self.tr("Copy"))
+            action.triggered.connect(qtLambda(self.docAction, nwDocAction.COPY))
             ctxMenu.addSeparator()
 
-        mnuSelAll = QAction(self.tr("Select All"), ctxMenu)
-        mnuSelAll.triggered.connect(qtLambda(self.docAction, nwDocAction.SEL_ALL))
-        ctxMenu.addAction(mnuSelAll)
+        action = qtAddAction(ctxMenu, self.tr("Select All"))
+        action.triggered.connect(qtLambda(self.docAction, nwDocAction.SEL_ALL))
 
-        mnuSelWord = QAction(self.tr("Select Word"), ctxMenu)
-        mnuSelWord.triggered.connect(qtLambda(
+        action = qtAddAction(ctxMenu, self.tr("Select Word"))
+        action.triggered.connect(qtLambda(
             self._makePosSelection, QTextCursor.SelectionType.WordUnderCursor, point
         ))
-        ctxMenu.addAction(mnuSelWord)
 
-        mnuSelPara = QAction(self.tr("Select Paragraph"), ctxMenu)
-        mnuSelPara.triggered.connect(qtLambda(
+        action = qtAddAction(ctxMenu, self.tr("Select Paragraph"))
+        action.triggered.connect(qtLambda(
             self._makePosSelection, QTextCursor.SelectionType.BlockUnderCursor, point
         ))
-        ctxMenu.addAction(mnuSelPara)
 
         # Open the context menu
-        ctxMenu.exec(self.viewport().mapToGlobal(point))
+        if viewport := self.viewport():
+            ctxMenu.exec(viewport.mapToGlobal(point))
+
         ctxMenu.setParent(None)
 
         return
@@ -450,7 +454,7 @@ class GuiDocViewer(QTextBrowser):
 
     def dragEnterEvent(self, event: QDragEnterEvent) -> None:
         """Overload drag enter event to handle dragged items."""
-        if event.mimeData().hasFormat(nwConst.MIME_HANDLE):
+        if (data := event.mimeData()) and data.hasFormat(nwConst.MIME_HANDLE):
             event.acceptProposedAction()
         else:
             super().dragEnterEvent(event)
@@ -458,7 +462,7 @@ class GuiDocViewer(QTextBrowser):
 
     def dragMoveEvent(self, event: QDragMoveEvent) -> None:
         """Overload drag move event to handle dragged items."""
-        if event.mimeData().hasFormat(nwConst.MIME_HANDLE):
+        if (data := event.mimeData()) and data.hasFormat(nwConst.MIME_HANDLE):
             event.acceptProposedAction()
         else:
             super().dragMoveEvent(event)
@@ -466,8 +470,8 @@ class GuiDocViewer(QTextBrowser):
 
     def dropEvent(self, event: QDropEvent) -> None:
         """Overload drop event to handle dragged items."""
-        if event.mimeData().hasFormat(nwConst.MIME_HANDLE):
-            if handles := decodeMimeHandles(event.mimeData()):
+        if (data := event.mimeData()) and data.hasFormat(nwConst.MIME_HANDLE):
+            if handles := decodeMimeHandles(data):
                 if SHARED.project.tree.checkType(handles[0], nwItemType.FILE):
                     self.openDocumentRequest.emit(handles[0], nwDocMode.VIEW, "", True)
         else:
@@ -609,12 +613,9 @@ class GuiDocViewHistory:
         for loop, it is skipped entirely if log level isn't DEBUG.
         """
         if CONFIG.isDebug:  # pragma: no cover
-            for i, (h, p) in enumerate(zip(self._navHistory, self._posHistory)):
-                logger.debug(
-                    "History %02d: %s %13s [x:%d]" % (
-                        i + 1, ">" if i == self._currPos else " ", h, p
-                    )
-                )
+            for i, (h, p) in enumerate(zip(self._navHistory, self._posHistory, strict=False)):
+                a = ">" if i == self._currPos else " "
+                logger.debug(f"History {i + 1:02d}: {a} {h:13s} [x:{p}]")
         return
 
 
@@ -638,13 +639,12 @@ class GuiDocViewHeader(QWidget):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        mPx = CONFIG.pxInt(4)
 
         # Main Widget Settings
         self.setAutoFillBackground(True)
 
         # Title Label
-        self.itemTitle = NColourLabel("", self, faded=SHARED.theme.fadedText)
+        self.itemTitle = NColorLabel("", self, faded=SHARED.theme.fadedText)
         self.itemTitle.setMargin(0)
         self.itemTitle.setContentsMargins(0, 0, 0, 0)
         self.itemTitle.setAutoFillBackground(True)
@@ -690,9 +690,9 @@ class GuiDocViewHeader(QWidget):
         self.outerBox.addWidget(self.outlineButton, 0)
         self.outerBox.addWidget(self.backButton, 0)
         self.outerBox.addWidget(self.forwardButton, 0)
-        self.outerBox.addSpacing(mPx)
+        self.outerBox.addSpacing(4)
         self.outerBox.addWidget(self.itemTitle, 1)
-        self.outerBox.addSpacing(mPx)
+        self.outerBox.addSpacing(4)
         self.outerBox.addWidget(self.editButton, 0)
         self.outerBox.addWidget(self.refreshButton, 0)
         self.outerBox.addWidget(self.closeButton, 0)
@@ -703,8 +703,8 @@ class GuiDocViewHeader(QWidget):
         # Fix Margins and Size
         # This is needed for high DPI systems. See issue #499.
         self.setContentsMargins(0, 0, 0, 0)
-        self.outerBox.setContentsMargins(mPx, mPx, mPx, mPx)
-        self.setMinimumHeight(iPx + 2*mPx)
+        self.outerBox.setContentsMargins(4, 4, 4, 4)
+        self.setMinimumHeight(iPx + 8)
 
         self.updateFont()
         self.updateTheme()
@@ -745,7 +745,7 @@ class GuiDocViewHeader(QWidget):
                     minLevel = min(minLevel, level)
             for title, text, level in entries[:30]:
                 indent = "    "*(level - minLevel)
-                action = self.outlineMenu.addAction(f"{indent}{text}")
+                action = qtAddAction(self.outlineMenu, f"{indent}{text}")
                 action.triggered.connect(
                     lambda _, title=title: self.docViewer.navigateTo(f"#{tHandle}:{title}")
                 )
@@ -760,12 +760,12 @@ class GuiDocViewHeader(QWidget):
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        self.outlineButton.setThemeIcon("list")
-        self.backButton.setThemeIcon("backward")
-        self.forwardButton.setThemeIcon("forward")
-        self.editButton.setThemeIcon("edit")
-        self.refreshButton.setThemeIcon("refresh")
-        self.closeButton.setThemeIcon("close")
+        self.outlineButton.setThemeIcon("list", "blue")
+        self.backButton.setThemeIcon("chevron_left", "blue")
+        self.forwardButton.setThemeIcon("chevron_right", "blue")
+        self.editButton.setThemeIcon("edit", "green")
+        self.refreshButton.setThemeIcon("refresh", "green")
+        self.closeButton.setThemeIcon("close", "red")
 
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.outlineButton.setStyleSheet(buttonStyle)
@@ -775,18 +775,19 @@ class GuiDocViewHeader(QWidget):
         self.refreshButton.setStyleSheet(buttonStyle)
         self.closeButton.setStyleSheet(buttonStyle)
 
-        self.matchColours()
+        self.matchColors()
 
         return
 
-    def matchColours(self) -> None:
+    def matchColors(self) -> None:
         """Update the colours of the widget to match those of the syntax
         theme rather than the main GUI.
         """
-        palette = QPalette()
-        palette.setColor(QPalette.ColorRole.Window, SHARED.theme.colBack)
-        palette.setColor(QPalette.ColorRole.WindowText, SHARED.theme.colText)
-        palette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
+        syntax = SHARED.theme.syntaxTheme
+        palette = self.palette()
+        palette.setColor(QPalette.ColorRole.Window, syntax.back)
+        palette.setColor(QPalette.ColorRole.WindowText, syntax.text)
+        palette.setColor(QPalette.ColorRole.Text, syntax.text)
         self.setPalette(palette)
         self.itemTitle.setTextColors(
             color=palette.windowText().color(), faded=SHARED.theme.fadedText
@@ -882,8 +883,6 @@ class GuiDocViewFooter(QWidget):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        hSp = CONFIG.pxInt(4)
-        mPx = CONFIG.pxInt(4)
 
         # Main Widget Settings
         self.setContentsMargins(0, 0, 0, 0)
@@ -920,14 +919,14 @@ class GuiDocViewFooter(QWidget):
         self.outerBox.addStretch(1)
         self.outerBox.addWidget(self.showComments, 0)
         self.outerBox.addWidget(self.showSynopsis, 0)
-        self.outerBox.setSpacing(hSp)
+        self.outerBox.setSpacing(4)
         self.setLayout(self.outerBox)
 
         # Fix Margins and Size
         # This is needed for high DPI systems. See issue #499.
         self.setContentsMargins(0, 0, 0, 0)
-        self.outerBox.setContentsMargins(mPx, mPx, mPx, mPx)
-        self.setMinimumHeight(iPx + 2*mPx)
+        self.outerBox.setContentsMargins(4, 4, 4, 4)
+        self.setMinimumHeight(iPx + 8)
 
         self.updateFont()
         self.updateTheme()
@@ -951,7 +950,7 @@ class GuiDocViewFooter(QWidget):
         """Update theme elements."""
         # Icons
         fPx = int(0.9*SHARED.theme.fontPixelSize)
-        bulletIcon = SHARED.theme.getToggleIcon("bullet", (fPx, fPx))
+        bulletIcon = SHARED.theme.getToggleIcon("bullet", (fPx, fPx), "blue")
 
         self.showHide.setThemeIcon("panel")
         self.showComments.setIcon(bulletIcon)
@@ -962,18 +961,19 @@ class GuiDocViewFooter(QWidget):
         self.showComments.setStyleSheet(buttonStyle)
         self.showSynopsis.setStyleSheet(buttonStyle)
 
-        self.matchColours()
+        self.matchColors()
 
         return
 
-    def matchColours(self) -> None:
+    def matchColors(self) -> None:
         """Update the colours of the widget to match those of the syntax
         theme rather than the main GUI.
         """
-        palette = QPalette()
-        palette.setColor(QPalette.ColorRole.Window, SHARED.theme.colBack)
-        palette.setColor(QPalette.ColorRole.WindowText, SHARED.theme.colText)
-        palette.setColor(QPalette.ColorRole.Text, SHARED.theme.colText)
+        syntax = SHARED.theme.syntaxTheme
+        palette = self.palette()
+        palette.setColor(QPalette.ColorRole.Window, syntax.back)
+        palette.setColor(QPalette.ColorRole.WindowText, syntax.text)
+        palette.setColor(QPalette.ColorRole.Text, syntax.text)
         self.setPalette(palette)
         return
 
