@@ -26,22 +26,25 @@ from __future__ import annotations
 import logging
 
 from enum import Enum
+from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import QModelIndex, Qt, pyqtSignal, pyqtSlot
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import QModelIndex, Qt, pyqtSignal, pyqtSlot
+from PyQt6.QtWidgets import (
     QAbstractItemView, QFrame, QMenu, QTabWidget, QToolButton, QTreeWidget,
     QTreeWidgetItem, QVBoxLayout, QWidget
 )
 
-from novelwriter import CONFIG, SHARED
-from novelwriter.common import checkInt
+from novelwriter import SHARED
+from novelwriter.common import checkInt, qtAddAction
 from novelwriter.constants import nwLabels, nwLists, nwStyles, trConst
-from novelwriter.core.index import IndexHeading, IndexItem
 from novelwriter.enum import nwChange, nwDocMode, nwItemClass
 from novelwriter.extensions.modified import NIconToolButton
 from novelwriter.gui.theme import STYLES_FLAT_TABS, STYLES_MIN_TOOLBUTTON
 from novelwriter.types import QtDecoration, QtHeaderFixed, QtHeaderToContents, QtUserRole
 
+if TYPE_CHECKING:
+    from novelwriter.core.indexdata import IndexHeading, IndexNode
+
 logger = logging.getLogger(__name__)
 
 
@@ -63,7 +66,7 @@ class GuiDocViewerPanel(QWidget):
 
         self.optsMenu = QMenu(self)
 
-        self.aInactive = self.optsMenu.addAction(self.tr("Hide Inactive Tags"))
+        self.aInactive = qtAddAction(self.optsMenu, self.tr("Hide Inactive Tags"))
         self.aInactive.setCheckable(True)
         self.aInactive.toggled.connect(self._toggleHideInactive)
 
@@ -101,14 +104,15 @@ class GuiDocViewerPanel(QWidget):
 
     def updateTheme(self, updateTabs: bool = True) -> None:
         """Update theme elements."""
-        self.optsButton.setThemeIcon("menu")
+        self.optsButton.setThemeIcon("more_vertical")
         self.optsButton.setStyleSheet(SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON))
         self.mainTabs.setStyleSheet(SHARED.theme.getStyleSheet(STYLES_FLAT_TABS))
-        self.updateHandle(self._lastHandle)
         if updateTabs:
             self.tabBackRefs.updateTheme()
+            self.tabBackRefs.refreshContent(self._lastHandle)
             for tab in self.kwTabs.values():
                 tab.updateTheme()
+            self._loadAllTags()
         return
 
     def openProjectTasks(self) -> None:
@@ -247,7 +251,6 @@ class _ViewPanelBackRefs(QTreeWidget):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        cMg = CONFIG.pxInt(6)
 
         self.setHeaderLabels([self.tr("Document"), "", "", self.tr("First Heading")])
         self.setIndentation(0)
@@ -256,20 +259,20 @@ class _ViewPanelBackRefs(QTreeWidget):
         self.setFrameStyle(QFrame.Shape.NoFrame)
 
         # Set Header Sizes
-        treeHeader = self.header()
-        treeHeader.setStretchLastSection(True)
-        treeHeader.setMinimumSectionSize(iPx + cMg)  # See Issue #1627
-        treeHeader.setSectionResizeMode(self.C_DOC, QtHeaderToContents)
-        treeHeader.setSectionResizeMode(self.C_EDIT, QtHeaderFixed)
-        treeHeader.setSectionResizeMode(self.C_VIEW, QtHeaderFixed)
-        treeHeader.setSectionResizeMode(self.C_TITLE, QtHeaderToContents)
-        treeHeader.resizeSection(self.C_EDIT, iPx + cMg)
-        treeHeader.resizeSection(self.C_VIEW, iPx + cMg)
-        treeHeader.setSectionsMovable(False)
+        if header := self.header():
+            header.setStretchLastSection(True)
+            header.setMinimumSectionSize(iPx + 6)  # See Issue #1627
+            header.setSectionResizeMode(self.C_DOC, QtHeaderToContents)
+            header.setSectionResizeMode(self.C_EDIT, QtHeaderFixed)
+            header.setSectionResizeMode(self.C_VIEW, QtHeaderFixed)
+            header.setSectionResizeMode(self.C_TITLE, QtHeaderToContents)
+            header.resizeSection(self.C_EDIT, iPx + 6)
+            header.resizeSection(self.C_VIEW, iPx + 6)
+            header.setSectionsMovable(False)
 
         # Cache Icons Locally
-        self._editIcon = SHARED.theme.getIcon("edit")
-        self._viewIcon = SHARED.theme.getIcon("view")
+        self._editIcon = SHARED.theme.getIcon("edit", "green")
+        self._viewIcon = SHARED.theme.getIcon("view", "blue")
 
         # Signals
         self.clicked.connect(self._treeItemClicked)
@@ -279,8 +282,8 @@ class _ViewPanelBackRefs(QTreeWidget):
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        self._editIcon = SHARED.theme.getIcon("edit")
-        self._viewIcon = SHARED.theme.getIcon("view")
+        self._editIcon = SHARED.theme.getIcon("edit", "green")
+        self._viewIcon = SHARED.theme.getIcon("view", "blue")
         for i in range(self.topLevelItemCount()):
             if item := self.topLevelItem(i):
                 item.setIcon(self.C_EDIT, self._editIcon)
@@ -384,7 +387,6 @@ class _ViewPanelKeyWords(QTreeWidget):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        cMg = CONFIG.pxInt(6)
 
         self.setHeaderLabels([
             self.tr("Tag"), "", "", self.tr("Importance"), self.tr("Document"),
@@ -400,19 +402,17 @@ class _ViewPanelKeyWords(QTreeWidget):
         self.sortByColumn(self.C_NAME, Qt.SortOrder.AscendingOrder)
 
         # Set Header Sizes
-        treeHeader = self.header()
-        treeHeader.setStretchLastSection(True)
-        treeHeader.setMinimumSectionSize(iPx + cMg)  # See Issue #1627
-        treeHeader.setSectionResizeMode(self.C_EDIT, QtHeaderFixed)
-        treeHeader.setSectionResizeMode(self.C_VIEW, QtHeaderFixed)
-        treeHeader.resizeSection(self.C_EDIT, iPx + cMg)
-        treeHeader.resizeSection(self.C_VIEW, iPx + cMg)
-        treeHeader.setSectionsMovable(False)
+        if header := self.header():
+            header.setStretchLastSection(True)
+            header.setMinimumSectionSize(iPx + 6)  # See Issue #1627
+            header.setSectionResizeMode(self.C_EDIT, QtHeaderFixed)
+            header.setSectionResizeMode(self.C_VIEW, QtHeaderFixed)
+            header.resizeSection(self.C_EDIT, iPx + 6)
+            header.resizeSection(self.C_VIEW, iPx + 6)
+            header.setSectionsMovable(False)
 
         # Cache Icons Locally
-        self._classIcon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[itemClass])
-        self._editIcon = SHARED.theme.getIcon("edit")
-        self._viewIcon = SHARED.theme.getIcon("view")
+        self.updateTheme()
 
         # Signals
         self.clicked.connect(self._treeItemClicked)
@@ -422,13 +422,9 @@ class _ViewPanelKeyWords(QTreeWidget):
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        self._classIcon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[self._class])
-        self._editIcon = SHARED.theme.getIcon("edit")
-        self._viewIcon = SHARED.theme.getIcon("view")
-        for i in range(self.topLevelItemCount()):
-            if item := self.topLevelItem(i):
-                item.setIcon(self.C_EDIT, self._editIcon)
-                item.setIcon(self.C_VIEW, self._viewIcon)
+        self._classIcon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[self._class], "root")
+        self._editIcon = SHARED.theme.getIcon("edit", "green")
+        self._viewIcon = SHARED.theme.getIcon("view", "blue")
         return
 
     def countEntries(self) -> int:
@@ -441,7 +437,7 @@ class _ViewPanelKeyWords(QTreeWidget):
         self.clear()
         return
 
-    def addUpdateEntry(self, tag: str, name: str, iItem: IndexItem, hItem: IndexHeading) -> None:
+    def addUpdateEntry(self, tag: str, name: str, iItem: IndexNode, hItem: IndexHeading) -> None:
         """Add a new entry, or update an existing one."""
         nwItem = iItem.item
         impLabel, impIcon = nwItem.getImportStatus()
@@ -487,19 +483,19 @@ class _ViewPanelKeyWords(QTreeWidget):
     def setColumnWidths(self, widths: list[int]) -> None:
         """Set the column widths."""
         if isinstance(widths, list) and len(widths) >= 4:
-            self.setColumnWidth(self.C_NAME, CONFIG.pxInt(checkInt(widths[0], 100)))
-            self.setColumnWidth(self.C_IMPORT, CONFIG.pxInt(checkInt(widths[1], 100)))
-            self.setColumnWidth(self.C_DOC, CONFIG.pxInt(checkInt(widths[2], 100)))
-            self.setColumnWidth(self.C_TITLE, CONFIG.pxInt(checkInt(widths[3], 100)))
+            self.setColumnWidth(self.C_NAME,   checkInt(widths[0], 100))
+            self.setColumnWidth(self.C_IMPORT, checkInt(widths[1], 100))
+            self.setColumnWidth(self.C_DOC,    checkInt(widths[2], 100))
+            self.setColumnWidth(self.C_TITLE,  checkInt(widths[3], 100))
         return
 
     def getColumnWidths(self) -> list[int]:
         """Get the widths of the user-adjustable columns."""
         return [
-            CONFIG.rpxInt(self.columnWidth(self.C_NAME)),
-            CONFIG.rpxInt(self.columnWidth(self.C_IMPORT)),
-            CONFIG.rpxInt(self.columnWidth(self.C_DOC)),
-            CONFIG.rpxInt(self.columnWidth(self.C_TITLE)),
+            self.columnWidth(self.C_NAME),
+            self.columnWidth(self.C_IMPORT),
+            self.columnWidth(self.C_DOC),
+            self.columnWidth(self.C_TITLE),
         ]
 
     ##
