@@ -27,10 +27,10 @@ import logging
 
 from enum import Enum
 
-from PyQt5.QtCore import pyqtSlot
-from PyQt5.QtWidgets import QGridLayout, QLabel, QWidget
+from PyQt6.QtCore import pyqtSlot
+from PyQt6.QtWidgets import QGridLayout, QLabel, QWidget
 
-from novelwriter import CONFIG, SHARED
+from novelwriter import SHARED
 from novelwriter.common import elide
 from novelwriter.constants import nwLabels, nwStats, trConst, trStats
 from novelwriter.enum import nwChange
@@ -53,9 +53,6 @@ class GuiItemDetails(QWidget):
         self._handle = None
 
         # Sizes
-        hSp = CONFIG.pxInt(6)
-        vSp = CONFIG.pxInt(1)
-        mPx = CONFIG.pxInt(6)
         fPt = SHARED.theme.fontPointSize
 
         fntLabel = self.font()
@@ -177,9 +174,9 @@ class GuiItemDetails(QWidget):
         self.mainBox.setColumnStretch(3, 0)
         self.mainBox.setColumnStretch(4, 0)
 
-        self.mainBox.setHorizontalSpacing(hSp)
-        self.mainBox.setVerticalSpacing(vSp)
-        self.mainBox.setContentsMargins(mPx, mPx, mPx, mPx)
+        self.mainBox.setHorizontalSpacing(6)
+        self.mainBox.setVerticalSpacing(1)
+        self.mainBox.setContentsMargins(6, 6, 6, 6)
 
         self.setLayout(self.mainBox)
 
@@ -231,18 +228,18 @@ class GuiItemDetails(QWidget):
             return
 
         self._handle = tHandle
-        iPx = int(round(0.9*SHARED.theme.baseIconHeight))
+        iPx = round(0.9*SHARED.theme.baseIconHeight)
 
         # Label
         # =====
 
         if nwItem.isFileType():
             if nwItem.isActive:
-                self.labelIcon.setPixmap(SHARED.theme.getPixmap("checked", (iPx, iPx)))
+                self.labelIcon.setPixmap(SHARED.theme.getPixmap("checked", (iPx, iPx), "green"))
             else:
-                self.labelIcon.setPixmap(SHARED.theme.getPixmap("unchecked", (iPx, iPx)))
+                self.labelIcon.setPixmap(SHARED.theme.getPixmap("unchecked", (iPx, iPx), "red"))
         else:
-            self.labelIcon.setPixmap(SHARED.theme.getPixmap("noncheckable", (iPx, iPx)))
+            self.labelIcon.setPixmap(SHARED.theme.getPixmap("noncheckable", (iPx, iPx), "faded"))
 
         self.labelData.setText(elide(nwItem.itemName, 100))
 
@@ -256,7 +253,7 @@ class GuiItemDetails(QWidget):
         # Class
         # =====
 
-        classIcon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[nwItem.itemClass])
+        classIcon = SHARED.theme.getIcon(nwLabels.CLASS_ICON[nwItem.itemClass], "root")
         self.classIcon.setPixmap(classIcon.pixmap(iPx, iPx))
         self.classData.setText(trConst(nwLabels.CLASS_NAME[nwItem.itemClass]))
 
