@@ -32,10 +32,12 @@ import logging
 
 from enum import Enum
 from time import time
+from typing import Final
 
-from PyQt5.QtCore import QT_TRANSLATE_NOOP, Qt, pyqtSignal, pyqtSlot
-from PyQt5.QtWidgets import (
-    QAbstractItemView, QAction, QFileDialog, QFrame, QGridLayout, QGroupBox,
+from PyQt6.QtCore import QT_TRANSLATE_NOOP, Qt, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QAction, QIcon
+from PyQt6.QtWidgets import (
+    QAbstractItemView, QFileDialog, QFrame, QGridLayout, QGroupBox,
     QHBoxLayout, QLabel, QMenu, QScrollArea, QSplitter, QToolBar, QToolButton,
     QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget
 )
@@ -45,7 +47,7 @@ from novelwriter.common import checkInt, formatFileFilter
 from novelwriter.constants import nwKeyWords, nwLabels, nwStats, nwStyles, trConst, trStats
 from novelwriter.enum import nwChange, nwDocMode, nwItemClass, nwItemLayout, nwItemType, nwOutline
 from novelwriter.error import logException
-from novelwriter.extensions.configlayout import NColourLabel
+from novelwriter.extensions.configlayout import NColorLabel
 from novelwriter.extensions.novelselector import NovelSelector
 from novelwriter.types import (
     QtAlignLeftTop, QtAlignRight, QtAlignRightTop, QtDecoration,
@@ -77,7 +79,7 @@ class GuiOutlineView(QWidget):
 
         # Assemble
         self.outerBox = QVBoxLayout()
-        self.outerBox.setContentsMargins(0, 0, CONFIG.pxInt(4), 0)
+        self.outerBox.setContentsMargins(0, 0, 4, 0)
         self.outerBox.addWidget(self.outlineBar)
         self.outerBox.addWidget(self.splitOutline)
 
@@ -103,7 +105,10 @@ class GuiOutlineView(QWidget):
     def updateTheme(self) -> None:
         """Update theme elements."""
         self.outlineBar.updateTheme()
-        self.refreshTree()
+        self.outlineTree.updateTheme()
+        self.outlineTree.refreshTree(
+            rootHandle=SHARED.project.data.getLastHandle("outline"), overRide=True
+        )
         return
 
     def initSettings(self) -> None:
@@ -218,14 +223,14 @@ class GuiOutlineToolBar(QToolBar):
         stretch.setSizePolicy(QtSizeExpanding, QtSizeExpanding)
 
         # Novel Selector
-        self.novelLabel = NColourLabel(
-            self.tr("Outline of"), self, scale=NColourLabel.HEADER_SCALE, bold=True
+        self.novelLabel = NColorLabel(
+            self.tr("Outline of"), self, scale=NColorLabel.HEADER_SCALE, bold=True
         )
-        self.novelLabel.setContentsMargins(0, 0, CONFIG.pxInt(12), 0)
+        self.novelLabel.setContentsMargins(0, 0, 12, 0)
 
         self.novelValue = NovelSelector(self)
         self.novelValue.setIncludeAll(True)
-        self.novelValue.setMinimumWidth(CONFIG.pxInt(200))
+        self.novelValue.setMinimumWidth(200)
         self.novelValue.novelSelectionChanged.connect(self._novelValueChanged)
 
         # Actions
@@ -268,9 +273,9 @@ class GuiOutlineToolBar(QToolBar):
         """Update theme elements."""
         self.setStyleSheet("QToolBar {border: 0px;}")
         self.novelValue.refreshNovelList()
-        self.aRefresh.setIcon(SHARED.theme.getIcon("refresh"))
-        self.aExport.setIcon(SHARED.theme.getIcon("export"))
-        self.tbColumns.setIcon(SHARED.theme.getIcon("menu"))
+        self.aRefresh.setIcon(SHARED.theme.getIcon("refresh", "green"))
+        self.aExport.setIcon(SHARED.theme.getIcon("export", "blue"))
+        self.tbColumns.setIcon(SHARED.theme.getIcon("more_vertical"))
         self.tbColumns.setStyleSheet("QToolButton::menu-indicator {image: none;}")
         self.novelLabel.setTextColors(color=self.palette().windowText().color())
         return
@@ -315,7 +320,7 @@ class GuiOutlineToolBar(QToolBar):
 
 class GuiOutlineTree(QTreeWidget):
 
-    DEF_WIDTH = {
+    DEF_WIDTH: Final[dict[nwOutline, int]] = {
         nwOutline.TITLE:   200,
         nwOutline.LEVEL:   40,
         nwOutline.LABEL:   150,
@@ -338,7 +343,7 @@ class GuiOutlineTree(QTreeWidget):
         nwOutline.SYNOP:   200,
     }
 
-    DEF_HIDDEN = {
+    DEF_HIDDEN: Final[dict[nwOutline, bool]] = {
         nwOutline.TITLE:   False,
         nwOutline.LEVEL:   True,
         nwOutline.LABEL:   False,
@@ -386,8 +391,8 @@ class GuiOutlineTree(QTreeWidget):
         self.setIconSize(SHARED.theme.baseIconSize)
         self.setIndentation(0)
 
-        self.treeHead = self.header()
-        self.treeHead.sectionMoved.connect(self._columnMoved)
+        if header := self.header():
+            header.sectionMoved.connect(self._columnMoved)
 
         # Pre-Generate Tree Formatting
         fH1 = self.font()
@@ -397,18 +402,8 @@ class GuiOutlineTree(QTreeWidget):
         fH2 = self.font()
         fH2.setBold(True)
 
-        iType = nwItemType.FILE
-        iClass = nwItemClass.NO_CLASS
-        iLayout = nwItemLayout.DOCUMENT
-
         self._hFonts = [self.font(), fH1, fH2, self.font(), self.font()]
-        self._dIcon = {
-            "H0": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H0"),
-            "H1": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H1"),
-            "H2": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H2"),
-            "H3": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H3"),
-            "H4": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H4"),
-        }
+        self._dIcon: dict[str, QIcon] = {}
 
         # Internals
         self._treeOrder = []
@@ -419,6 +414,7 @@ class GuiOutlineTree(QTreeWidget):
         self._firstView = True
         self._lastBuild = 0
 
+        self.updateTheme()
         self.initSettings()
         self.clearContent()
 
@@ -480,6 +476,20 @@ class GuiOutlineTree(QTreeWidget):
 
         return
 
+    def updateTheme(self) -> None:
+        """Update theme elements."""
+        iType = nwItemType.FILE
+        iClass = nwItemClass.NO_CLASS
+        iLayout = nwItemLayout.DOCUMENT
+        self._dIcon = {
+            "H0": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H0"),
+            "H1": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H1"),
+            "H2": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H2"),
+            "H3": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H3"),
+            "H4": SHARED.theme.getItemIcon(iType, iClass, iLayout, "H4"),
+        }
+        return
+
     def refreshTree(
         self, rootHandle: str | None = None,
         overRide: bool = False, novelChanged: bool = False
@@ -489,7 +499,7 @@ class GuiOutlineTree(QTreeWidget):
         tree.
         """
         # If it's the first time, we always build
-        if self._firstView or self._firstView and overRide:
+        if self._firstView or (self._firstView and overRide):
             self._loadHeaderState()
             self._populateTree(rootHandle)
             self._firstView = False
@@ -547,14 +557,11 @@ class GuiOutlineTree(QTreeWidget):
         )[0]:
             CONFIG.setLastPath("outline", path)
             logger.info("Writing CSV file: %s", path)
-            cols = [col for col in self._treeOrder if not self._colHidden[col]]
-            order = [self._colIdx[col] for col in cols]
-            with open(path, mode="w", newline="") as csvFile:
+            with open(path, mode="w", newline="", encoding="utf-8") as csvFile:
                 writer = csv.writer(csvFile, dialect="excel", quoting=csv.QUOTE_ALL)
-                writer.writerow([trConst(nwLabels.OUTLINE_COLS[col]) for col in cols])
-                for i in range(self.topLevelItemCount()):
-                    if item := self.topLevelItem(i):
-                        writer.writerow(item.text(i) for i in order)
+                writer.writerows(
+                    self._dumpNovelData(self.outlineView.outlineBar.novelValue.handle)
+                )
         return
 
     ##
@@ -614,7 +621,7 @@ class GuiOutlineTree(QTreeWidget):
                     continue
                 tmpOrder.append(nwOutline[name])
                 tmpHidden[nwOutline[name]] = hidden
-                tmpWidth[nwOutline[name]] = CONFIG.pxInt(width)
+                tmpWidth[nwOutline[name]] = width
         except Exception:
             logger.error("Invalid column state")
             logException()
@@ -638,26 +645,22 @@ class GuiOutlineTree(QTreeWidget):
         save the current width of hidden columns though. This preserves
         the last known width in case they're unhidden again.
         """
-        # If we haven't built the tree, there is nothing to save.
-        if self._lastBuild == 0:
-            return
-
-        colState = {}
-        for iCol in range(self.columnCount()):
-            hItem = self._treeOrder[iCol]
-            iLog = self.treeHead.logicalIndex(iCol)
-            logHidden = self.isColumnHidden(iLog)
-            orgWidth = CONFIG.rpxInt(self._colWidth[hItem])
-            logWidth = CONFIG.rpxInt(self.columnWidth(iLog))
-            colState[hItem.name] = [
-                logHidden, orgWidth if logHidden and logWidth == 0 else logWidth
-            ]
-
-        logger.debug("Saving State: GuiOutline")
-        pOptions = SHARED.project.options
-        pOptions.setValue("GuiOutline", "columnState", colState)
-        pOptions.saveSettings()
+        if self._lastBuild > 0 and (header := self.header()):
+            colState = {}
+            for iCol in range(self.columnCount()):
+                hItem = self._treeOrder[iCol]
+                iLog = header.logicalIndex(iCol)
+                logHidden = self.isColumnHidden(iLog)
+                orgWidth = self._colWidth[hItem]
+                logWidth = self.columnWidth(iLog)
+                colState[hItem.name] = [
+                    logHidden, orgWidth if logHidden and logWidth == 0 else logWidth
+                ]
 
+            logger.debug("Saving State: GuiOutline")
+            pOptions = SHARED.project.options
+            pOptions.setValue("GuiOutline", "columnState", colState)
+            pOptions.saveSettings()
         return
 
     def _populateTree(self, rootHandle: str | None) -> None:
@@ -745,6 +748,77 @@ class GuiOutlineTree(QTreeWidget):
 
         return
 
+    def _dumpNovelData(self, rootHandle: str | None) -> list[list[str | int]]:
+        """Dump all novel data into a table."""
+        sLabel = SHARED.project.localLookup("Story Structure")
+        nLabel = SHARED.project.localLookup("Note")
+        sKeys = sorted(SHARED.project.index.getStoryKeys())
+        nKeys = sorted(SHARED.project.index.getNoteKeys())
+        sMatch = [f"story.{k}" for k in sKeys]
+        nMatch = [f"note.{k}" for k in nKeys]
+        sHeaders = [f"{sLabel} ({k})" for k in sKeys]
+        nHeaders = [f"{nLabel} ({k})" for k in nKeys]
+
+        data: list[list[str | int]] = [[
+            "H",
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.TITLE]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.LABEL]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.LINE]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.STATUS]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.CCOUNT]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.WCOUNT]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.PCOUNT]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.POV]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.FOCUS]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.CHAR]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.PLOT]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.TIME]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.WORLD]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.OBJECT]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.ENTITY]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.CUSTOM]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.STORY]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.MENTION]),
+            trConst(nwLabels.OUTLINE_COLS[nwOutline.SYNOP]),
+            *sHeaders,
+            *nHeaders,
+        ]]
+
+        for _, tHandle, sTitle, novIdx in SHARED.project.index.novelStructure(
+            rootHandle=rootHandle, activeOnly=True
+        ):
+            if novIdx.level != "H0" and (nwItem := SHARED.project.tree[tHandle]):
+                refs = SHARED.project.index.getReferences(tHandle, sTitle)
+                comments = dict(novIdx.comments.items())
+                story = [comments.get(k, "") for k in sMatch]
+                notes = [comments.get(k, "") for k in nMatch]
+                data.append([
+                    novIdx.level,
+                    novIdx.title,
+                    nwItem.itemName,
+                    novIdx.line,
+                    nwItem.getImportStatus()[0],
+                    novIdx.charCount,
+                    novIdx.wordCount,
+                    novIdx.paraCount,
+                    ", ".join(refs[nwKeyWords.POV_KEY]),
+                    ", ".join(refs[nwKeyWords.FOCUS_KEY]),
+                    ", ".join(refs[nwKeyWords.CHAR_KEY]),
+                    ", ".join(refs[nwKeyWords.PLOT_KEY]),
+                    ", ".join(refs[nwKeyWords.TIME_KEY]),
+                    ", ".join(refs[nwKeyWords.WORLD_KEY]),
+                    ", ".join(refs[nwKeyWords.OBJECT_KEY]),
+                    ", ".join(refs[nwKeyWords.ENTITY_KEY]),
+                    ", ".join(refs[nwKeyWords.CUSTOM_KEY]),
+                    ", ".join(refs[nwKeyWords.STORY_KEY]),
+                    ", ".join(refs[nwKeyWords.MENTION_KEY]),
+                    novIdx.synopsis,
+                    *story,
+                    *notes,
+                ])
+
+        return data
+
 
 class GuiOutlineHeaderMenu(QMenu):
 
@@ -790,7 +864,7 @@ class GuiOutlineHeaderMenu(QMenu):
 
 class GuiOutlineDetails(QScrollArea):
 
-    LVL_MAP = {
+    LVL_MAP: Final[dict[str, str]] = {
         "H1": QT_TRANSLATE_NOOP("GuiOutlineDetails", "Title"),
         "H2": QT_TRANSLATE_NOOP("GuiOutlineDetails", "Chapter"),
         "H3": QT_TRANSLATE_NOOP("GuiOutlineDetails", "Scene"),
@@ -810,8 +884,6 @@ class GuiOutlineDetails(QScrollArea):
         minTitle = 30*SHARED.theme.textNWidth
         maxTitle = 40*SHARED.theme.textNWidth
         wCount = SHARED.theme.getTextWidth("999,999")
-        hSpace = int(CONFIG.pxInt(10))
-        vSpace = int(CONFIG.pxInt(4))
 
         bFont = SHARED.theme.guiFontB
 
@@ -890,8 +962,8 @@ class GuiOutlineDetails(QScrollArea):
 
         self.mainForm.setColumnStretch(1, 1)
         self.mainForm.setRowStretch(4, 1)
-        self.mainForm.setHorizontalSpacing(hSpace)
-        self.mainForm.setVerticalSpacing(vSpace)
+        self.mainForm.setHorizontalSpacing(10)
+        self.mainForm.setVerticalSpacing(4)
 
         # Selected Item Tags
         self.tagsForm = QGridLayout()
@@ -914,8 +986,8 @@ class GuiOutlineDetails(QScrollArea):
 
         self.tagsForm.setColumnStretch(1, 1)
         self.tagsForm.setRowStretch(len(self.tagValues), 1)
-        self.tagsForm.setHorizontalSpacing(hSpace)
-        self.tagsForm.setVerticalSpacing(vSpace)
+        self.tagsForm.setHorizontalSpacing(10)
+        self.tagsForm.setVerticalSpacing(4)
 
         # Assemble
         self.mainSplit = QSplitter(Qt.Orientation.Horizontal)
@@ -956,21 +1028,18 @@ class GuiOutlineDetails(QScrollArea):
         width = parent.width() if isinstance(parent, QWidget) else 1000
         pOptions = SHARED.project.options
         self.mainSplit.setSizes([
-            CONFIG.pxInt(pOptions.getInt("GuiOutlineDetails", "detailsWidth", width//3)),
-            CONFIG.pxInt(pOptions.getInt("GuiOutlineDetails", "tagsWidth", 2*width//3))
+            pOptions.getInt("GuiOutlineDetails", "detailsWidth", width//3),
+            pOptions.getInt("GuiOutlineDetails", "tagsWidth", 2*width//3),
         ])
         return
 
     def saveGuiSettings(self) -> None:
         """Run close project tasks."""
-        mainSplit = self.mainSplit.sizes()
-        detailsWidth = CONFIG.rpxInt(mainSplit[0])
-        tagsWidth = CONFIG.rpxInt(mainSplit[1])
-
         logger.debug("Saving State: GuiOutlineDetails")
+        mainSplit = self.mainSplit.sizes()
         pOptions = SHARED.project.options
-        pOptions.setValue("GuiOutlineDetails", "detailsWidth", detailsWidth)
-        pOptions.setValue("GuiOutlineDetails", "tagsWidth", tagsWidth)
+        pOptions.setValue("GuiOutlineDetails", "detailsWidth", mainSplit[0])
+        pOptions.setValue("GuiOutlineDetails", "tagsWidth", mainSplit[1])
         return
 
     def clearDetails(self) -> None:
