@@ -27,18 +27,17 @@ import logging
 
 from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import QEvent, QPoint, QSize, pyqtSignal
-from PyQt5.QtGui import QPalette
-from PyQt5.QtWidgets import QMenu, QVBoxLayout, QWidget
+from PyQt6.QtCore import QEvent, QPoint, QSize, pyqtSignal
+from PyQt6.QtWidgets import QMenu, QVBoxLayout, QWidget
 
-from novelwriter import CONFIG, SHARED
+from novelwriter import SHARED
 from novelwriter.common import qtLambda
 from novelwriter.enum import nwView
 from novelwriter.extensions.eventfilters import StatusTipFilter
 from novelwriter.extensions.modified import NIconToolButton
 from novelwriter.gui.theme import STYLES_BIG_TOOLBUTTON
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from novelwriter.guimain import GuiMain
 
 logger = logging.getLogger(__name__)
@@ -114,7 +113,7 @@ class GuiSideBar(QWidget):
         self.outerBox.addWidget(self.tbStats)
         self.outerBox.addWidget(self.tbSettings)
         self.outerBox.setContentsMargins(0, 0, 0, 0)
-        self.outerBox.setSpacing(CONFIG.pxInt(6))
+        self.outerBox.setSpacing(6)
 
         self.setLayout(self.outerBox)
         self.updateTheme()
@@ -125,10 +124,6 @@ class GuiSideBar(QWidget):
 
     def updateTheme(self) -> None:
         """Initialise GUI elements that depend on specific settings."""
-        qPalette = self.palette()
-        qPalette.setBrush(QPalette.ColorRole.Window, qPalette.base())
-        self.setPalette(qPalette)
-
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_BIG_TOOLBUTTON)
 
         self.tbProject.setStyleSheet(buttonStyle)
@@ -140,13 +135,13 @@ class GuiSideBar(QWidget):
         self.tbStats.setStyleSheet(buttonStyle)
         self.tbSettings.setStyleSheet(buttonStyle)
 
-        self.tbProject.setThemeIcon("view_editor")
-        self.tbNovel.setThemeIcon("view_novel")
-        self.tbSearch.setThemeIcon("view_search")
-        self.tbOutline.setThemeIcon("view_outline")
-        self.tbBuild.setThemeIcon("view_build")
-        self.tbDetails.setThemeIcon("proj_details")
-        self.tbStats.setThemeIcon("proj_stats")
+        self.tbProject.setThemeIcon("sb_project")
+        self.tbNovel.setThemeIcon("sb_novel")
+        self.tbSearch.setThemeIcon("sb_search")
+        self.tbOutline.setThemeIcon("sb_outline")
+        self.tbBuild.setThemeIcon("sb_build")
+        self.tbDetails.setThemeIcon("sb_details")
+        self.tbStats.setThemeIcon("sb_stats")
         self.tbSettings.setThemeIcon("settings")
 
         return
@@ -160,4 +155,4 @@ class _PopRightMenu(QMenu):
             if isinstance(parent := self.parent(), QWidget):
                 offset = QPoint(parent.width(), parent.height() - self.height())
                 self.move(parent.mapToGlobal(offset))
-        return super(_PopRightMenu, self).event(event)
+        return super().event(event)
