@@ -28,12 +28,12 @@ import logging
 from datetime import datetime
 from time import time
 
-from PyQt5.QtCore import QLocale, pyqtSlot
-from PyQt5.QtWidgets import QApplication, QLabel, QStatusBar, QWidget
+from PyQt6.QtCore import QLocale, pyqtSlot
+from PyQt6.QtWidgets import QApplication, QLabel, QStatusBar, QWidget
 
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import formatTime
-from novelwriter.constants import nwConst
+from novelwriter.constants import nwConst, nwLabels, nwStats, trStats
 from novelwriter.extensions.modified import NClickableLabel
 from novelwriter.extensions.statusled import StatusLED
 
@@ -56,13 +56,11 @@ class GuiMainStatus(QStatusBar):
         # Permanent Widgets
         # =================
 
-        xM = CONFIG.pxInt(8)
-
         # The Spell Checker Language
         self.langIcon = QLabel("", self)
         self.langText = QLabel(self.tr("None"), self)
         self.langIcon.setContentsMargins(0, 0, 0, 0)
-        self.langText.setContentsMargins(0, 0, xM, 0)
+        self.langText.setContentsMargins(0, 0, 8, 0)
         self.addPermanentWidget(self.langIcon)
         self.addPermanentWidget(self.langText)
 
@@ -70,7 +68,7 @@ class GuiMainStatus(QStatusBar):
         self.docIcon = StatusLED(iPx, iPx, self)
         self.docText = QLabel(self.tr("Editor"), self)
         self.docIcon.setContentsMargins(0, 0, 0, 0)
-        self.docText.setContentsMargins(0, 0, xM, 0)
+        self.docText.setContentsMargins(0, 0, 8, 0)
         self.addPermanentWidget(self.docIcon)
         self.addPermanentWidget(self.docText)
 
@@ -78,7 +76,7 @@ class GuiMainStatus(QStatusBar):
         self.projIcon = StatusLED(iPx, iPx, self)
         self.projText = QLabel(self.tr("Project"), self)
         self.projIcon.setContentsMargins(0, 0, 0, 0)
-        self.projText.setContentsMargins(0, 0, xM, 0)
+        self.projText.setContentsMargins(0, 0, 8, 0)
         self.addPermanentWidget(self.projIcon)
         self.addPermanentWidget(self.projText)
 
@@ -86,7 +84,7 @@ class GuiMainStatus(QStatusBar):
         self.statsIcon = QLabel(self)
         self.statsText = QLabel("", self)
         self.statsIcon.setContentsMargins(0, 0, 0, 0)
-        self.statsText.setContentsMargins(0, 0, xM, 0)
+        self.statsText.setContentsMargins(0, 0, 8, 0)
         self.addPermanentWidget(self.statsIcon)
         self.addPermanentWidget(self.statsText)
 
@@ -110,11 +108,22 @@ class GuiMainStatus(QStatusBar):
 
         logger.debug("Ready: GuiMainStatus")
 
+        self.initSettings()
         self.updateTheme()
         self.clearStatus()
 
         return
 
+    def initSettings(self) -> None:
+        """Apply user settings."""
+        if CONFIG.useCharCount:
+            self._trStatsCount = trStats(nwLabels.STATS_DISPLAY[nwStats.CHARS])
+            self._trStatsTip = self.tr("Total character count (session change)")
+        else:
+            self._trStatsCount = trStats(nwLabels.STATS_DISPLAY[nwStats.WORDS])
+            self._trStatsTip = self.tr("Total word count (session change)")
+        return
+
     def clearStatus(self) -> None:
         """Reset all widgets on the status bar to default values."""
         self.setRefTime(-1.0)
@@ -128,15 +137,15 @@ class GuiMainStatus(QStatusBar):
     def updateTheme(self) -> None:
         """Update theme elements."""
         iPx = SHARED.theme.baseIconHeight
-        self.langIcon.setPixmap(SHARED.theme.getPixmap("status_lang", (iPx, iPx)))
-        self.statsIcon.setPixmap(SHARED.theme.getPixmap("status_stats", (iPx, iPx)))
-        self.timePixmap = SHARED.theme.getPixmap("status_time", (iPx, iPx))
-        self.idlePixmap = SHARED.theme.getPixmap("status_idle", (iPx, iPx))
+        self.langIcon.setPixmap(SHARED.theme.getPixmap("language", (iPx, iPx)))
+        self.statsIcon.setPixmap(SHARED.theme.getPixmap("stats", (iPx, iPx)))
+        self.timePixmap = SHARED.theme.getPixmap("timer", (iPx, iPx))
+        self.idlePixmap = SHARED.theme.getPixmap("timer_off", (iPx, iPx))
         self.timeIcon.setPixmap(self.timePixmap)
 
-        colNone = SHARED.theme.statNone
-        colSaved = SHARED.theme.statSaved
-        colUnsaved = SHARED.theme.statUnsaved
+        colNone = SHARED.theme.getIconColor("default").darker(150)
+        colSaved = SHARED.theme.getIconColor("green").darker(150)
+        colUnsaved = SHARED.theme.getIconColor("red").darker(150)
         self.docIcon.setColors(colNone, colSaved, colUnsaved)
         self.projIcon.setColors(colNone, colSaved, colUnsaved)
 
@@ -175,11 +184,8 @@ class GuiMainStatus(QStatusBar):
 
     def setProjectStats(self, pWC: int, sWC: int) -> None:
         """Update the current project statistics."""
-        self.statsText.setText(self.tr("Words: {0} ({1})").format(f"{pWC:n}", f"{sWC:+n}"))
-        if CONFIG.incNotesWCount:
-            self.statsText.setToolTip(self.tr("Project word count (session change)"))
-        else:
-            self.statsText.setToolTip(self.tr("Novel word count (session change)"))
+        self.statsText.setText(self._trStatsCount.format(f"{pWC:n}", f"{sWC:+n}"))
+        self.statsText.setToolTip(self._trStatsTip)
         return
 
     def updateTime(self, idleTime: float = 0.0) -> None:
