@@ -30,11 +30,11 @@ from datetime import datetime
 from pathlib import Path
 from time import time
 
-from PyQt5.QtCore import Qt, QTimer, pyqtSlot
-from PyQt5.QtGui import QCloseEvent, QCursor, QIcon
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import Qt, QTimer, pyqtSlot
+from PyQt6.QtGui import QCloseEvent, QCursor, QIcon, QShortcut
+from PyQt6.QtWidgets import (
     QApplication, QFileDialog, QHBoxLayout, QMainWindow, QMessageBox,
-    QShortcut, QSplitter, QStackedWidget, QVBoxLayout, QWidget
+    QSplitter, QStackedWidget, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED, __hexversion__, __version__
@@ -56,7 +56,6 @@ from novelwriter.gui.projtree import GuiProjectView
 from novelwriter.gui.search import GuiProjectSearch
 from novelwriter.gui.sidebar import GuiSideBar
 from novelwriter.gui.statusbar import GuiMainStatus
-from novelwriter.gui.theme import GuiTheme
 from novelwriter.tools.dictionaries import GuiDictionaries
 from novelwriter.tools.manuscript import GuiManuscript
 from novelwriter.tools.noveldetails import GuiNovelDetails
@@ -92,8 +91,8 @@ class GuiMain(QMainWindow):
         logger.info("OS: %s", CONFIG.osType)
         logger.info("Kernel: %s", CONFIG.kernelVer)
         logger.info("Host: %s", CONFIG.hostName)
-        logger.info("Qt5: %s (0x%06x)", CONFIG.verQtString, CONFIG.verQtValue)
-        logger.info("PyQt5: %s (0x%06x)", CONFIG.verPyQtString, CONFIG.verPyQtValue)
+        logger.info("Qt: %s (0x%06x)", CONFIG.verQtString, CONFIG.verQtValue)
+        logger.info("PyQt: %s (0x%06x)", CONFIG.verPyQtString, CONFIG.verPyQtValue)
         logger.info("Python: %s (0x%08x)", CONFIG.verPyString, sys.hexversion)
         logger.info("GUI Language: %s", CONFIG.guiLocale)
 
@@ -101,7 +100,7 @@ class GuiMain(QMainWindow):
         # ============
 
         # Initialise UserData Instance
-        SHARED.initSharedData(self, GuiTheme())
+        SHARED.initSharedData(self)
 
         # Prepare Main Window
         self.resize(*CONFIG.mainWinSize)
@@ -115,10 +114,6 @@ class GuiMain(QMainWindow):
         # Build the GUI
         # =============
 
-        # Sizes
-        mPx = CONFIG.pxInt(4)
-        hWd = CONFIG.pxInt(4)
-
         # Main GUI Elements
         self.mainStatus     = GuiMainStatus(self)
         self.projView       = GuiProjectView(self)
@@ -143,7 +138,7 @@ class GuiMain(QMainWindow):
         self.treePane = QWidget(self)
         self.treeBox = QVBoxLayout()
         self.treeBox.setContentsMargins(0, 0, 0, 0)
-        self.treeBox.setSpacing(mPx)
+        self.treeBox.setSpacing(4)
         self.treeBox.addWidget(self.projStack)
         self.treeBox.addWidget(self.itemDetails)
         self.treePane.setLayout(self.treeBox)
@@ -152,7 +147,7 @@ class GuiMain(QMainWindow):
         self.splitView = QSplitter(Qt.Orientation.Vertical, self)
         self.splitView.addWidget(self.docViewer)
         self.splitView.addWidget(self.docViewerPanel)
-        self.splitView.setHandleWidth(hWd)
+        self.splitView.setHandleWidth(4)
         self.splitView.setOpaqueResize(False)
         self.splitView.setSizes(CONFIG.viewPanePos)
         self.splitView.setCollapsible(0, False)
@@ -163,7 +158,7 @@ class GuiMain(QMainWindow):
         self.splitDocs.addWidget(self.docEditor)
         self.splitDocs.addWidget(self.splitView)
         self.splitDocs.setOpaqueResize(False)
-        self.splitDocs.setHandleWidth(hWd)
+        self.splitDocs.setHandleWidth(4)
         self.splitDocs.setCollapsible(0, False)
         self.splitDocs.setCollapsible(1, False)
 
@@ -173,7 +168,7 @@ class GuiMain(QMainWindow):
         self.splitMain.addWidget(self.treePane)
         self.splitMain.addWidget(self.splitDocs)
         self.splitMain.setOpaqueResize(False)
-        self.splitMain.setHandleWidth(hWd)
+        self.splitMain.setHandleWidth(4)
         self.splitMain.setSizes(CONFIG.mainPanePos)
         self.splitMain.setCollapsible(0, False)
         self.splitMain.setCollapsible(0, False)
@@ -252,8 +247,6 @@ class GuiMain(QMainWindow):
         self.docEditor.itemHandleChanged.connect(self.novelView.setActiveHandle)
         self.docEditor.itemHandleChanged.connect(self.projView.setActiveHandle)
         self.docEditor.loadDocumentTagRequest.connect(self._followTag)
-        self.docEditor.novelItemMetaChanged.connect(self.novelView.updateNovelItemMeta)
-        self.docEditor.novelStructureChanged.connect(self.novelView.refreshTree)
         self.docEditor.openDocumentRequest.connect(self._openDocument)
         self.docEditor.requestNewNoteCreation.connect(SHARED.createNewNote)
         self.docEditor.requestNextDocument.connect(self.openNextDocument)
@@ -317,11 +310,11 @@ class GuiMain(QMainWindow):
         self.asProjTimer.start()
         self.asDocTimer.start()
         self.mainStatus.clearStatus()
-        self.showNormal()
 
         logger.debug("Ready: GUI")
         logger.info("novelWriter is ready ...")
         self.mainStatus.setStatusMessage(self.tr("novelWriter is ready ..."))
+        CONFIG.splashMessage("novelWriter is ready ...")
 
         return
 
@@ -347,6 +340,15 @@ class GuiMain(QMainWindow):
             logger.info("Command line path: %s", cmdOpen)
             self.openProject(cmdOpen)
 
+        # Add a small delay for the window coordinates to be ready
+        # before showing any dialogs
+        QTimer.singleShot(50, self.showPostLaunchDialogs)
+
+        return
+
+    @pyqtSlot()
+    def showPostLaunchDialogs(self) -> None:
+        """Show post launch dialogs."""
         if not SHARED.hasProject:
             self.showWelcomeDialog()
 
@@ -377,7 +379,7 @@ class GuiMain(QMainWindow):
             return True
 
         if not isYes:
-            msgYes = SHARED.question("%s<br>%s" % (
+            msgYes = SHARED.question("{0}<br>{1}".format(
                 self.tr("Close the current project?"),
                 self.tr("Changes are saved automatically.")
             ))
@@ -537,7 +539,7 @@ class GuiMain(QMainWindow):
     ) -> bool:
         """Open a specific document, optionally at a given line."""
         if not (SHARED.hasProject and tHandle):
-            logger.error("Nothing to open open")
+            logger.error("Nothing to open")
             return False
 
         if sTitle and tLine is None:
@@ -740,7 +742,6 @@ class GuiMain(QMainWindow):
 
             SHARED.project.index.rebuild()
             SHARED.project.tree.refreshAllItems()
-            self.novelView.refreshTree()
 
             tEnd = time()
             self.mainStatus.setStatusMessage(
@@ -852,7 +853,7 @@ class GuiMain(QMainWindow):
 
     def closeMain(self) -> bool:
         """Save everything, and close novelWriter."""
-        if SHARED.hasProject and CONFIG.askBeforeExit and not SHARED.question("%s<br>%s" % (
+        if SHARED.hasProject and CONFIG.askBeforeExit and not SHARED.question("{0}<br>{1}".format(
             self.tr("Do you want to exit novelWriter?"),
             self.tr("Changes are saved automatically.")
         )):
@@ -861,10 +862,10 @@ class GuiMain(QMainWindow):
         logger.info("Exiting novelWriter")
 
         if not SHARED.focusMode:
-            CONFIG.setMainPanePos(self.splitMain.sizes())
-            CONFIG.setOutlinePanePos(self.outlineView.splitSizes())
+            CONFIG.mainPanePos = self.splitMain.sizes()
+            CONFIG.outlinePanePos = self.outlineView.splitSizes()
             if self.docViewerPanel.isVisible():
-                CONFIG.setViewPanePos(self.splitView.sizes())
+                CONFIG.viewPanePos = self.splitView.sizes()
 
         CONFIG.showViewerPanel = self.docViewerPanel.isVisible()
         wFull = Qt.WindowState.WindowFullScreen
@@ -1017,7 +1018,7 @@ class GuiMain(QMainWindow):
             fN = self.novelView.treeHasFocus()
 
             self._changeView(nwView.EDITOR)
-            if (vM and (vP and fP or vN and not fN)) or (not vM and vN):
+            if (vM and ((vP and fP) or (vN and not fN))) or (not vM and vN):
                 self._changeView(nwView.NOVEL)
                 self.novelView.setTreeFocus()
             else:
@@ -1047,13 +1048,14 @@ class GuiMain(QMainWindow):
         self.initMain()
         self.saveDocument()
 
-        if tree:
+        if tree and not theme:
+            # These are also updated by a theme refresh
             SHARED.project.tree.refreshAllItems()
+            self.novelView.refreshCurrentTree()
 
         if theme:
-            # We are doing this manually instead of connecting to
-            # paletteChanged since the processing order matters
             SHARED.theme.loadTheme()
+            self.setPalette(QApplication.palette())
             self.docEditor.updateTheme()
             self.docViewer.updateTheme()
             self.docViewerPanel.updateTheme()
@@ -1064,16 +1066,18 @@ class GuiMain(QMainWindow):
             self.outlineView.updateTheme()
             self.itemDetails.updateTheme()
             self.mainStatus.updateTheme()
+            SHARED.project.tree.refreshAllItems()
 
         if syntax:
             SHARED.theme.loadSyntax()
-            self.docEditor.updateSyntaxColours()
+            self.docEditor.updateSyntaxColors()
 
         self.docEditor.initEditor()
         self.docViewer.initViewer()
         self.projView.initSettings()
         self.novelView.initSettings()
         self.outlineView.initSettings()
+        self.mainStatus.initSettings()
 
         # Force update of word count
         self._lastTotalCount = 0
@@ -1179,6 +1183,12 @@ class GuiMain(QMainWindow):
             )
         elif view == nwView.OUTLINE:
             self.mainStack.setCurrentWidget(self.outlineView)
+
+        # Set active status
+        isMain = self.mainStack.currentWidget() == self.splitMain
+        isNovel = self.projStack.currentWidget() == self.novelView
+        self.novelView.setActive(isMain and isNovel)
+
         return
 
     @pyqtSlot(nwDocAction)
@@ -1254,15 +1264,23 @@ class GuiMain(QMainWindow):
         if self._lastTotalCount != currentTotalCount:
             self._lastTotalCount = currentTotalCount
 
-            SHARED.project.updateWordCounts()
+            SHARED.project.updateCounts()
             if CONFIG.incNotesWCount:
-                iTotal = sum(SHARED.project.data.initCounts)
-                cTotal = sum(SHARED.project.data.currCounts)
-                self.mainStatus.setProjectStats(cTotal, cTotal - iTotal)
+                if CONFIG.useCharCount:
+                    iTotal = sum(SHARED.project.data.initCounts[2:])
+                    cTotal = sum(SHARED.project.data.currCounts[2:])
+                else:
+                    iTotal = sum(SHARED.project.data.initCounts[:2])
+                    cTotal = sum(SHARED.project.data.currCounts[:2])
             else:
-                iNovel, _ = SHARED.project.data.initCounts
-                cNovel, _ = SHARED.project.data.currCounts
-                self.mainStatus.setProjectStats(cNovel, cNovel - iNovel)
+                if CONFIG.useCharCount:
+                    iTotal = SHARED.project.data.initCounts[2]
+                    cTotal = SHARED.project.data.currCounts[2]
+                else:
+                    iTotal = SHARED.project.data.initCounts[0]
+                    cTotal = SHARED.project.data.currCounts[0]
+
+            self.mainStatus.setProjectStats(cTotal, cTotal - iTotal)
 
         return
 
