@@ -26,8 +26,8 @@ from __future__ import annotations
 import logging
 import random
 
-from PyQt5.QtCore import pyqtSlot
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import pyqtSlot
+from PyQt6.QtWidgets import (
     QDialogButtonBox, QGridLayout, QHBoxLayout, QLabel, QSpinBox, QVBoxLayout,
     QWidget
 )
@@ -52,18 +52,15 @@ class GuiLipsum(NDialog):
 
         self._lipsumText = ""
 
-        vSp = CONFIG.pxInt(4)
-        nPx = CONFIG.pxInt(64)
-
         self.innerBox = QHBoxLayout()
-        self.innerBox.setSpacing(CONFIG.pxInt(16))
+        self.innerBox.setSpacing(16)
 
         # Icon
         self.docIcon = QLabel(self)
-        self.docIcon.setPixmap(SHARED.theme.getPixmap("proj_document", (nPx, nPx)))
+        self.docIcon.setPixmap(SHARED.theme.getPixmap("text", (64, 64), "blue"))
 
         self.leftBox = QVBoxLayout()
-        self.leftBox.setSpacing(vSp)
+        self.leftBox.setSpacing(4)
         self.leftBox.addWidget(self.docIcon)
         self.leftBox.addStretch(1)
         self.innerBox.addLayout(self.leftBox)
@@ -78,8 +75,9 @@ class GuiLipsum(NDialog):
         self.paraCount.setMaximum(100)
         self.paraCount.setValue(5)
 
-        self.randLabel = QLabel(self.tr("Randomise order"), self)
         self.randSwitch = NSwitch(self)
+        self.randLabel = QLabel(self.tr("Randomise order"), self)
+        self.randLabel.setBuddy(self.randSwitch)
 
         self.formBox = QGridLayout()
         self.formBox.addWidget(self.headLabel, 0, 0, 1, 2, QtAlignLeft)
@@ -87,7 +85,7 @@ class GuiLipsum(NDialog):
         self.formBox.addWidget(self.paraCount, 1, 1, 1, 1, QtAlignRight)
         self.formBox.addWidget(self.randLabel, 2, 0, 1, 1, QtAlignLeft)
         self.formBox.addWidget(self.randSwitch, 2, 1, 1, 1, QtAlignRight)
-        self.formBox.setVerticalSpacing(vSp)
+        self.formBox.setVerticalSpacing(4)
         self.formBox.setRowStretch(3, 1)
         self.innerBox.addLayout(self.formBox)
 
@@ -96,17 +94,19 @@ class GuiLipsum(NDialog):
         self.buttonBox.rejected.connect(self.reject)
 
         self.btnClose = self.buttonBox.addButton(QtDialogClose)
-        self.btnClose.setAutoDefault(False)
+        if self.btnClose:
+            self.btnClose.setAutoDefault(False)
 
         self.btnInsert = self.buttonBox.addButton(self.tr("Insert"), QtRoleAction)
-        self.btnInsert.clicked.connect(self._doInsert)
-        self.btnInsert.setAutoDefault(False)
+        if self.btnInsert:
+            self.btnInsert.clicked.connect(self._doInsert)
+            self.btnInsert.setAutoDefault(False)
 
         # Assemble
         self.outerBox = QVBoxLayout()
         self.outerBox.addLayout(self.innerBox)
         self.outerBox.addWidget(self.buttonBox)
-        self.outerBox.setSpacing(CONFIG.pxInt(16))
+        self.outerBox.setSpacing(16)
         self.setLayout(self.outerBox)
 
         logger.debug("Ready: GuiLipsum")
@@ -125,10 +125,10 @@ class GuiLipsum(NDialog):
     @classmethod
     def getLipsum(cls, parent: QWidget) -> str:
         """Pop the dialog and return the lipsum text."""
-        cls = GuiLipsum(parent)
-        cls.exec()
-        text = cls.lipsumText
-        cls.softDelete()
+        dialog = cls(parent)
+        dialog.exec()
+        text = dialog.lipsumText
+        dialog.softDelete()
         return text
 
     ##
