@@ -28,13 +28,13 @@ import logging
 from time import time
 from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import Qt, QTimer, QUrl, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import (
-    QCloseEvent, QColor, QCursor, QDesktopServices, QFont, QPalette,
-    QResizeEvent, QTextDocument
+from PyQt6.QtCore import Qt, QTimer, QUrl, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import (
+    QCloseEvent, QColor, QCursor, QDesktopServices, QFont, QPageLayout,
+    QPalette, QResizeEvent, QTextDocument
 )
-from PyQt5.QtPrintSupport import QPrinter, QPrintPreviewDialog
-from PyQt5.QtWidgets import (
+from PyQt6.QtPrintSupport import QPrinter, QPrintPreviewDialog
+from PyQt6.QtWidgets import (
     QAbstractItemView, QApplication, QFormLayout, QGridLayout, QHBoxLayout,
     QLabel, QListWidget, QListWidgetItem, QPushButton, QSplitter,
     QStackedWidget, QTabWidget, QTextBrowser, QTreeWidget, QTreeWidgetItem,
@@ -42,8 +42,8 @@ from PyQt5.QtWidgets import (
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import fuzzyTime
-from novelwriter.constants import nwLabels, nwStats, trStats
+from novelwriter.common import fuzzyTime, qtLambda
+from novelwriter.constants import nwHeadFmt, nwLabels, nwStats, nwUnicode, trStats
 from novelwriter.core.buildsettings import BuildCollection, BuildSettings
 from novelwriter.core.docbuild import NWBuildDocument
 from novelwriter.extensions.modified import NIconToggleButton, NIconToolButton, NToolDialog
@@ -59,7 +59,7 @@ from novelwriter.types import (
     QtUserRole
 )
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from novelwriter.guimain import GuiMain
 
 logger = logging.getLogger(__name__)
@@ -85,18 +85,16 @@ class GuiManuscript(NToolDialog):
         self._buildMap: dict[str, QListWidgetItem] = {}
 
         self.setWindowTitle(self.tr("Build Manuscript"))
-        self.setMinimumWidth(CONFIG.pxInt(600))
-        self.setMinimumHeight(CONFIG.pxInt(500))
+        self.setMinimumWidth(600)
+        self.setMinimumHeight(500)
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        wWin = CONFIG.pxInt(900)
-        hWin = CONFIG.pxInt(600)
 
         pOptions = SHARED.project.options
         self.resize(
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "winWidth", wWin)),
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "winHeight", hWin))
+            pOptions.getInt("GuiManuscript", "winWidth", 900),
+            pOptions.getInt("GuiManuscript", "winHeight", 600),
         )
 
         # Build Controls
@@ -108,22 +106,22 @@ class GuiManuscript(NToolDialog):
 
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
 
-        self.tbAdd = NIconToolButton(self, iSz, "add")
+        self.tbAdd = NIconToolButton(self, iSz, "add", "green")
         self.tbAdd.setToolTip(self.tr("Add New Build"))
         self.tbAdd.setStyleSheet(buttonStyle)
         self.tbAdd.clicked.connect(self._createNewBuild)
 
-        self.tbDel = NIconToolButton(self, iSz, "remove")
+        self.tbDel = NIconToolButton(self, iSz, "remove", "red")
         self.tbDel.setToolTip(self.tr("Delete Selected Build"))
         self.tbDel.setStyleSheet(buttonStyle)
         self.tbDel.clicked.connect(self._deleteSelectedBuild)
 
-        self.tbCopy = NIconToolButton(self, iSz, "copy")
+        self.tbCopy = NIconToolButton(self, iSz, "copy", "blue")
         self.tbCopy.setToolTip(self.tr("Duplicate Selected Build"))
         self.tbCopy.setStyleSheet(buttonStyle)
         self.tbCopy.clicked.connect(self._copySelectedBuild)
 
-        self.tbEdit = NIconToolButton(self, iSz, "edit")
+        self.tbEdit = NIconToolButton(self, iSz, "edit", "green")
         self.tbEdit.setToolTip(self.tr("Edit Selected Build"))
         self.tbEdit.setStyleSheet(buttonStyle)
         self.tbEdit.clicked.connect(self._editSelectedBuild)
@@ -153,9 +151,7 @@ class GuiManuscript(NToolDialog):
         # ============
 
         self.buildDetails = _DetailsWidget(self)
-        self.buildDetails.setColumnWidth(
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "detailsWidth", 100)),
-        )
+        self.buildDetails.setColumnWidth(pOptions.getInt("GuiManuscript", "detailsWidth", 100))
 
         self.buildOutline = _OutlineWidget(self)
 
@@ -168,8 +164,8 @@ class GuiManuscript(NToolDialog):
         self.buildSplit.addWidget(self.buildList)
         self.buildSplit.addWidget(self.detailsTabs)
         self.buildSplit.setSizes([
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "listHeight", 50)),
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "detailsHeight", 50)),
+            pOptions.getInt("GuiManuscript", "listHeight", 50),
+            pOptions.getInt("GuiManuscript", "detailsHeight", 50),
         ])
 
         # Process Controls
@@ -185,7 +181,7 @@ class GuiManuscript(NToolDialog):
         self.btnBuild.clicked.connect(self._buildManuscript)
 
         self.btnClose = QPushButton(self.tr("Close"), self)
-        self.btnClose.clicked.connect(self.close)
+        self.btnClose.clicked.connect(qtLambda(self.close))
 
         self.processBox = QGridLayout()
         self.processBox.addWidget(self.btnPreview, 0, 0)
@@ -240,8 +236,8 @@ class GuiManuscript(NToolDialog):
         self.mainSplit.setStretchFactor(0, 0)
         self.mainSplit.setStretchFactor(1, 1)
         self.mainSplit.setSizes([
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "optsWidth", wWin//4)),
-            CONFIG.pxInt(pOptions.getInt("GuiManuscript", "viewWidth", 3*wWin//4)),
+            pOptions.getInt("GuiManuscript", "optsWidth", 225),
+            pOptions.getInt("GuiManuscript", "viewWidth", 675),
         ])
 
         self.outerBox = QVBoxLayout()
@@ -337,7 +333,7 @@ class GuiManuscript(NToolDialog):
     def _deleteSelectedBuild(self) -> None:
         """Delete the currently selected build settings entry."""
         if build := self._getSelectedBuild():
-            if SHARED.question(self.tr("Delete build '{0}'?".format(build.name))):
+            if SHARED.question(self.tr("Delete build '{0}'?").format(build.name)):
                 if dialog := self._findSettingsDialog(build.buildID):
                     dialog.close()
                 self._builds.removeBuild(build.buildID)
@@ -431,38 +427,30 @@ class GuiManuscript(NToolDialog):
 
     def _saveSettings(self) -> None:
         """Save the user GUI settings."""
-        buildOrder = []
-        for i in range(self.buildList.count()):
-            if item := self.buildList.item(i):
-                buildOrder.append(item.data(self.D_KEY))
+        buildOrder = [
+            item.data(self.D_KEY) for i in range(self.buildList.count())
+            if (item := self.buildList.item(i))
+        ]
 
         current = self.buildList.currentItem()
         lastBuild = current.data(self.D_KEY) if isinstance(current, QListWidgetItem) else ""
 
         self._builds.setBuildsState(lastBuild, buildOrder)
 
-        winWidth  = CONFIG.rpxInt(self.width())
-        winHeight = CONFIG.rpxInt(self.height())
-
         mainSplit = self.mainSplit.sizes()
-        optsWidth = CONFIG.rpxInt(mainSplit[0])
-        viewWidth = CONFIG.rpxInt(mainSplit[1])
-
         buildSplit = self.buildSplit.sizes()
-        listHeight = CONFIG.rpxInt(buildSplit[0])
-        detailsHeight = CONFIG.rpxInt(buildSplit[1])
-        detailsWidth = CONFIG.rpxInt(self.buildDetails.getColumnWidth())
+        detailsWidth = self.buildDetails.getColumnWidth()
         detailsExpanded = self.buildDetails.getExpandedState()
         showNewPage = self.swtNewPage.isChecked()
 
         logger.debug("Saving State: GuiManuscript")
         pOptions = SHARED.project.options
-        pOptions.setValue("GuiManuscript", "winWidth", winWidth)
-        pOptions.setValue("GuiManuscript", "winHeight", winHeight)
-        pOptions.setValue("GuiManuscript", "optsWidth", optsWidth)
-        pOptions.setValue("GuiManuscript", "viewWidth", viewWidth)
-        pOptions.setValue("GuiManuscript", "listHeight", listHeight)
-        pOptions.setValue("GuiManuscript", "detailsHeight", detailsHeight)
+        pOptions.setValue("GuiManuscript", "winWidth", self.width())
+        pOptions.setValue("GuiManuscript", "winHeight", self.height())
+        pOptions.setValue("GuiManuscript", "optsWidth", mainSplit[0])
+        pOptions.setValue("GuiManuscript", "viewWidth", mainSplit[1])
+        pOptions.setValue("GuiManuscript", "listHeight", buildSplit[0])
+        pOptions.setValue("GuiManuscript", "detailsHeight", buildSplit[1])
         pOptions.setValue("GuiManuscript", "detailsWidth", detailsWidth)
         pOptions.setValue("GuiManuscript", "detailsExpanded", detailsExpanded)
         pOptions.setValue("GuiManuscript", "showNewPage", showNewPage)
@@ -490,7 +478,7 @@ class GuiManuscript(NToolDialog):
         for key, name in self._builds.builds():
             bItem = QListWidgetItem()
             bItem.setText(name)
-            bItem.setIcon(SHARED.theme.getIcon("export"))
+            bItem.setIcon(SHARED.theme.getIcon("build_settings", "blue"))
             bItem.setData(self.D_KEY, key)
             self.buildList.addItem(bItem)
             self._buildMap[key] = bItem
@@ -585,8 +573,8 @@ class _DetailsWidget(QWidget):
 
         self.listView.clear()
 
-        on = SHARED.theme.getIcon("bullet-on")
-        off = SHARED.theme.getIcon("bullet-off")
+        on = SHARED.theme.getIcon("bullet-on", "blue")
+        off = SHARED.theme.getIcon("bullet-off", "blue")
 
         # Name
         item = QTreeWidgetItem()
@@ -607,11 +595,7 @@ class _DetailsWidget(QWidget):
                 item.addChild(sub)
 
         # Headings
-        hFmt = HeadingFormatter(SHARED.project)
-        hFmt.incChapter()
-        hFmt.incScene()
-        hFmt.resetScene()
-        hFmt.incScene()
+        hFmt = HeadingFormatter(SHARED.project, 7, 5, 23)
         title = self.tr("Title")
         hidden = self.tr("Hidden")
 
@@ -632,7 +616,8 @@ class _DetailsWidget(QWidget):
             if build.getBool(hHide):
                 sub.setText(1, f"[{hidden}]")
             else:
-                sub.setText(1, hFmt.apply(build.getStr(hFormat), title, 0))
+                preview = build.getStr(hFormat).replace(nwHeadFmt.BR, nwUnicode.U_LBREAK)
+                sub.setText(1, hFmt.apply(preview, title, 0))
             item.addChild(sub)
 
         # Text Content
@@ -641,8 +626,8 @@ class _DetailsWidget(QWidget):
         item.setText(1, "")
         self.listView.addTopLevelItem(item)
         for key in [
-            "text.includeSynopsis", "text.includeComments",
-            "text.includeKeywords", "text.includeBodyText",
+            "text.includeSynopsis", "text.includeComments", "text.includeStory",
+            "text.includeNotes", "text.includeKeywords", "text.includeBodyText",
         ]:
             sub = QTreeWidgetItem()
             sub.setText(0, build.getLabel(key))
@@ -693,33 +678,31 @@ class _OutlineWidget(QWidget):
             hFont.setBold(True)
             hFont.setUnderline(True)
 
-            root = self.listView.invisibleRootItem()
-            parent = root
             indent = False
-            for anchor, entry in data.items():
-                prefix, _, text = entry.partition("|")
-                if prefix in ("TT", "PT", "CH", "SC", "H1", "H2"):
-                    item = QTreeWidgetItem([text])
-                    item.setData(0, self.D_LINE, anchor)
-                    if prefix == "TT":
-                        item.setFont(0, tFont)
-                        item.setForeground(0, tBrush)
-                        root.addChild(item)
-                        parent = root
-                    elif prefix == "PT":
-                        item.setFont(0, hFont)
-                        root.addChild(item)
-                        parent = root
-                    elif prefix in ("CH", "H1"):
-                        root.addChild(item)
-                        parent = item
-                    elif prefix in ("SC", "H2"):
-                        parent.addChild(item)
-                        indent = True
+            if root := self.listView.invisibleRootItem():
+                parent = root
+                for anchor, entry in data.items():
+                    prefix, _, text = entry.partition("|")
+                    if prefix in ("TT", "PT", "CH", "SC", "H1", "H2"):
+                        item = QTreeWidgetItem([text])
+                        item.setData(0, self.D_LINE, anchor)
+                        if prefix == "TT":
+                            item.setFont(0, tFont)
+                            item.setForeground(0, tBrush)
+                            root.addChild(item)
+                            parent = root
+                        elif prefix == "PT":
+                            item.setFont(0, hFont)
+                            root.addChild(item)
+                            parent = root
+                        elif prefix in ("CH", "H1"):
+                            root.addChild(item)
+                            parent = item
+                        elif prefix in ("SC", "H2"):
+                            parent.addChild(item)
+                            indent = True
 
-            self.listView.setIndentation(
-                SHARED.theme.baseIconHeight if indent else CONFIG.pxInt(4)
-            )
+            self.listView.setIndentation(SHARED.theme.baseIconHeight if indent else 4)
             self._outline = data
 
         return
@@ -750,13 +733,15 @@ class _PreviewWidget(QTextBrowser):
         self.setPalette(dPalette)
 
         self.setMinimumWidth(40*SHARED.theme.textNWidth)
-        self.setTabStopDistance(CONFIG.getTabWidth())
+        self.setTabStopDistance(CONFIG.tabWidth)
         self.setOpenExternalLinks(False)
         self.setOpenLinks(False)
 
-        self.document().setDocumentMargin(CONFIG.getTextMargin())
+        if document := self.document():
+            document.setDocumentMargin(CONFIG.textMargin)
+
         self.setPlaceholderText(self.tr(
-            "Press the \"Preview\" button to generate ..."
+            'Press the "Preview" button to generate ...'
         ))
 
         self.setVerticalScrollBarPolicy(Qt.ScrollBarPolicy.ScrollBarAlwaysOn)
@@ -781,11 +766,11 @@ class _PreviewWidget(QTextBrowser):
         self.ageLabel.setFixedHeight(int(2.1*SHARED.theme.fontPixelSize))
 
         # Progress
-        self.buildProgress = NProgressCircle(self, CONFIG.pxInt(160), CONFIG.pxInt(16))
+        self.buildProgress = NProgressCircle(self, 160, 16)
         self.buildProgress.setVisible(False)
         self.buildProgress.setMaximum(1)
         self.buildProgress.setValue(0)
-        self.buildProgress.setColours(
+        self.buildProgress.setColors(
             back=QColor(255, 255, 255, 224),
             track=QColor(196, 196, 196, 128),
             text=QColor(0, 0, 0)
@@ -834,7 +819,8 @@ class _PreviewWidget(QTextBrowser):
         self.buildProgress.setValue(0)
         self.buildProgress.setCentreText(None)
         self.buildProgress.setVisible(True)
-        self._scrollPos = self.verticalScrollBar().value()
+        if vBar := self.verticalScrollBar():
+            self._scrollPos = vBar.value()
         self.setPlaceholderText("")
         self.clear()
         return
@@ -852,9 +838,9 @@ class _PreviewWidget(QTextBrowser):
         self.buildProgress.setCentreText(self.tr("Processing ..."))
         QApplication.processEvents()
 
-        document.setDocumentMargin(CONFIG.getTextMargin())
+        document.setDocumentMargin(CONFIG.textMargin)
         self.setDocument(document)
-        self.setTabStopDistance(CONFIG.getTabWidth())
+        self.setTabStopDistance(CONFIG.tabWidth)
 
         self._docTime = int(time())
         self._updateBuildAge()
@@ -883,10 +869,11 @@ class _PreviewWidget(QTextBrowser):
     @pyqtSlot("QPrinter*")
     def printPreview(self, printer: QPrinter) -> None:
         """Connect the print preview painter to the document viewer."""
-        QApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
-        printer.setOrientation(QPrinter.Orientation.Portrait)
-        self.document().print(printer)
-        QApplication.restoreOverrideCursor()
+        if document := self.document():
+            QApplication.setOverrideCursor(QCursor(Qt.CursorShape.WaitCursor))
+            printer.setPageOrientation(QPageLayout.Orientation.Portrait)
+            document.print(printer)
+            QApplication.restoreOverrideCursor()
         return
 
     @pyqtSlot(str)
@@ -928,7 +915,8 @@ class _PreviewWidget(QTextBrowser):
     def _postUpdate(self) -> None:
         """Run tasks after content update."""
         self.buildProgress.setVisible(False)
-        self.verticalScrollBar().setValue(self._scrollPos)
+        if vBar := self.verticalScrollBar():
+            vBar.setValue(self._scrollPos)
         return
 
     ##
@@ -941,7 +929,7 @@ class _PreviewWidget(QTextBrowser):
         """
         vBar = self.verticalScrollBar()
         tB = self.frameWidth()
-        vW = self.width() - 2*tB - vBar.width()
+        vW = self.width() - 2*tB - (vBar.width() if vBar else 0)
         vH = self.height() - 2*tB
         tH = self.ageLabel.height()
         pS = self.buildProgress.width()
@@ -986,23 +974,23 @@ class _StatsWidget(QWidget):
     def updateStats(self, data: dict[str, int]) -> None:
         """Update the stats values from a Tokenizer stats dict."""
         # Minimal
-        self.minWordCount.setText("{0:n}".format(data.get(nwStats.WORDS, 0)))
-        self.minCharCount.setText("{0:n}".format(data.get(nwStats.CHARS, 0)))
+        self.minWordCount.setText(f"{data.get(nwStats.WORDS, 0):n}")
+        self.minCharCount.setText(f"{data.get(nwStats.CHARS, 0):n}")
 
         # Maximal
-        self.maxTotalWords.setText("{0:n}".format(data.get(nwStats.WORDS, 0)))
-        self.maxHeadWords.setText("{0:n}".format(data.get(nwStats.WORDS_TITLE, 0)))
-        self.maxTextWords.setText("{0:n}".format(data.get(nwStats.WORDS_TEXT, 0)))
-        self.maxTitleCount.setText("{0:n}".format(data.get(nwStats.TITLES, 0)))
-        self.maxParCount.setText("{0:n}".format(data.get(nwStats.PARAGRAPHS, 0)))
+        self.maxTotalWords.setText(f"{data.get(nwStats.WORDS, 0):n}")
+        self.maxHeadWords.setText(f"{data.get(nwStats.WORDS_TITLE, 0):n}")
+        self.maxTextWords.setText(f"{data.get(nwStats.WORDS_TEXT, 0):n}")
+        self.maxTitleCount.setText(f"{data.get(nwStats.TITLES, 0):n}")
+        self.maxParCount.setText(f"{data.get(nwStats.PARAGRAPHS, 0):n}")
 
-        self.maxTotalChars.setText("{0:n}".format(data.get(nwStats.CHARS, 0)))
-        self.maxHeaderChars.setText("{0:n}".format(data.get(nwStats.CHARS_TITLE, 0)))
-        self.maxTextChars.setText("{0:n}".format(data.get(nwStats.CHARS_TEXT, 0)))
+        self.maxTotalChars.setText(f"{data.get(nwStats.CHARS, 0):n}")
+        self.maxHeaderChars.setText(f"{data.get(nwStats.CHARS_TITLE, 0):n}")
+        self.maxTextChars.setText(f"{data.get(nwStats.CHARS_TEXT, 0):n}")
 
-        self.maxTotalWordChars.setText("{0:n}".format(data.get(nwStats.WCHARS_ALL, 0)))
-        self.maxHeadWordChars.setText("{0:n}".format(data.get(nwStats.WCHARS_TITLE, 0)))
-        self.maxTextWordChars.setText("{0:n}".format(data.get(nwStats.WCHARS_TEXT, 0)))
+        self.maxTotalWordChars.setText(f"{data.get(nwStats.WCHARS_ALL, 0):n}")
+        self.maxHeadWordChars.setText(f"{data.get(nwStats.WCHARS_TITLE, 0):n}")
+        self.maxTextWordChars.setText(f"{data.get(nwStats.WCHARS_TEXT, 0):n}")
 
         return
 
@@ -1033,10 +1021,6 @@ class _StatsWidget(QWidget):
 
     def _buildBottomPanel(self) -> None:
         """Build the bottom page."""
-        mPx = CONFIG.pxInt(8)
-        hPx = CONFIG.pxInt(12)
-        vPx = CONFIG.pxInt(4)
-
         trAllChars = trStats(nwLabels.STATS_NAME[nwStats.CHARS])
         trTextChars = trStats(nwLabels.STATS_NAME[nwStats.CHARS_TEXT])
         trTitleChars = trStats(nwLabels.STATS_NAME[nwStats.CHARS_TITLE])
@@ -1073,8 +1057,8 @@ class _StatsWidget(QWidget):
         self.leftForm.addRow("", QLabel(self))
         self.leftForm.addRow(trTitleCount, self.maxTitleCount)
         self.leftForm.addRow(trParagraphCount, self.maxParCount)
-        self.leftForm.setHorizontalSpacing(hPx)
-        self.leftForm.setVerticalSpacing(vPx)
+        self.leftForm.setHorizontalSpacing(12)
+        self.leftForm.setVerticalSpacing(4)
 
         # Maximal Form, Right Column
         self.maxTotalChars = QLabel(self)
@@ -1098,25 +1082,25 @@ class _StatsWidget(QWidget):
         self.rightForm.addRow(trAllWordChars, self.maxTotalWordChars)
         self.rightForm.addRow(trTitleWordChars, self.maxHeadWordChars)
         self.rightForm.addRow(trTextWordChars, self.maxTextWordChars)
-        self.rightForm.setHorizontalSpacing(hPx)
-        self.rightForm.setVerticalSpacing(vPx)
+        self.rightForm.setHorizontalSpacing(12)
+        self.rightForm.setVerticalSpacing(4)
 
         # Assemble
         self.minLayout = QHBoxLayout()
         self.minLayout.addWidget(QLabel(trAllWords, self))
         self.minLayout.addWidget(self.minWordCount)
-        self.minLayout.addSpacing(mPx)
+        self.minLayout.addSpacing(8)
         self.minLayout.addWidget(QLabel(trAllChars, self))
         self.minLayout.addWidget(self.minCharCount)
         self.minLayout.addStretch(1)
-        self.minLayout.setSpacing(mPx)
+        self.minLayout.setSpacing(8)
         self.minLayout.setContentsMargins(0, 0, 0, 0)
 
         self.maxLayout = QHBoxLayout()
         self.maxLayout.addLayout(self.leftForm)
         self.maxLayout.addLayout(self.rightForm)
         self.maxLayout.addStretch(1)
-        self.maxLayout.setSpacing(CONFIG.pxInt(32))
+        self.maxLayout.setSpacing(32)
         self.maxLayout.setContentsMargins(0, 0, 0, 0)
 
         self.minWidget.setLayout(self.minLayout)
