@@ -27,9 +27,9 @@ import logging
 
 from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import QEvent, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QFont, QIcon, QSyntaxHighlighter, QTextCharFormat, QTextDocument
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import QEvent, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QFont, QIcon, QSyntaxHighlighter, QTextCharFormat, QTextDocument
+from PyQt6.QtWidgets import (
     QAbstractButton, QAbstractItemView, QDialogButtonBox, QFrame, QGridLayout,
     QHBoxLayout, QLabel, QLineEdit, QMenu, QPlainTextEdit, QPushButton,
     QSplitter, QStackedWidget, QTreeWidget, QTreeWidgetItem, QVBoxLayout,
@@ -37,11 +37,11 @@ from PyQt5.QtWidgets import (
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import describeFont, fontMatcher, qtLambda
-from novelwriter.constants import nwHeadFmt, nwKeyWords, nwLabels, trConst
+from novelwriter.common import describeFont, fontMatcher, qtAddAction, qtLambda
+from novelwriter.constants import nwHeadFmt, nwKeyWords, nwLabels, nwUnicode, trConst
 from novelwriter.core.buildsettings import BuildSettings, FilterMode
 from novelwriter.extensions.configlayout import (
-    NColourLabel, NFixedPage, NScrollableForm, NScrollablePage
+    NColorLabel, NFixedPage, NScrollableForm, NScrollablePage
 )
 from novelwriter.extensions.modified import (
     NComboBox, NDoubleSpinBox, NIconToolButton, NSpinBox, NToolDialog
@@ -55,7 +55,7 @@ from novelwriter.types import (
     QtUserRole
 )
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from novelwriter.guimain import GuiMain
 
 logger = logging.getLogger(__name__)
@@ -80,24 +80,22 @@ class GuiBuildSettings(NToolDialog):
         logger.debug("Create: GuiBuildSettings")
         self.setObjectName("GuiBuildSettings")
 
-        self._build = build
+        # Make a copy of the build object
+        self._build = BuildSettings.fromDict(build.pack())
 
         self.setWindowTitle(self.tr("Manuscript Build Settings"))
-        self.setMinimumSize(CONFIG.pxInt(700), CONFIG.pxInt(400))
-
-        wWin = CONFIG.pxInt(750)
-        hWin = CONFIG.pxInt(550)
+        self.setMinimumSize(700, 400)
 
         options = SHARED.project.options
         self.resize(
-            CONFIG.pxInt(options.getInt("GuiBuildSettings", "winWidth", wWin)),
-            CONFIG.pxInt(options.getInt("GuiBuildSettings", "winHeight", hWin))
+            options.getInt("GuiBuildSettings", "winWidth", 750),
+            options.getInt("GuiBuildSettings", "winHeight", 550),
         )
 
         # Title
-        self.titleLabel = NColourLabel(
+        self.titleLabel = NColorLabel(
             self.tr("Manuscript Build Settings"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE, indent=CONFIG.pxInt(4)
+            scale=NColorLabel.HEADER_SCALE, indent=4,
         )
 
         # Settings Name
@@ -107,6 +105,7 @@ class GuiBuildSettings(NToolDialog):
         # SideBar
         self.sidebar = NPagedSideBar(self)
         self.sidebar.setLabelColor(SHARED.theme.helpText)
+        self.sidebar.setAccessibleName(self.titleLabel.text())
 
         self.sidebar.addLabel(self.tr("General"))
         self.sidebar.addButton(self.tr("Selection"), self.OPT_FILTERS)
@@ -145,7 +144,7 @@ class GuiBuildSettings(NToolDialog):
         self.outerBox.addLayout(self.topBox)
         self.outerBox.addLayout(self.mainBox)
         self.outerBox.addWidget(self.buttonBox)
-        self.outerBox.setSpacing(CONFIG.pxInt(12))
+        self.outerBox.setSpacing(12)
 
         self.setLayout(self.outerBox)
 
@@ -186,6 +185,7 @@ class GuiBuildSettings(NToolDialog):
         settings.
         """
         logger.debug("Closing: GuiBuildSettings")
+        self._applyChanges()
         self._askToSaveBuild()
         self._saveSettings()
         event.accept()
@@ -213,11 +213,14 @@ class GuiBuildSettings(NToolDialog):
         """Handle button clicks from the dialog button box."""
         role = self.buttonBox.buttonRole(button)
         if role == QtRoleApply:
+            self._applyChanges()
             self._emitBuildData()
         elif role == QtRoleAccept:
+            self._applyChanges()
             self._emitBuildData()
             self.close()
         elif role == QtRoleReject:
+            self._build.resetChangedState()
             self.close()
         return
 
@@ -230,35 +233,34 @@ class GuiBuildSettings(NToolDialog):
         whether the user wants to save them.
         """
         if self._build.changed:
-            response = SHARED.question(self.tr(
-                "Do you want to save your changes to '{0}'?".format(self._build.name)
-            ))
-            if response:
+            if SHARED.question(self.tr(
+                "Do you want to save your changes to '{0}'?"
+            ).format(self._build.name)):
                 self._emitBuildData()
             self._build.resetChangedState()
         return
 
     def _saveSettings(self) -> None:
         """Save the various user settings."""
-        winWidth  = CONFIG.rpxInt(self.width())
-        winHeight = CONFIG.rpxInt(self.height())
         treeWidth, filterWidth = self.optTabSelect.mainSplitSizes()
-
         logger.debug("Saving State: GuiBuildSettings")
         pOptions = SHARED.project.options
-        pOptions.setValue("GuiBuildSettings", "winWidth", winWidth)
-        pOptions.setValue("GuiBuildSettings", "winHeight", winHeight)
+        pOptions.setValue("GuiBuildSettings", "winWidth", self.width())
+        pOptions.setValue("GuiBuildSettings", "winHeight", self.height())
         pOptions.setValue("GuiBuildSettings", "treeWidth", treeWidth)
         pOptions.setValue("GuiBuildSettings", "filterWidth", filterWidth)
         pOptions.saveSettings()
+        return
 
+    def _applyChanges(self) -> None:
+        """Apply all settings changes to the build object."""
+        self._build.setName(self.editBuildName.text())
+        self.optTabHeadings.saveContent()
+        self.optTabFormatting.saveContent()
         return
 
     def _emitBuildData(self) -> None:
         """Assemble the build data and emit the signal."""
-        self._build.setName(self.editBuildName.text())
-        self.optTabHeadings.saveContent()
-        self.optTabFormatting.saveContent()
         self.newSettingsReady.emit(self._build)
         self._build.resetChangedState()
         return
@@ -287,9 +289,9 @@ class _FilterTab(NFixedPage):
 
         self._statusFlags: dict[int, QIcon] = {
             self.F_NONE:     QIcon(),
-            self.F_FILTERED: SHARED.theme.getIcon("build_filtered"),
-            self.F_INCLUDED: SHARED.theme.getIcon("build_included"),
-            self.F_EXCLUDED: SHARED.theme.getIcon("build_excluded"),
+            self.F_FILTERED: SHARED.theme.getIcon("filter", "orange"),
+            self.F_INCLUDED: SHARED.theme.getIcon("pin", "blue"),
+            self.F_EXCLUDED: SHARED.theme.getIcon("exclude", "red"),
         }
 
         self._trIncluded = self.tr("Included in manuscript")
@@ -300,7 +302,6 @@ class _FilterTab(NFixedPage):
 
         iSz = SHARED.theme.baseIconSize
         iPx = SHARED.theme.baseIconHeight
-        cMg = CONFIG.pxInt(6)
 
         # Tree Widget
         self.optTree = QTreeWidget(self)
@@ -311,14 +312,14 @@ class _FilterTab(NFixedPage):
         self.optTree.setIndentation(iPx)
         self.optTree.setColumnCount(3)
 
-        treeHeader = self.optTree.header()
-        treeHeader.setStretchLastSection(False)
-        treeHeader.setMinimumSectionSize(iPx + cMg)  # See Issue #1551
-        treeHeader.setSectionResizeMode(self.C_NAME, QtHeaderStretch)
-        treeHeader.setSectionResizeMode(self.C_ACTIVE, QtHeaderFixed)
-        treeHeader.setSectionResizeMode(self.C_STATUS, QtHeaderFixed)
-        treeHeader.resizeSection(self.C_ACTIVE, iPx + cMg)
-        treeHeader.resizeSection(self.C_STATUS, iPx + cMg)
+        if header := self.optTree.header():
+            header.setStretchLastSection(False)
+            header.setMinimumSectionSize(iPx + 6)  # See Issue #1551
+            header.setSectionResizeMode(self.C_NAME, QtHeaderStretch)
+            header.setSectionResizeMode(self.C_ACTIVE, QtHeaderFixed)
+            header.setSectionResizeMode(self.C_STATUS, QtHeaderFixed)
+            header.resizeSection(self.C_ACTIVE, iPx + 6)
+            header.resizeSection(self.C_STATUS, iPx + 6)
 
         self.optTree.setDragDropMode(QAbstractItemView.DragDropMode.NoDragDrop)
         self.optTree.setSelectionMode(QAbstractItemView.SelectionMode.ExtendedSelection)
@@ -337,7 +338,7 @@ class _FilterTab(NFixedPage):
         self.excludedButton.setIcon(self._statusFlags[self.F_EXCLUDED])
         self.excludedButton.clicked.connect(qtLambda(self._setSelectedMode, self.F_EXCLUDED))
 
-        self.resetButton = NIconToolButton(self, iSz, "revert")
+        self.resetButton = NIconToolButton(self, iSz, "revert", "green")
         self.resetButton.setToolTip(self.tr("Reset to default"))
         self.resetButton.clicked.connect(qtLambda(self._setSelectedMode, self.F_FILTERED))
 
@@ -347,7 +348,7 @@ class _FilterTab(NFixedPage):
         self.modeBox.addWidget(self.includedButton)
         self.modeBox.addWidget(self.excludedButton)
         self.modeBox.addWidget(self.resetButton)
-        self.modeBox.setSpacing(CONFIG.pxInt(4))
+        self.modeBox.setSpacing(4)
 
         # Filer Options
         self.filterOpt = NSwitchBox(self, iPx)
@@ -375,8 +376,8 @@ class _FilterTab(NFixedPage):
         self.mainSplit.setStretchFactor(0, 1)
         self.mainSplit.setStretchFactor(1, 0)
         self.mainSplit.setSizes([
-            CONFIG.pxInt(pOptions.getInt("GuiBuildSettings", "treeWidth", 300)),
-            CONFIG.pxInt(pOptions.getInt("GuiBuildSettings", "filterWidth", 300))
+            pOptions.getInt("GuiBuildSettings", "treeWidth", 300),
+            pOptions.getInt("GuiBuildSettings", "filterWidth", 300),
         ])
 
         self.setCentralWidget(self.mainSplit)
@@ -393,7 +394,7 @@ class _FilterTab(NFixedPage):
         """Extract the sizes of the main splitter."""
         sizes = self.mainSplit.sizes()
         m, n = (sizes[0], sizes[1]) if len(sizes) >= 2 else (0, 0)
-        return CONFIG.rpxInt(m), CONFIG.rpxInt(n)
+        return m, n
 
     ##
     #  Slots
@@ -459,19 +460,19 @@ class _FilterTab(NFixedPage):
         self.filterOpt.clear()
         self.filterOpt.addLabel(self._build.getLabel("filter"))
         self.filterOpt.addItem(
-            SHARED.theme.getIcon("proj_scene"),
+            SHARED.theme.getIcon("prj_scene", "scene"),
             self._build.getLabel("filter.includeNovel"),
             "doc:filter.includeNovel",
             default=self._build.getBool("filter.includeNovel")
         )
         self.filterOpt.addItem(
-            SHARED.theme.getIcon("proj_note"),
+            SHARED.theme.getIcon("prj_note", "note"),
             self._build.getLabel("filter.includeNotes"),
             "doc:filter.includeNotes",
             default=self._build.getBool("filter.includeNotes")
         )
         self.filterOpt.addItem(
-            SHARED.theme.getIcon("unchecked"),
+            SHARED.theme.getIcon("unchecked", "red"),
             self._build.getLabel("filter.includeInactive"),
             "doc:filter.includeInactive",
             default=self._build.getBool("filter.includeInactive")
@@ -558,25 +559,23 @@ class _HeadingsTab(NScrollablePage):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        sSp = CONFIG.pxInt(16)
-        vSp = CONFIG.pxInt(12)
-        bSp = CONFIG.pxInt(6)
         trHide = self.tr("Hide")
 
         # Format Boxes
         # ============
         self.formatBox = QGridLayout()
-        self.formatBox.setHorizontalSpacing(bSp)
+        self.formatBox.setHorizontalSpacing(6)
 
         # Title Heading
         self.lblPart = QLabel(self._build.getLabel("headings.fmtPart"), self)
         self.fmtPart = QLineEdit("", self)
         self.fmtPart.setReadOnly(True)
-        self.btnPart = NIconToolButton(self, iSz, "edit")
+        self.btnPart = NIconToolButton(self, iSz, "edit", "green")
         self.btnPart.clicked.connect(qtLambda(self._editHeading, self.EDIT_TITLE))
-        self.hdePart = QLabel(trHide, self)
-        self.hdePart.setIndent(bSp)
         self.swtPart = NSwitch(self, height=iPx)
+        self.hdePart = QLabel(trHide, self)
+        self.hdePart.setIndent(6)
+        self.hdePart.setBuddy(self.swtPart)
 
         self.formatBox.addWidget(self.lblPart, 0, 0)
         self.formatBox.addWidget(self.fmtPart, 0, 1)
@@ -588,11 +587,12 @@ class _HeadingsTab(NScrollablePage):
         self.lblChapter = QLabel(self._build.getLabel("headings.fmtChapter"), self)
         self.fmtChapter = QLineEdit("", self)
         self.fmtChapter.setReadOnly(True)
-        self.btnChapter = NIconToolButton(self, iSz, "edit")
+        self.btnChapter = NIconToolButton(self, iSz, "edit", "green")
         self.btnChapter.clicked.connect(qtLambda(self._editHeading, self.EDIT_CHAPTER))
-        self.hdeChapter = QLabel(trHide, self)
-        self.hdeChapter.setIndent(bSp)
         self.swtChapter = NSwitch(self, height=iPx)
+        self.hdeChapter = QLabel(trHide, self)
+        self.hdeChapter.setIndent(6)
+        self.hdeChapter.setBuddy(self.swtChapter)
 
         self.formatBox.addWidget(self.lblChapter, 1, 0)
         self.formatBox.addWidget(self.fmtChapter, 1, 1)
@@ -604,11 +604,12 @@ class _HeadingsTab(NScrollablePage):
         self.lblUnnumbered = QLabel(self._build.getLabel("headings.fmtUnnumbered"), self)
         self.fmtUnnumbered = QLineEdit("", self)
         self.fmtUnnumbered.setReadOnly(True)
-        self.btnUnnumbered = NIconToolButton(self, iSz, "edit")
+        self.btnUnnumbered = NIconToolButton(self, iSz, "edit", "green")
         self.btnUnnumbered.clicked.connect(qtLambda(self._editHeading, self.EDIT_UNNUM))
-        self.hdeUnnumbered = QLabel(trHide, self)
-        self.hdeUnnumbered.setIndent(bSp)
         self.swtUnnumbered = NSwitch(self, height=iPx)
+        self.hdeUnnumbered = QLabel(trHide, self)
+        self.hdeUnnumbered.setIndent(6)
+        self.hdeUnnumbered.setBuddy(self.swtUnnumbered)
 
         self.formatBox.addWidget(self.lblUnnumbered, 2, 0)
         self.formatBox.addWidget(self.fmtUnnumbered, 2, 1)
@@ -620,11 +621,12 @@ class _HeadingsTab(NScrollablePage):
         self.lblScene = QLabel(self._build.getLabel("headings.fmtScene"), self)
         self.fmtScene = QLineEdit("", self)
         self.fmtScene.setReadOnly(True)
-        self.btnScene = NIconToolButton(self, iSz, "edit")
+        self.btnScene = NIconToolButton(self, iSz, "edit", "green")
         self.btnScene.clicked.connect(qtLambda(self._editHeading, self.EDIT_SCENE))
-        self.hdeScene = QLabel(trHide, self)
-        self.hdeScene.setIndent(bSp)
         self.swtScene = NSwitch(self, height=iPx)
+        self.hdeScene = QLabel(trHide, self)
+        self.hdeScene.setIndent(6)
+        self.hdeScene.setBuddy(self.swtScene)
 
         self.formatBox.addWidget(self.lblScene, 3, 0)
         self.formatBox.addWidget(self.fmtScene, 3, 1)
@@ -636,11 +638,12 @@ class _HeadingsTab(NScrollablePage):
         self.lblAScene = QLabel(self._build.getLabel("headings.fmtAltScene"), self)
         self.fmtAScene = QLineEdit("", self)
         self.fmtAScene.setReadOnly(True)
-        self.btnAScene = NIconToolButton(self, iSz, "edit")
+        self.btnAScene = NIconToolButton(self, iSz, "edit", "green")
         self.btnAScene.clicked.connect(qtLambda(self._editHeading, self.EDIT_HSCENE))
-        self.hdeAScene = QLabel(trHide, self)
-        self.hdeAScene.setIndent(bSp)
         self.swtAScene = NSwitch(self, height=iPx)
+        self.hdeAScene = QLabel(trHide, self)
+        self.hdeAScene.setIndent(6)
+        self.hdeAScene.setBuddy(self.swtAScene)
 
         self.formatBox.addWidget(self.lblAScene, 4, 0)
         self.formatBox.addWidget(self.fmtAScene, 4, 1)
@@ -652,11 +655,12 @@ class _HeadingsTab(NScrollablePage):
         self.lblSection = QLabel(self._build.getLabel("headings.fmtSection"), self)
         self.fmtSection = QLineEdit("", self)
         self.fmtSection.setReadOnly(True)
-        self.btnSection = NIconToolButton(self, iSz, "edit")
+        self.btnSection = NIconToolButton(self, iSz, "edit", "green")
         self.btnSection.clicked.connect(qtLambda(self._editHeading, self.EDIT_SECTION))
-        self.hdeSection = QLabel(trHide, self)
-        self.hdeSection.setIndent(bSp)
         self.swtSection = NSwitch(self, height=iPx)
+        self.hdeSection = QLabel(trHide, self)
+        self.hdeSection.setIndent(6)
+        self.hdeSection.setBuddy(self.swtSection)
 
         self.formatBox.addWidget(self.lblSection, 5, 0)
         self.formatBox.addWidget(self.fmtSection, 5, 1)
@@ -675,16 +679,16 @@ class _HeadingsTab(NScrollablePage):
 
         self.formSyntax = _HeadingSyntaxHighlighter(self.editTextBox.document())
 
-        self.menuInsert = QMenu(self)
-        self.aInsTitle = self.menuInsert.addAction(self.tr("Title"))
-        self.aInsChNum = self.menuInsert.addAction(self.tr("Chapter Number"))
-        self.aInsChWord = self.menuInsert.addAction(self.tr("Chapter Number (Word)"))
-        self.aInsChRomU = self.menuInsert.addAction(self.tr("Chapter Number (Upper Case Roman)"))
-        self.aInsChRomL = self.menuInsert.addAction(self.tr("Chapter Number (Lower Case Roman)"))
-        self.aInsScNum = self.menuInsert.addAction(self.tr("Scene Number (In Chapter)"))
-        self.aInsScAbs = self.menuInsert.addAction(self.tr("Scene Number (Absolute)"))
-        self.aInsCharPOV = self.menuInsert.addAction(self.tr("Point of View Character"))
-        self.aInsCharFocus = self.menuInsert.addAction(self.tr("Focus Character"))
+        self.mInsert = QMenu(self)
+        self.aInsTitle = qtAddAction(self.mInsert, self.tr("Title"))
+        self.aInsChNum = qtAddAction(self.mInsert, self.tr("Chapter Number"))
+        self.aInsChWord = qtAddAction(self.mInsert, self.tr("Chapter Number (Word)"))
+        self.aInsChRomU = qtAddAction(self.mInsert, self.tr("Chapter Number (Upper Case Roman)"))
+        self.aInsChRomL = qtAddAction(self.mInsert, self.tr("Chapter Number (Lower Case Roman)"))
+        self.aInsScNum = qtAddAction(self.mInsert, self.tr("Scene Number (In Chapter)"))
+        self.aInsScAbs = qtAddAction(self.mInsert, self.tr("Scene Number (Absolute)"))
+        self.aInsCharPOV = qtAddAction(self.mInsert, self.tr("Point of View Character"))
+        self.aInsCharFocus = qtAddAction(self.mInsert, self.tr("Focus Character"))
 
         self.aInsTitle.triggered.connect(qtLambda(self._insertIntoForm, nwHeadFmt.TITLE))
         self.aInsChNum.triggered.connect(qtLambda(self._insertIntoForm, nwHeadFmt.CH_NUM))
@@ -697,7 +701,7 @@ class _HeadingsTab(NScrollablePage):
         self.aInsCharFocus.triggered.connect(qtLambda(self._insertIntoForm, nwHeadFmt.CHAR_FOCUS))
 
         self.btnInsert = QPushButton(self.tr("Insert"), self)
-        self.btnInsert.setMenu(self.menuInsert)
+        self.btnInsert.setMenu(self.mInsert)
 
         self.btnApply = QPushButton(self.tr("Apply"), self)
         self.btnApply.clicked.connect(self._saveFormat)
@@ -714,44 +718,59 @@ class _HeadingsTab(NScrollablePage):
 
         # Layout Matrix
         # =============
-        self.layoutMatrix = QGridLayout()
-        self.layoutMatrix.setVerticalSpacing(vSp)
-        self.layoutMatrix.setHorizontalSpacing(vSp)
+        trCentre = self.tr("Centre")
+        trBreak = self.tr("Page Break")
 
-        self.layoutMatrix.addWidget(QLabel(self.tr("Centre"), self), 0, 1)
-        self.layoutMatrix.addWidget(QLabel(self.tr("Page Break"), self), 0, 2)
+        self.layoutMatrix = QGridLayout()
+        self.layoutMatrix.setVerticalSpacing(12)
+        self.layoutMatrix.setHorizontalSpacing(12)
+
+        self.layoutMatrix.addWidget(QLabel(trCentre, self), 0, 1)
+        self.layoutMatrix.addWidget(QLabel(trBreak, self), 0, 2)
 
         # Title Layout
-        self.lblTitle = QLabel(self._build.getLabel("headings.styleTitle"), self)
+        trLabel = self._build.getLabel("headings.styleTitle")
+        self.lblTitle = QLabel(trLabel, self)
         self.centerTitle = NSwitch(self, height=iPx)
+        self.centerTitle.setAccessibleName(f"{trLabel}: {trCentre}")
         self.breakTitle = NSwitch(self, height=iPx)
+        self.breakTitle.setAccessibleName(f"{trLabel}: {trBreak}")
 
         self.layoutMatrix.addWidget(self.lblTitle,    1, 0)
         self.layoutMatrix.addWidget(self.centerTitle, 1, 1, QtAlignCenter)
         self.layoutMatrix.addWidget(self.breakTitle,  1, 2, QtAlignCenter)
 
         # Partition Layout
-        self.lblPart = QLabel(self._build.getLabel("headings.stylePart"), self)
+        trLabel = self._build.getLabel("headings.stylePart")
+        self.lblPart = QLabel(trLabel, self)
         self.centerPart = NSwitch(self, height=iPx)
+        self.centerPart.setAccessibleName(f"{trLabel}: {trCentre}")
         self.breakPart = NSwitch(self, height=iPx)
+        self.breakPart.setAccessibleName(f"{trLabel}: {trBreak}")
 
         self.layoutMatrix.addWidget(self.lblPart,    2, 0)
         self.layoutMatrix.addWidget(self.centerPart, 2, 1, QtAlignCenter)
         self.layoutMatrix.addWidget(self.breakPart,  2, 2, QtAlignCenter)
 
         # Chapter Layout
-        self.lblChapter = QLabel(self._build.getLabel("headings.styleChapter"), self)
+        trLabel = self._build.getLabel("headings.styleChapter")
+        self.lblChapter = QLabel(trLabel, self)
         self.centerChapter = NSwitch(self, height=iPx)
+        self.centerChapter.setAccessibleName(f"{trLabel}: {trCentre}")
         self.breakChapter = NSwitch(self, height=iPx)
+        self.breakChapter.setAccessibleName(f"{trLabel}: {trBreak}")
 
         self.layoutMatrix.addWidget(self.lblChapter,    3, 0)
         self.layoutMatrix.addWidget(self.centerChapter, 3, 1, QtAlignCenter)
         self.layoutMatrix.addWidget(self.breakChapter,  3, 2, QtAlignCenter)
 
         # Scene Layout
-        self.lblScene = QLabel(self._build.getLabel("headings.styleScene"), self)
+        trLabel = self._build.getLabel("headings.styleScene")
+        self.lblScene = QLabel(trLabel, self)
         self.centerScene = NSwitch(self, height=iPx)
+        self.centerScene.setAccessibleName(f"{trLabel}: {trCentre}")
         self.breakScene = NSwitch(self, height=iPx)
+        self.breakScene.setAccessibleName(f"{trLabel}: {trBreak}")
 
         self.layoutMatrix.addWidget(self.lblScene,    4, 0)
         self.layoutMatrix.addWidget(self.centerScene, 4, 1, QtAlignCenter)
@@ -764,9 +783,9 @@ class _HeadingsTab(NScrollablePage):
 
         self.outerBox = QVBoxLayout()
         self.outerBox.addLayout(self.formatBox)
-        self.outerBox.addSpacing(sSp)
+        self.outerBox.addSpacing(16)
         self.outerBox.addLayout(self.editFormBox)
-        self.outerBox.addSpacing(sSp)
+        self.outerBox.addSpacing(16)
         self.outerBox.addLayout(self.layoutMatrix)
         self.outerBox.addStretch(1)
 
@@ -776,12 +795,15 @@ class _HeadingsTab(NScrollablePage):
 
     def loadContent(self) -> None:
         """Populate the widgets."""
-        self.fmtPart.setText(self._build.getStr("headings.fmtPart"))
-        self.fmtChapter.setText(self._build.getStr("headings.fmtChapter"))
-        self.fmtUnnumbered.setText(self._build.getStr("headings.fmtUnnumbered"))
-        self.fmtScene.setText(self._build.getStr("headings.fmtScene"))
-        self.fmtAScene.setText(self._build.getStr("headings.fmtAltScene"))
-        self.fmtSection.setText(self._build.getStr("headings.fmtSection"))
+        def fmtBreak(text: str) -> str:
+            return text.replace(nwHeadFmt.BR, nwUnicode.U_LBREAK)
+
+        self.fmtPart.setText(fmtBreak(self._build.getStr("headings.fmtPart")))
+        self.fmtChapter.setText(fmtBreak(self._build.getStr("headings.fmtChapter")))
+        self.fmtUnnumbered.setText(fmtBreak(self._build.getStr("headings.fmtUnnumbered")))
+        self.fmtScene.setText(fmtBreak(self._build.getStr("headings.fmtScene")))
+        self.fmtAScene.setText(fmtBreak(self._build.getStr("headings.fmtAltScene")))
+        self.fmtSection.setText(fmtBreak(self._build.getStr("headings.fmtSection")))
 
         self.swtPart.setChecked(self._build.getBool("headings.hidePart"))
         self.swtChapter.setChecked(self._build.getBool("headings.hideChapter"))
@@ -861,7 +883,7 @@ class _HeadingsTab(NScrollablePage):
             text = ""
             label = self.tr("None")
 
-        self.editTextBox.setPlainText(text.replace(nwHeadFmt.BR, "\n"))
+        self.editTextBox.setPlainText(text.replace(nwUnicode.U_LBREAK, "\n"))
         self.lblEditForm.setText(self.tr("Editing: {0}").format(label))
 
         return
@@ -874,25 +896,26 @@ class _HeadingsTab(NScrollablePage):
     def _saveFormat(self) -> None:
         """Save the format from the edit text box."""
         heading = self._editing
-        text = self.editTextBox.toPlainText().strip().replace("\n", nwHeadFmt.BR)
+        text = self.editTextBox.toPlainText().strip().replace("\n", nwUnicode.U_LBREAK)
+        value = text.replace(nwUnicode.U_LBREAK, nwHeadFmt.BR)
         if heading == self.EDIT_TITLE:
             self.fmtPart.setText(text)
-            self._build.setValue("headings.fmtPart", text)
+            self._build.setValue("headings.fmtPart", value)
         elif heading == self.EDIT_CHAPTER:
             self.fmtChapter.setText(text)
-            self._build.setValue("headings.fmtChapter", text)
+            self._build.setValue("headings.fmtChapter", value)
         elif heading == self.EDIT_UNNUM:
             self.fmtUnnumbered.setText(text)
-            self._build.setValue("headings.fmtUnnumbered", text)
+            self._build.setValue("headings.fmtUnnumbered", value)
         elif heading == self.EDIT_SCENE:
             self.fmtScene.setText(text)
-            self._build.setValue("headings.fmtScene", text)
+            self._build.setValue("headings.fmtScene", value)
         elif heading == self.EDIT_HSCENE:
             self.fmtAScene.setText(text)
-            self._build.setValue("headings.fmtAltScene", text)
+            self._build.setValue("headings.fmtAltScene", value)
         elif heading == self.EDIT_SECTION:
             self.fmtSection.setText(text)
-            self._build.setValue("headings.fmtSection", text)
+            self._build.setValue("headings.fmtSection", value)
         else:
             return
 
@@ -904,12 +927,13 @@ class _HeadingsTab(NScrollablePage):
 
 class _HeadingSyntaxHighlighter(QSyntaxHighlighter):
 
-    def __init__(self, document: QTextDocument) -> None:
+    def __init__(self, document: QTextDocument | None) -> None:
         super().__init__(document)
+        syntax = SHARED.theme.syntaxTheme
         self._fmtSymbol = QTextCharFormat()
-        self._fmtSymbol.setForeground(SHARED.theme.colHead)
+        self._fmtSymbol.setForeground(syntax.head)
         self._fmtFormat = QTextCharFormat()
-        self._fmtFormat.setForeground(SHARED.theme.colEmph)
+        self._fmtFormat.setForeground(syntax.emph)
         return
 
     def highlightBlock(self, text: str) -> None:
@@ -960,11 +984,15 @@ class _FormattingTab(NScrollableForm):
         self.incBodyText = NSwitch(self, height=iPx)
         self.incSynopsis = NSwitch(self, height=iPx)
         self.incComments = NSwitch(self, height=iPx)
+        self.incStory = NSwitch(self, height=iPx)
+        self.incNotes = NSwitch(self, height=iPx)
         self.incKeywords = NSwitch(self, height=iPx)
 
         self.addRow(self._build.getLabel("text.includeBodyText"), self.incBodyText)
         self.addRow(self._build.getLabel("text.includeSynopsis"), self.incSynopsis)
         self.addRow(self._build.getLabel("text.includeComments"), self.incComments)
+        self.addRow(self._build.getLabel("text.includeStory"), self.incStory)
+        self.addRow(self._build.getLabel("text.includeNotes"), self.incNotes)
         self.addRow(self._build.getLabel("text.includeKeywords"), self.incKeywords)
 
         # Ignored Keywords
@@ -977,7 +1005,7 @@ class _FormattingTab(NScrollableForm):
                 lambda keyword=keyword: self._updateIgnoredKeywords(keyword)
             )
 
-        self.ignoredKeywordsButton = NIconToolButton(self, iSz, "add")
+        self.ignoredKeywordsButton = NIconToolButton(self, iSz, "add", "green")
         self.ignoredKeywordsButton.setMenu(self.mnKeywords)
         self.addRow(
             self._build.getLabel("text.ignoredKeywords"), self.ignoredKeywords,
@@ -986,7 +1014,6 @@ class _FormattingTab(NScrollableForm):
 
         # Note Headings
         self.addNoteHead = NSwitch(self, height=iPx)
-
         self.addRow(self._build.getLabel("text.addNoteHeadings"), self.addNoteHead)
 
         # Text Format
@@ -1063,8 +1090,8 @@ class _FormattingTab(NScrollableForm):
         pixB = SHARED.theme.getPixmap("margin_bottom", (iPx, iPx))
         pixL = SHARED.theme.getPixmap("margin_left", (iPx, iPx))
         pixR = SHARED.theme.getPixmap("margin_right", (iPx, iPx))
-        pixH = SHARED.theme.getPixmap("size_height", (iPx, iPx))
-        pixW = SHARED.theme.getPixmap("size_width", (iPx, iPx))
+        pixH = SHARED.theme.getPixmap("fit_height", (iPx, iPx))
+        pixW = SHARED.theme.getPixmap("fit_width", (iPx, iPx))
 
         # Title
         self.titleMarginT = NDoubleSpinBox(self)
@@ -1177,11 +1204,11 @@ class _FormattingTab(NScrollableForm):
         for key, name in nwLabels.PAPER_NAME.items():
             self.pageSize.addItem(trConst(name), key)
 
-        self.pageWidth = NDoubleSpinBox(self, max=500.0)
+        self.pageWidth = NDoubleSpinBox(self, maxVal=500.0)
         self.pageWidth.setFixedWidth(dbW)
         self.pageWidth.valueChanged.connect(self._pageSizeValueChanged)
 
-        self.pageHeight = NDoubleSpinBox(self, max=500.0)
+        self.pageHeight = NDoubleSpinBox(self, maxVal=500.0)
         self.pageHeight.setFixedWidth(dbW)
         self.pageHeight.valueChanged.connect(self._pageSizeValueChanged)
 
@@ -1222,8 +1249,8 @@ class _FormattingTab(NScrollableForm):
 
         # Header
         self.odtPageHeader = QLineEdit(self)
-        self.odtPageHeader.setMinimumWidth(CONFIG.pxInt(200))
-        self.btnPageHeader = NIconToolButton(self, iSz, "revert")
+        self.odtPageHeader.setMinimumWidth(200)
+        self.btnPageHeader = NIconToolButton(self, iSz, "revert", "green")
         self.btnPageHeader.clicked.connect(self._resetPageHeader)
         self.addRow(
             self._build.getLabel("doc.pageHeader"), self.odtPageHeader,
@@ -1273,6 +1300,8 @@ class _FormattingTab(NScrollableForm):
         self.incBodyText.setChecked(self._build.getBool("text.includeBodyText"))
         self.incSynopsis.setChecked(self._build.getBool("text.includeSynopsis"))
         self.incComments.setChecked(self._build.getBool("text.includeComments"))
+        self.incStory.setChecked(self._build.getBool("text.includeStory"))
+        self.incNotes.setChecked(self._build.getBool("text.includeNotes"))
         self.incKeywords.setChecked(self._build.getBool("text.includeKeywords"))
         self.ignoredKeywords.setText(self._build.getStr("text.ignoredKeywords"))
         self.addNoteHead.setChecked(self._build.getBool("text.addNoteHeadings"))
@@ -1371,6 +1400,8 @@ class _FormattingTab(NScrollableForm):
         self._build.setValue("text.includeBodyText", self.incBodyText.isChecked())
         self._build.setValue("text.includeSynopsis", self.incSynopsis.isChecked())
         self._build.setValue("text.includeComments", self.incComments.isChecked())
+        self._build.setValue("text.includeStory", self.incStory.isChecked())
+        self._build.setValue("text.includeNotes", self.incNotes.isChecked())
         self._build.setValue("text.includeKeywords", self.incKeywords.isChecked())
         self._build.setValue("text.ignoredKeywords", self.ignoredKeywords.text())
         self._build.setValue("text.addNoteHeadings", self.addNoteHead.isChecked())
