@@ -26,24 +26,28 @@ from __future__ import annotations
 import logging
 import math
 
-from PyQt5.QtCore import pyqtSlot
-from PyQt5.QtGui import QCloseEvent
-from PyQt5.QtWidgets import (
+from typing import TYPE_CHECKING
+
+from PyQt6.QtCore import pyqtSlot
+from PyQt6.QtWidgets import (
     QAbstractItemView, QDialogButtonBox, QFormLayout, QGridLayout, QHBoxLayout,
     QLabel, QSpinBox, QStackedWidget, QTreeWidget, QTreeWidgetItem,
     QVBoxLayout, QWidget
 )
 
-from novelwriter import CONFIG, SHARED
+from novelwriter import SHARED
 from novelwriter.common import formatTime, numberToRoman
 from novelwriter.constants import nwUnicode
-from novelwriter.extensions.configlayout import NColourLabel, NFixedPage, NScrollablePage
+from novelwriter.extensions.configlayout import NColorLabel, NFixedPage, NScrollablePage
 from novelwriter.extensions.modified import NNonBlockingDialog
 from novelwriter.extensions.novelselector import NovelSelector
 from novelwriter.extensions.pagedsidebar import NPagedSideBar
 from novelwriter.extensions.switch import NSwitch
 from novelwriter.types import QtAlignRight, QtDecoration, QtDialogClose
 
+if TYPE_CHECKING:
+    from PyQt6.QtGui import QCloseEvent
+
 logger = logging.getLogger(__name__)
 
 
@@ -60,16 +64,16 @@ class GuiNovelDetails(NNonBlockingDialog):
         self.setWindowTitle(self.tr("Novel Details"))
 
         options = SHARED.project.options
-        self.setMinimumSize(CONFIG.pxInt(500), CONFIG.pxInt(400))
+        self.setMinimumSize(500, 400)
         self.resize(
-            CONFIG.pxInt(options.getInt("GuiNovelDetails", "winWidth", CONFIG.pxInt(650))),
-            CONFIG.pxInt(options.getInt("GuiNovelDetails", "winHeight", CONFIG.pxInt(500)))
+            options.getInt("GuiNovelDetails", "winWidth", 650),
+            options.getInt("GuiNovelDetails", "winHeight", 500),
         )
 
         # Title
-        self.titleLabel = NColourLabel(
+        self.titleLabel = NColorLabel(
             self.tr("Novel Details"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE, indent=CONFIG.pxInt(4)
+            scale=NColorLabel.HEADER_SCALE, indent=4,
         )
 
         # Novel Selector
@@ -82,6 +86,7 @@ class GuiNovelDetails(NNonBlockingDialog):
         # SideBar
         self.sidebar = NPagedSideBar(self)
         self.sidebar.setLabelColor(SHARED.theme.helpText)
+        self.sidebar.setAccessibleName(self.titleLabel.text())
         self.sidebar.addButton(self.tr("Overview"), self.PAGE_OVERVIEW)
         self.sidebar.addButton(self.tr("Contents"), self.PAGE_CONTENTS)
         self.sidebar.setSelected(self.PAGE_OVERVIEW)
@@ -114,7 +119,7 @@ class GuiNovelDetails(NNonBlockingDialog):
         self.outerBox.addLayout(self.topBox)
         self.outerBox.addLayout(self.mainBox)
         self.outerBox.addWidget(self.buttonBox)
-        self.outerBox.setSpacing(CONFIG.pxInt(8))
+        self.outerBox.setSpacing(8)
 
         self.setLayout(self.outerBox)
         self.setSizeGripEnabled(True)
@@ -137,9 +142,10 @@ class GuiNovelDetails(NNonBlockingDialog):
 
     def updateValues(self) -> None:
         """Load the dialogs initial values."""
-        self.overviewPage.updateProjectData()
-        self.overviewPage.novelValueChanged(self.novelSelector.handle)
-        self.contentsPage.novelValueChanged(self.novelSelector.handle)
+        if handle := self.novelSelector.handle:
+            self.overviewPage.updateProjectData()
+            self.overviewPage.novelValueChanged(handle)
+            self.contentsPage.novelValueChanged(handle)
         return
 
     ##
@@ -172,18 +178,13 @@ class GuiNovelDetails(NNonBlockingDialog):
 
     def _saveSettings(self) -> None:
         """Save the user GUI settings."""
-        winWidth  = CONFIG.rpxInt(self.width())
-        winHeight = CONFIG.rpxInt(self.height())
-        novelRoot = self.novelSelector.handle
-
         logger.debug("Saving State: GuiNovelDetails")
+        novelRoot = self.novelSelector.handle
         options = SHARED.project.options
-        options.setValue("GuiNovelDetails", "winWidth", winWidth)
-        options.setValue("GuiNovelDetails", "winHeight", winHeight)
+        options.setValue("GuiNovelDetails", "winWidth", self.width())
+        options.setValue("GuiNovelDetails", "winHeight", self.height())
         options.setValue("GuiNovelDetails", "novelRoot", novelRoot)
-
         self.contentsPage.saveSettings()
-
         return
 
 
@@ -192,15 +193,10 @@ class _OverviewPage(NScrollablePage):
     def __init__(self, parent: QWidget) -> None:
         super().__init__(parent=parent)
 
-        mPx = CONFIG.pxInt(8)
-        sPx = CONFIG.pxInt(16)
-        hPx = CONFIG.pxInt(24)
-        vPx = CONFIG.pxInt(4)
-
         # Project Info
-        self.projLabel = NColourLabel(
+        self.projLabel = NColorLabel(
             self.tr("Project"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE
+            scale=NColorLabel.HEADER_SCALE
         )
 
         self.projName = QLabel("", self)
@@ -217,14 +213,14 @@ class _OverviewPage(NScrollablePage):
         self.projForm.addRow("<b>{0}</b>".format(self.tr("Word Count")), self.projWords)
         self.projForm.addRow("<b>\u2026 {0}</b>".format(self.tr("In Novels")), self.projNovels)
         self.projForm.addRow("<b>\u2026 {0}</b>".format(self.tr("In Notes")), self.projNotes)
-        self.projForm.setContentsMargins(mPx, 0, 0, 0)
-        self.projForm.setHorizontalSpacing(hPx)
-        self.projForm.setVerticalSpacing(vPx)
+        self.projForm.setContentsMargins(8, 0, 0, 0)
+        self.projForm.setHorizontalSpacing(24)
+        self.projForm.setVerticalSpacing(4)
 
         # Novel Info
-        self.novelLabel = NColourLabel(
+        self.novelLabel = NColorLabel(
             self.tr("Selected Novel"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE
+            scale=NColorLabel.HEADER_SCALE
         )
 
         self.novelName = QLabel("", self)
@@ -237,9 +233,9 @@ class _OverviewPage(NScrollablePage):
         self.novelForm.addRow("<b>{0}</b>".format(self.tr("Word Count")), self.novelWords)
         self.novelForm.addRow("<b>{0}</b>".format(self.tr("Chapters")), self.novelChapters)
         self.novelForm.addRow("<b>{0}</b>".format(self.tr("Scenes")), self.novelScenes)
-        self.novelForm.setContentsMargins(mPx, 0, 0, 0)
-        self.novelForm.setHorizontalSpacing(hPx)
-        self.novelForm.setVerticalSpacing(vPx)
+        self.novelForm.setContentsMargins(8, 0, 0, 0)
+        self.novelForm.setHorizontalSpacing(24)
+        self.novelForm.setVerticalSpacing(4)
 
         # Assemble
         self.outerBox = QVBoxLayout()
@@ -247,7 +243,7 @@ class _OverviewPage(NScrollablePage):
         self.outerBox.addLayout(self.projForm)
         self.outerBox.addWidget(self.novelLabel)
         self.outerBox.addLayout(self.novelForm)
-        self.outerBox.setSpacing(sPx)
+        self.outerBox.setSpacing(16)
         self.outerBox.addStretch(1)
 
         self.setCentralLayout(self.outerBox)
@@ -261,8 +257,8 @@ class _OverviewPage(NScrollablePage):
     def updateProjectData(self) -> None:
         """Load information about the project."""
         project = SHARED.project
-        project.updateWordCounts()
-        wcNovel, wcNotes = project.data.currCounts
+        project.updateCounts()
+        wcNovel, wcNotes, _, _ = project.data.currCounts
 
         self.projName.setText(project.data.name)
         self.projRevisions.setText(f"{project.data.saveCount:n}")
@@ -309,14 +305,12 @@ class _ContentsPage(NFixedPage):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        hPx = CONFIG.pxInt(12)
-        vPx = CONFIG.pxInt(4)
         options = SHARED.project.options
 
         # Title
-        self.contentLabel = NColourLabel(
+        self.contentLabel = NColorLabel(
             self.tr("Table of Contents"), self, color=SHARED.theme.helpText,
-            scale=NColourLabel.HEADER_SCALE
+            scale=NColorLabel.HEADER_SCALE
         )
 
         # Contents Tree
@@ -341,38 +335,36 @@ class _ContentsPage(NFixedPage):
             treeHeadItem.setTextAlignment(self.C_PAGE,  QtAlignRight)
             treeHeadItem.setTextAlignment(self.C_PROG,  QtAlignRight)
 
-        treeHeader = self.tocTree.header()
-        treeHeader.setStretchLastSection(True)
-        treeHeader.setMinimumSectionSize(hPx)
+        if header := self.tocTree.header():
+            header.setStretchLastSection(True)
+            header.setMinimumSectionSize(12)
 
-        wCol0 = CONFIG.pxInt(options.getInt("GuiNovelDetails", "widthCol0", 200))
-        wCol1 = CONFIG.pxInt(options.getInt("GuiNovelDetails", "widthCol1", 60))
-        wCol2 = CONFIG.pxInt(options.getInt("GuiNovelDetails", "widthCol2", 60))
-        wCol3 = CONFIG.pxInt(options.getInt("GuiNovelDetails", "widthCol3", 60))
-        wCol4 = CONFIG.pxInt(options.getInt("GuiNovelDetails", "widthCol4", 90))
+        wCol0 = options.getInt("GuiNovelDetails", "widthCol0", 200)
+        wCol1 = options.getInt("GuiNovelDetails", "widthCol1", 60)
+        wCol2 = options.getInt("GuiNovelDetails", "widthCol2", 60)
+        wCol3 = options.getInt("GuiNovelDetails", "widthCol3", 60)
+        wCol4 = options.getInt("GuiNovelDetails", "widthCol4", 90)
 
         self.tocTree.setColumnWidth(0, wCol0)
         self.tocTree.setColumnWidth(1, wCol1)
         self.tocTree.setColumnWidth(2, wCol2)
         self.tocTree.setColumnWidth(3, wCol3)
         self.tocTree.setColumnWidth(4, wCol4)
-        self.tocTree.setColumnWidth(5, hPx)
+        self.tocTree.setColumnWidth(5, 12)
 
         # Options
         wordsPerPage = options.getInt("GuiNovelDetails", "wordsPerPage", 350)
         countFrom    = options.getInt("GuiNovelDetails", "countFrom", 1)
         clearDouble  = options.getBool("GuiNovelDetails", "clearDouble", True)
 
-        self.wpLabel = QLabel(self.tr("Words per page"), self)
-
         self.wpValue = QSpinBox(self)
         self.wpValue.setMinimum(10)
         self.wpValue.setMaximum(1000)
         self.wpValue.setSingleStep(10)
         self.wpValue.setValue(wordsPerPage)
         self.wpValue.valueChanged.connect(self._populateTree)
-
-        self.poLabel = QLabel(self.tr("First page offset"), self)
+        self.wpLabel = QLabel(self.tr("Words per page"), self)
+        self.wpLabel.setBuddy(self.wpValue)
 
         self.poValue = QSpinBox(self)
         self.poValue.setMinimum(1)
@@ -380,12 +372,14 @@ class _ContentsPage(NFixedPage):
         self.poValue.setSingleStep(1)
         self.poValue.setValue(countFrom)
         self.poValue.valueChanged.connect(self._populateTree)
-
-        self.dblLabel = QLabel(self.tr("Chapters on odd pages"), self)
+        self.poLabel = QLabel(self.tr("First page offset"), self)
+        self.poLabel.setBuddy(self.poValue)
 
         self.dblValue = NSwitch(self, height=iPx)
         self.dblValue.setChecked(clearDouble)
         self.dblValue.clicked.connect(self._populateTree)
+        self.dblLabel = QLabel(self.tr("Chapters on odd pages"), self)
+        self.dblLabel.setBuddy(self.dblValue)
 
         self.optionsBox = QGridLayout()
         self.optionsBox.addWidget(self.wpLabel,  0, 0)
@@ -394,8 +388,8 @@ class _ContentsPage(NFixedPage):
         self.optionsBox.addWidget(self.dblValue, 0, 4)
         self.optionsBox.addWidget(self.poLabel,  1, 0)
         self.optionsBox.addWidget(self.poValue,  1, 1)
-        self.optionsBox.setHorizontalSpacing(hPx)
-        self.optionsBox.setVerticalSpacing(vPx)
+        self.optionsBox.setHorizontalSpacing(12)
+        self.optionsBox.setVerticalSpacing(4)
         self.optionsBox.setColumnStretch(2, 1)
 
         # Assemble
@@ -410,18 +404,12 @@ class _ContentsPage(NFixedPage):
 
     def saveSettings(self) -> None:
         """Save the user GUI settings."""
-        widthCol0 = CONFIG.rpxInt(self.tocTree.columnWidth(0))
-        widthCol1 = CONFIG.rpxInt(self.tocTree.columnWidth(1))
-        widthCol2 = CONFIG.rpxInt(self.tocTree.columnWidth(2))
-        widthCol3 = CONFIG.rpxInt(self.tocTree.columnWidth(3))
-        widthCol4 = CONFIG.rpxInt(self.tocTree.columnWidth(4))
-
         options = SHARED.project.options
-        options.setValue("GuiNovelDetails", "widthCol0",    widthCol0)
-        options.setValue("GuiNovelDetails", "widthCol1",    widthCol1)
-        options.setValue("GuiNovelDetails", "widthCol2",    widthCol2)
-        options.setValue("GuiNovelDetails", "widthCol3",    widthCol3)
-        options.setValue("GuiNovelDetails", "widthCol4",    widthCol4)
+        options.setValue("GuiNovelDetails", "widthCol0",    self.tocTree.columnWidth(0))
+        options.setValue("GuiNovelDetails", "widthCol1",    self.tocTree.columnWidth(1))
+        options.setValue("GuiNovelDetails", "widthCol2",    self.tocTree.columnWidth(2))
+        options.setValue("GuiNovelDetails", "widthCol3",    self.tocTree.columnWidth(3))
+        options.setValue("GuiNovelDetails", "widthCol4",    self.tocTree.columnWidth(4))
         options.setValue("GuiNovelDetails", "wordsPerPage", self.wpValue.value())
         options.setValue("GuiNovelDetails", "countFrom",    self.poValue.value())
         options.setValue("GuiNovelDetails", "clearDouble",  self.dblValue.isChecked())
