@@ -28,20 +28,19 @@ import logging
 from datetime import datetime
 from pathlib import Path
 
-from PyQt5.QtCore import (
-    QAbstractListModel, QEvent, QModelIndex, QObject, QPoint, QSize, Qt,
-    pyqtSignal, pyqtSlot
+from PyQt6.QtCore import (
+    QAbstractListModel, QModelIndex, QObject, QPoint, QSize, Qt, pyqtSignal,
+    pyqtSlot
 )
-from PyQt5.QtGui import QCloseEvent, QColor, QFont, QPainter, QPaintEvent, QPen
-from PyQt5.QtWidgets import (
-    QAction, QApplication, QFileDialog, QFormLayout, QHBoxLayout, QLabel,
-    QLineEdit, QListView, QMenu, QPushButton, QScrollArea, QShortcut,
-    QStackedWidget, QStyledItemDelegate, QStyleOptionViewItem, QVBoxLayout,
-    QWidget
+from PyQt6.QtGui import QAction, QCloseEvent, QColor, QFont, QPainter, QPaintEvent, QPen, QShortcut
+from PyQt6.QtWidgets import (
+    QApplication, QFileDialog, QFormLayout, QHBoxLayout, QLabel, QLineEdit,
+    QListView, QMenu, QPushButton, QScrollArea, QStackedWidget,
+    QStyledItemDelegate, QStyleOptionViewItem, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import cssCol, formatInt, makeFileNameSafe
+from novelwriter.common import formatInt, makeFileNameSafe, qtAddAction, qtLambda
 from novelwriter.constants import nwFiles
 from novelwriter.core.coretools import ProjectBuilder
 from novelwriter.enum import nwItemClass
@@ -49,7 +48,7 @@ from novelwriter.extensions.configlayout import NWrappedWidgetBox
 from novelwriter.extensions.modified import NDialog, NIconToolButton, NSpinBox
 from novelwriter.extensions.switch import NSwitch
 from novelwriter.extensions.versioninfo import VersionInfoWidget
-from novelwriter.types import QtAlignLeft, QtAlignRightTop, QtScrollAsNeeded, QtSelected
+from novelwriter.types import QtAlignLeft, QtAlignRightTop, QtHexArgb, QtScrollAsNeeded, QtSelected
 
 logger = logging.getLogger(__name__)
 
@@ -67,29 +66,21 @@ class GuiWelcome(NDialog):
         self.setObjectName("GuiWelcome")
 
         self.setWindowTitle(self.tr("Welcome"))
-        self.setMinimumWidth(CONFIG.pxInt(650))
-        self.setMinimumHeight(CONFIG.pxInt(450))
-
-        hA = CONFIG.pxInt(8)
-        hB = CONFIG.pxInt(16)
-        hC = CONFIG.pxInt(24)
-        hD = CONFIG.pxInt(36)
-        hE = CONFIG.pxInt(48)
-        hF = CONFIG.pxInt(128)
-        btnIconSize = SHARED.theme.buttonIconSize
-
-        self._hPx = CONFIG.pxInt(600)
+        self.setMinimumWidth(650)
+        self.setMinimumHeight(450)
         self.resize(*CONFIG.welcomeWinSize)
 
+        btnIconSize = SHARED.theme.buttonIconSize
+
         # Elements
         # ========
 
-        self.bgImage = SHARED.theme.loadDecoration("welcome")
-        self.nwImage = SHARED.theme.loadDecoration("nw-text", h=hD)
-        self.bgColor = QColor(255, 255, 255) if SHARED.theme.isLightTheme else QColor(54, 54, 54)
+        self.bgImage = SHARED.theme.getDecoration("welcome")
+        self.nwImage = SHARED.theme.getDecoration("nw-text", h=36)
+        self.bgColor = QColor(54, 54, 54) if SHARED.theme.isDarkTheme else QColor(255, 255, 255)
 
         self.nwLogo = QLabel(self)
-        self.nwLogo.setPixmap(SHARED.theme.getPixmap("novelwriter", (hF, hF)))
+        self.nwLogo.setPixmap(SHARED.theme.getPixmap("novelwriter", (128, 128)))
 
         self.nwLabel = QLabel(self)
         self.nwLabel.setPixmap(self.nwImage)
@@ -110,32 +101,32 @@ class GuiWelcome(NDialog):
         # =======
 
         self.btnList = QPushButton(self.tr("List"), self)
-        self.btnList.setIcon(SHARED.theme.getIcon("list"))
+        self.btnList.setIcon(SHARED.theme.getIcon("list", "blue"))
         self.btnList.setIconSize(btnIconSize)
         self.btnList.clicked.connect(self._showOpenProjectPage)
 
         self.btnNew = QPushButton(self.tr("New"), self)
-        self.btnNew.setIcon(SHARED.theme.getIcon("add"))
+        self.btnNew.setIcon(SHARED.theme.getIcon("add", "green"))
         self.btnNew.setIconSize(btnIconSize)
         self.btnNew.clicked.connect(self._showNewProjectPage)
 
         self.btnBrowse = QPushButton(self.tr("Browse"), self)
-        self.btnBrowse.setIcon(SHARED.theme.getIcon("browse"))
+        self.btnBrowse.setIcon(SHARED.theme.getIcon("browse", "yellow"))
         self.btnBrowse.setIconSize(btnIconSize)
         self.btnBrowse.clicked.connect(self._browseForProject)
 
         self.btnCancel = QPushButton(self.tr("Cancel"), self)
-        self.btnCancel.setIcon(SHARED.theme.getIcon("cross"))
+        self.btnCancel.setIcon(SHARED.theme.getIcon("cancel", "red"))
         self.btnCancel.setIconSize(btnIconSize)
-        self.btnCancel.clicked.connect(self.close)
+        self.btnCancel.clicked.connect(qtLambda(self.close))
 
         self.btnCreate = QPushButton(self.tr("Create"), self)
-        self.btnCreate.setIcon(SHARED.theme.getIcon("star"))
+        self.btnCreate.setIcon(SHARED.theme.getIcon("star", "yellow"))
         self.btnCreate.setIconSize(btnIconSize)
         self.btnCreate.clicked.connect(self.tabNew.createNewProject)
 
         self.btnOpen = QPushButton(self.tr("Open"), self)
-        self.btnOpen.setIcon(SHARED.theme.getIcon("open"))
+        self.btnOpen.setIcon(SHARED.theme.getIcon("open", "blue"))
         self.btnOpen.setIconSize(btnIconSize)
         self.btnOpen.clicked.connect(self._openSelectedItem)
 
@@ -153,18 +144,18 @@ class GuiWelcome(NDialog):
         # ========
 
         self.innerBox = QVBoxLayout()
-        self.innerBox.addSpacing(hB)
+        self.innerBox.addSpacing(16)
         self.innerBox.addWidget(self.nwLabel)
         self.innerBox.addWidget(self.nwInfo)
-        self.innerBox.addSpacing(hA)
+        self.innerBox.addSpacing(8)
         self.innerBox.addWidget(self.mainStack)
-        self.innerBox.addSpacing(hB)
+        self.innerBox.addSpacing(16)
         self.innerBox.addLayout(self.btnBox)
 
         self.outerBox = QHBoxLayout()
         self.outerBox.addWidget(self.nwLogo, 3, QtAlignRightTop)
         self.outerBox.addLayout(self.innerBox, 9)
-        self.outerBox.setContentsMargins(hF, hE, hC, hE)
+        self.outerBox.setContentsMargins(128, 48, 24, 48)
 
         self.setLayout(self.outerBox)
         self.setSizeGripEnabled(True)
@@ -184,7 +175,7 @@ class GuiWelcome(NDialog):
     def paintEvent(self, event: QPaintEvent) -> None:
         """Overload the paint event to draw the background image."""
         hWin = self.height()
-        hPix = min(hWin, self._hPx)
+        hPix = min(hWin, 600)
         tMode = Qt.TransformationMode.SmoothTransformation
         painter = QPainter(self)
         painter.fillRect(self.rect(), self.bgColor)
@@ -289,7 +280,7 @@ class _OpenProjectPage(QWidget):
 
         # Info / Tool
         self.aMissing = QAction(self)
-        self.aMissing.setIcon(SHARED.theme.getIcon("alert_warn"))
+        self.aMissing.setIcon(SHARED.theme.getIcon("alert_warn", "orange"))
         self.aMissing.setToolTip(self.tr("The project path is not reachable."))
 
         self.selectedPath = QLineEdit(self)
@@ -310,11 +301,12 @@ class _OpenProjectPage(QWidget):
 
         self._selectFirstItem()
 
-        mPx = CONFIG.pxInt(4)
-        baseCol = cssCol(self.palette().base().color(), PANEL_ALPHA)
+        base = self.palette().base().color()
+        base.setAlpha(PANEL_ALPHA)
+        baseCol = base.name(QtHexArgb)
         self.setStyleSheet(
             f"QListView {{border: none; background: {baseCol};}} "
-            f"QLineEdit {{border: none; background: {baseCol}; padding: {mPx}px;}} "
+            f"QLineEdit {{border: none; background: {baseCol}; padding: 4px;}} "
         )
 
         return
@@ -371,9 +363,9 @@ class _OpenProjectPage(QWidget):
         """Open the custom context menu."""
         ctxMenu = QMenu(self)
         ctxMenu.setObjectName("ContextMenu")  # Used for testing
-        action = ctxMenu.addAction(self.tr("Open Project"))
+        action = qtAddAction(ctxMenu, self.tr("Open Project"))
         action.triggered.connect(self.openSelectedItem)
-        action = ctxMenu.addAction(self.tr("Remove Project"))
+        action = qtAddAction(ctxMenu, self.tr("Remove Project"))
         action.triggered.connect(self._deleteSelectedItem)
         ctxMenu.exec(self.mapToGlobal(pos))
         ctxMenu.setParent(None)
@@ -393,7 +385,7 @@ class _OpenProjectPage(QWidget):
 
 class _ProjectListItem(QStyledItemDelegate):
 
-    __slots__ = ("_pPx", "_hPx", "_tFont", "_dFont", "_dPen", "_icon")
+    __slots__ = ("_dFont", "_dPen", "_hPx", "_icon", "_pPx", "_tFont")
 
     def __init__(self, parent: QWidget) -> None:
         super().__init__(parent=parent)
@@ -401,11 +393,10 @@ class _ProjectListItem(QStyledItemDelegate):
         fPx = SHARED.theme.fontPixelSize
         fPt = SHARED.theme.fontPointSize
         tPx = round(1.2 * fPx)
-        mPx = CONFIG.pxInt(4)
         iPx = tPx + fPx
 
-        self._pPx = (mPx//2, 3*mPx//2, iPx + mPx, mPx, mPx + tPx)  # Painter coordinates
-        self._hPx = 2*mPx + tPx + fPx  # Fixed height
+        self._pPx = (iPx + 4, tPx + 4)  # Painter coordinates
+        self._hPx = 8 + tPx + fPx  # Fixed height
 
         self._tFont = QApplication.font()
         self._tFont.setPointSizeF(1.2*fPt)
@@ -424,7 +415,7 @@ class _ProjectListItem(QStyledItemDelegate):
         rect = opt.rect
         title, _, details = index.data()
         tFlag = Qt.TextFlag.TextSingleLine
-        ix, iy, x, y1, y2 = self._pPx
+        x, y = self._pPx
 
         painter.save()
         if opt.state & QtSelected == QtSelected:
@@ -432,12 +423,12 @@ class _ProjectListItem(QStyledItemDelegate):
             painter.fillRect(rect, QApplication.palette().highlight())
             painter.setOpacity(1.0)
 
-        painter.drawPixmap(ix, rect.top() + iy, self._icon)
+        painter.drawPixmap(2, rect.top() + 6, self._icon)
         painter.setFont(self._tFont)
-        painter.drawText(rect.adjusted(x, y1, 0, 0), tFlag, title)
+        painter.drawText(rect.adjusted(x, 4, 0, 0), tFlag, title)
         painter.setFont(self._dFont)
         painter.setPen(self._dPen)
-        painter.drawText(rect.adjusted(x, y2, 0, 0), tFlag, details)
+        painter.drawText(rect.adjusted(x, y, 0, 0), tFlag, details)
         painter.restore()
 
         return
@@ -518,7 +509,9 @@ class _NewProjectPage(QWidget):
         # Styles
         # ======
 
-        baseCol = cssCol(self.palette().base().color(), PANEL_ALPHA)
+        base = self.palette().base().color()
+        base.setAlpha(PANEL_ALPHA)
+        baseCol = base.name(QtHexArgb)
         self.setStyleSheet(
             f"QScrollArea {{border: none; background: {baseCol};}} "
             f"_NewProjectForm {{border: none; background: {baseCol};}} "
@@ -558,7 +551,6 @@ class _NewProjectForm(QWidget):
 
         iPx = SHARED.theme.baseIconHeight
         iSz = SHARED.theme.baseIconSize
-        sPx = CONFIG.pxInt(16)
 
         # Project Settings
         # ================
@@ -573,6 +565,7 @@ class _NewProjectForm(QWidget):
         self.projAuthor = QLineEdit(self)
         self.projAuthor.setMaxLength(200)
         self.projAuthor.setPlaceholderText(self.tr("Optional"))
+        self.projAuthor.setText(CONFIG.lastAuthor)
 
         # Project Path
         self.projPath = QLineEdit(self)
@@ -589,20 +582,20 @@ class _NewProjectForm(QWidget):
         self.projFill = QLineEdit(self)
         self.projFill.setReadOnly(True)
 
-        self.browseFill = NIconToolButton(self, iSz, "add_document")
+        self.browseFill = NIconToolButton(self, iSz, "document_add", "blue")
 
-        self.fillMenu = _PopLeftDirectionMenu(self.browseFill)
+        self.fillMenu = QMenu(self.browseFill)
 
-        self.fillBlank = self.fillMenu.addAction(self.tr("Create a fresh project"))
+        self.fillBlank = qtAddAction(self.fillMenu, self.tr("Create a fresh project"))
         self.fillBlank.setIcon(SHARED.theme.getIcon("document"))
         self.fillBlank.triggered.connect(self._setFillBlank)
 
-        self.fillSample = self.fillMenu.addAction(self.tr("Create an example project"))
-        self.fillSample.setIcon(SHARED.theme.getIcon("add_document"))
+        self.fillSample = qtAddAction(self.fillMenu, self.tr("Create an example project"))
+        self.fillSample.setIcon(SHARED.theme.getIcon("document_add", "blue"))
         self.fillSample.triggered.connect(self._setFillSample)
 
-        self.fillCopy = self.fillMenu.addAction(self.tr("Copy an existing project"))
-        self.fillCopy.setIcon(SHARED.theme.getIcon("browse"))
+        self.fillCopy = qtAddAction(self.fillMenu, self.tr("Copy an existing project"))
+        self.fillCopy.setIcon(SHARED.theme.getIcon("project_copy", "green"))
         self.fillCopy.triggered.connect(self._setFillCopy)
 
         self.browseFill.setMenu(self.fillMenu)
@@ -676,7 +669,7 @@ class _NewProjectForm(QWidget):
         self.extraBox = QVBoxLayout()
         self.extraBox.addWidget(QLabel("<b>{0}</b>".format(self.tr("Chapters and Scenes")), self))
         self.extraBox.addLayout(self.novelForm)
-        self.extraBox.addSpacing(sPx)
+        self.extraBox.addSpacing(16)
         self.extraBox.addWidget(QLabel("<b>{0}</b>".format(self.tr("Project Notes")), self))
         self.extraBox.addLayout(self.notesForm)
         self.extraBox.setContentsMargins(0, 0, 0, 0)
@@ -688,7 +681,7 @@ class _NewProjectForm(QWidget):
         self.formBox = QVBoxLayout()
         self.formBox.addWidget(QLabel("<b>{0}</b>".format(self.tr("Create New Project")), self))
         self.formBox.addLayout(self.projectForm)
-        self.formBox.addSpacing(sPx)
+        self.formBox.addSpacing(16)
         self.formBox.addWidget(self.extraWidget)
         self.formBox.addStretch(1)
 
@@ -803,14 +796,3 @@ class _NewProjectForm(QWidget):
         self.extraWidget.setVisible(self._fillMode == self.FILL_BLANK)
 
         return
-
-
-class _PopLeftDirectionMenu(QMenu):
-
-    def event(self, event: QEvent) -> bool:
-        """Overload the show event and move the menu popup location."""
-        if event.type() == QEvent.Type.Show:
-            if isinstance(parent := self.parent(), QWidget):
-                offset = QPoint(parent.width() - self.width(), parent.height())
-                self.move(parent.mapToGlobal(offset))
-        return super(_PopLeftDirectionMenu, self).event(event)
