@@ -29,12 +29,11 @@ import logging
 from datetime import datetime
 from typing import TYPE_CHECKING
 
-from PyQt5.QtCore import Qt, pyqtSlot
-from PyQt5.QtGui import QCloseEvent, QCursor, QPixmap
-from PyQt5.QtWidgets import (
-    QAction, QApplication, QDialogButtonBox, QFileDialog, QGridLayout,
-    QGroupBox, QHBoxLayout, QLabel, QMenu, QSpinBox, QTreeWidget,
-    QTreeWidgetItem
+from PyQt6.QtCore import Qt, pyqtSlot
+from PyQt6.QtGui import QAction, QCloseEvent, QCursor, QPixmap
+from PyQt6.QtWidgets import (
+    QApplication, QDialogButtonBox, QFileDialog, QGridLayout, QGroupBox,
+    QHBoxLayout, QLabel, QMenu, QSpinBox, QTreeWidget, QTreeWidgetItem
 )
 
 from novelwriter import CONFIG, SHARED
@@ -48,7 +47,7 @@ from novelwriter.types import (
     QtDialogClose, QtRoleAction
 )
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from novelwriter.guimain import GuiMain
 
 logger = logging.getLogger(__name__)
@@ -83,26 +82,18 @@ class GuiWritingStats(NToolDialog):
         pOptions = SHARED.project.options
 
         self.setWindowTitle(self.tr("Writing Statistics"))
-        self.setMinimumWidth(CONFIG.pxInt(420))
-        self.setMinimumHeight(CONFIG.pxInt(400))
+        self.setMinimumWidth(420)
+        self.setMinimumHeight(400)
         self.resize(
-            CONFIG.pxInt(pOptions.getInt("GuiWritingStats", "winWidth",  550)),
-            CONFIG.pxInt(pOptions.getInt("GuiWritingStats", "winHeight", 500))
+            pOptions.getInt("GuiWritingStats", "winWidth", 550),
+            pOptions.getInt("GuiWritingStats", "winHeight", 500),
         )
 
         # List Box
-        wCol0 = CONFIG.pxInt(
-            pOptions.getInt("GuiWritingStats", "widthCol0", 180)
-        )
-        wCol1 = CONFIG.pxInt(
-            pOptions.getInt("GuiWritingStats", "widthCol1", 80)
-        )
-        wCol2 = CONFIG.pxInt(
-            pOptions.getInt("GuiWritingStats", "widthCol2", 80)
-        )
-        wCol3 = CONFIG.pxInt(
-            pOptions.getInt("GuiWritingStats", "widthCol3", 80)
-        )
+        wCol0 = pOptions.getInt("GuiWritingStats", "widthCol0", 180)
+        wCol1 = pOptions.getInt("GuiWritingStats", "widthCol1", 80)
+        wCol2 = pOptions.getInt("GuiWritingStats", "widthCol2", 80)
+        wCol3 = pOptions.getInt("GuiWritingStats", "widthCol3", 80)
 
         self.listBox = QTreeWidget(self)
         self.listBox.setHeaderLabels([
@@ -124,18 +115,16 @@ class GuiWritingStats(NToolDialog):
             hHeader.setTextAlignment(self.C_IDLE, QtAlignRight)
             hHeader.setTextAlignment(self.C_COUNT, QtAlignRight)
 
-        sDec = Qt.SortOrder.DescendingOrder
-        sAsc = Qt.SortOrder.AscendingOrder
         sortCol = minmax(pOptions.getInt("GuiWritingStats", "sortCol", 0), 0, 2)
         sortOrder = checkIntTuple(
-            pOptions.getInt("GuiWritingStats", "sortOrder", sDec), (sAsc, sDec), sDec
+            pOptions.getInt("GuiWritingStats", "sortOrder", 1), (0, 1), 1
         )
-        self.listBox.sortByColumn(sortCol, sortOrder)  # type: ignore
+        sortOrders = (Qt.SortOrder.AscendingOrder, Qt.SortOrder.DescendingOrder)
+        self.listBox.sortByColumn(sortCol, sortOrders[sortOrder])
         self.listBox.setSortingEnabled(True)
 
         # Word Bar
-        self.barHeight = int(round(0.5*SHARED.theme.fontPixelSize))
-        self.barWidth = CONFIG.pxInt(200)
+        self.barHeight = round(0.5*SHARED.theme.fontPixelSize)
         self.barImage = QPixmap(self.barHeight, self.barHeight)
         self.barImage.fill(self.palette().highlight().color())
 
@@ -194,59 +183,82 @@ class GuiWritingStats(NToolDialog):
         # Filter Options
         iPx = SHARED.theme.baseIconHeight
 
-        self.filterBox = QGroupBox(self.tr("Filters"), self)
         self.filterForm = QGridLayout(self)
+        self.filterForm.setRowStretch(6, 1)
+        self.filterBox = QGroupBox(self.tr("Filters"), self)
         self.filterBox.setLayout(self.filterForm)
 
-        self.incNovel = NSwitch(self, height=iPx)
-        self.incNovel.setChecked(
+        # Include Novel Files
+        self.swtIncNovel = NSwitch(self, height=iPx)
+        self.swtIncNovel.setChecked(
             pOptions.getBool("GuiWritingStats", "incNovel", True)
         )
-        self.incNovel.clicked.connect(self._updateListBox)
+        self.swtIncNovel.clicked.connect(self._updateListBox)
+        self.lblIncNovel = QLabel(self.tr("Count novel files"), self)
+        self.lblIncNovel.setBuddy(self.swtIncNovel)
 
-        self.incNotes = NSwitch(self, height=iPx)
-        self.incNotes.setChecked(
+        self.filterForm.addWidget(self.lblIncNovel, 0, 0)
+        self.filterForm.addWidget(self.swtIncNovel, 0, 1)
+
+        # Include Note Files
+        self.swtIncNotes = NSwitch(self, height=iPx)
+        self.swtIncNotes.setChecked(
             pOptions.getBool("GuiWritingStats", "incNotes", True)
         )
-        self.incNotes.clicked.connect(self._updateListBox)
+        self.swtIncNotes.clicked.connect(self._updateListBox)
+        self.lblIncNotes = QLabel(self.tr("Count note files"), self)
+        self.lblIncNotes.setBuddy(self.swtIncNotes)
 
-        self.hideZeros = NSwitch(self, height=iPx)
-        self.hideZeros.setChecked(
+        self.filterForm.addWidget(self.lblIncNotes, 1, 0)
+        self.filterForm.addWidget(self.swtIncNotes, 1, 1)
+
+        # Hide Zero Counts
+        self.swtHideZeros = NSwitch(self, height=iPx)
+        self.swtHideZeros.setChecked(
             pOptions.getBool("GuiWritingStats", "hideZeros", True)
         )
-        self.hideZeros.clicked.connect(self._updateListBox)
+        self.swtHideZeros.clicked.connect(self._updateListBox)
+        self.lblHideZeros = QLabel(self.tr("Hide zero word count"), self)
+        self.lblHideZeros.setBuddy(self.swtHideZeros)
 
-        self.hideNegative = NSwitch(self, height=iPx)
-        self.hideNegative.setChecked(
+        self.filterForm.addWidget(self.lblHideZeros, 2, 0)
+        self.filterForm.addWidget(self.swtHideZeros, 2, 1)
+
+        # Hide Negative Counts
+        self.swtHideNegative = NSwitch(self, height=iPx)
+        self.swtHideNegative.setChecked(
             pOptions.getBool("GuiWritingStats", "hideNegative", False)
         )
-        self.hideNegative.clicked.connect(self._updateListBox)
+        self.swtHideNegative.clicked.connect(self._updateListBox)
+        self.lblHideNegative = QLabel(self.tr("Hide negative word count"), self)
+        self.lblHideNegative.setBuddy(self.swtHideNegative)
 
-        self.groupByDay = NSwitch(self, height=iPx)
-        self.groupByDay.setChecked(
+        self.filterForm.addWidget(self.lblHideNegative, 3, 0)
+        self.filterForm.addWidget(self.swtHideNegative, 3, 1)
+
+        # Group Entries
+        self.swtGroupByDay = NSwitch(self, height=iPx)
+        self.swtGroupByDay.setChecked(
             pOptions.getBool("GuiWritingStats", "groupByDay", False)
         )
-        self.groupByDay.clicked.connect(self._updateListBox)
+        self.swtGroupByDay.clicked.connect(self._updateListBox)
+        self.lblGroupByDay = QLabel(self.tr("Group entries by day"), self)
+        self.lblGroupByDay.setBuddy(self.swtGroupByDay)
 
-        self.showIdleTime = NSwitch(self, height=iPx)
-        self.showIdleTime.setChecked(
+        self.filterForm.addWidget(self.lblGroupByDay, 4, 0)
+        self.filterForm.addWidget(self.swtGroupByDay, 4, 1)
+
+        # Show Idle
+        self.swtShowIdleTime = NSwitch(self, height=iPx)
+        self.swtShowIdleTime.setChecked(
             pOptions.getBool("GuiWritingStats", "showIdleTime", False)
         )
-        self.showIdleTime.clicked.connect(self._updateListBox)
+        self.swtShowIdleTime.clicked.connect(self._updateListBox)
+        self.lblShowIdleTime = QLabel(self.tr("Show idle time"), self)
+        self.lblShowIdleTime.setBuddy(self.swtShowIdleTime)
 
-        self.filterForm.addWidget(QLabel(self.tr("Count novel files"), self),        0, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Count note files"), self),         1, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Hide zero word count"), self),     2, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Hide negative word count"), self), 3, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Group entries by day"), self),     4, 0)
-        self.filterForm.addWidget(QLabel(self.tr("Show idle time"), self),           5, 0)
-        self.filterForm.addWidget(self.incNovel,     0, 1)
-        self.filterForm.addWidget(self.incNotes,     1, 1)
-        self.filterForm.addWidget(self.hideZeros,    2, 1)
-        self.filterForm.addWidget(self.hideNegative, 3, 1)
-        self.filterForm.addWidget(self.groupByDay,   4, 1)
-        self.filterForm.addWidget(self.showIdleTime, 5, 1)
-        self.filterForm.setRowStretch(6, 1)
+        self.filterForm.addWidget(self.lblShowIdleTime, 5, 0)
+        self.filterForm.addWidget(self.swtShowIdleTime, 5, 1)
 
         # Settings
         self.histMax = QSpinBox(self)
@@ -264,25 +276,27 @@ class GuiWritingStats(NToolDialog):
         self.optsBox.addWidget(self.histMax, 0)
 
         # Buttons
+        self.saveJSON = QAction(self.tr("JSON Data File (.json)"), self)
+        self.saveJSON.triggered.connect(qtLambda(self._saveData, self.FMT_JSON))
+
+        self.saveCSV = QAction(self.tr("CSV Data File (.csv)"), self)
+        self.saveCSV.triggered.connect(qtLambda(self._saveData, self.FMT_CSV))
+
+        self.saveMenu = QMenu(self)
+        self.saveMenu.addAction(self.saveJSON)
+        self.saveMenu.addAction(self.saveCSV)
+
         self.buttonBox = QDialogButtonBox(self)
         self.buttonBox.rejected.connect(self._doClose)
 
         self.btnClose = self.buttonBox.addButton(QtDialogClose)
-        self.btnClose.setAutoDefault(False)
+        if self.btnClose:
+            self.btnClose.setAutoDefault(False)
 
         self.btnSave = self.buttonBox.addButton(self.tr("Save As"), QtRoleAction)
-        self.btnSave.setAutoDefault(False)
-
-        self.saveMenu = QMenu(self)
-        self.btnSave.setMenu(self.saveMenu)
-
-        self.saveJSON = QAction(self.tr("JSON Data File (.json)"), self)
-        self.saveJSON.triggered.connect(qtLambda(self._saveData, self.FMT_JSON))
-        self.saveMenu.addAction(self.saveJSON)
-
-        self.saveCSV = QAction(self.tr("CSV Data File (.csv)"), self)
-        self.saveCSV.triggered.connect(qtLambda(self._saveData, self.FMT_CSV))
-        self.saveMenu.addAction(self.saveCSV)
+        if self.btnSave:
+            self.btnSave.setAutoDefault(False)
+            self.btnSave.setMenu(self.saveMenu)
 
         # Assemble
         self.outerBox = QGridLayout()
@@ -330,30 +344,26 @@ class GuiWritingStats(NToolDialog):
         """Save the state of the window, clear cache, end close."""
         self.logData = []
 
-        winWidth     = CONFIG.rpxInt(self.width())
-        winHeight    = CONFIG.rpxInt(self.height())
-        widthCol0    = CONFIG.rpxInt(self.listBox.columnWidth(0))
-        widthCol1    = CONFIG.rpxInt(self.listBox.columnWidth(1))
-        widthCol2    = CONFIG.rpxInt(self.listBox.columnWidth(2))
-        widthCol3    = CONFIG.rpxInt(self.listBox.columnWidth(3))
+        header = self.listBox.header()
+
         sortCol      = self.listBox.sortColumn()
-        sortOrder    = self.listBox.header().sortIndicatorOrder()
-        incNovel     = self.incNovel.isChecked()
-        incNotes     = self.incNotes.isChecked()
-        hideZeros    = self.hideZeros.isChecked()
-        hideNegative = self.hideNegative.isChecked()
-        groupByDay   = self.groupByDay.isChecked()
-        showIdleTime = self.showIdleTime.isChecked()
+        sortOrder    = header.sortIndicatorOrder() if header else 0
+        incNovel     = self.swtIncNovel.isChecked()
+        incNotes     = self.swtIncNotes.isChecked()
+        hideZeros    = self.swtHideZeros.isChecked()
+        hideNegative = self.swtHideNegative.isChecked()
+        groupByDay   = self.swtGroupByDay.isChecked()
+        showIdleTime = self.swtShowIdleTime.isChecked()
         histMax      = self.histMax.value()
 
         logger.debug("Saving State: GuiWritingStats")
         pOptions = SHARED.project.options
-        pOptions.setValue("GuiWritingStats", "winWidth",     winWidth)
-        pOptions.setValue("GuiWritingStats", "winHeight",    winHeight)
-        pOptions.setValue("GuiWritingStats", "widthCol0",    widthCol0)
-        pOptions.setValue("GuiWritingStats", "widthCol1",    widthCol1)
-        pOptions.setValue("GuiWritingStats", "widthCol2",    widthCol2)
-        pOptions.setValue("GuiWritingStats", "widthCol3",    widthCol3)
+        pOptions.setValue("GuiWritingStats", "winWidth",     self.width())
+        pOptions.setValue("GuiWritingStats", "winHeight",    self.height())
+        pOptions.setValue("GuiWritingStats", "widthCol0",    self.listBox.columnWidth(0))
+        pOptions.setValue("GuiWritingStats", "widthCol1",    self.listBox.columnWidth(1))
+        pOptions.setValue("GuiWritingStats", "widthCol2",    self.listBox.columnWidth(2))
+        pOptions.setValue("GuiWritingStats", "widthCol3",    self.listBox.columnWidth(3))
         pOptions.setValue("GuiWritingStats", "sortCol",      sortCol)
         pOptions.setValue("GuiWritingStats", "sortOrder",    sortOrder)
         pOptions.setValue("GuiWritingStats", "incNovel",     incNovel)
@@ -460,7 +470,7 @@ class GuiWritingStats(NToolDialog):
             rType = record.get("type")
             if rType == "initial":
                 self.wordOffset = checkInt(record.get("offset"), 0)
-                logger.debug("Initial word count when log was started is %d" % self.wordOffset)
+                logger.debug("Initial word count when log was started is %d", self.wordOffset)
             elif rType == "record":
                 try:
                     dStart = datetime.fromisoformat(str(record.get("start")))
@@ -500,11 +510,11 @@ class GuiWritingStats(NToolDialog):
         self.listBox.clear()
         self.timeFilter = 0.0
 
-        incNovel     = self.incNovel.isChecked()
-        incNotes     = self.incNotes.isChecked()
-        hideZeros    = self.hideZeros.isChecked()
-        hideNegative = self.hideNegative.isChecked()
-        groupByDay   = self.groupByDay.isChecked()
+        incNovel     = self.swtIncNovel.isChecked()
+        incNotes     = self.swtIncNotes.isChecked()
+        hideZeros    = self.swtHideZeros.isChecked()
+        hideNegative = self.swtHideNegative.isChecked()
+        groupByDay   = self.swtGroupByDay.isChecked()
         histMax      = self.histMax.value()
 
         # Group the data
@@ -576,14 +586,14 @@ class GuiWritingStats(NToolDialog):
         # Populate the list
         mTrans = Qt.TransformationMode.FastTransformation
         mAspect = Qt.AspectRatioMode.IgnoreAspectRatio
-        showIdleTime = self.showIdleTime.isChecked()
+        showIdleTime = self.swtShowIdleTime.isChecked()
         for _, sStart, sDiff, nWords, _, _, sIdle in self.filterData:
 
             if showIdleTime:
                 idleEntry = formatTime(sIdle)
             else:
                 sRatio = sIdle/sDiff if sDiff > 0.0 else 0.0
-                idleEntry = "%d %%" % round(100.0 * sRatio)
+                idleEntry = f"{round(100.0 * sRatio)} %"
 
             newItem = QTreeWidgetItem()
             newItem.setText(self.C_TIME, sStart)
