@@ -29,23 +29,23 @@ import unicodedata
 import uuid
 import xml.etree.ElementTree as ET
 
-from collections.abc import Callable
 from configparser import ConfigParser
 from datetime import datetime
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Literal, TypeVar
+from typing import TYPE_CHECKING, Any, Literal, TypeGuard, TypeVar
 from urllib.parse import urljoin
 from urllib.request import pathname2url
 
-from PyQt5.QtCore import QCoreApplication, QMimeData, QUrl
-from PyQt5.QtGui import QColor, QDesktopServices, QFont, QFontDatabase, QFontInfo
+from PyQt6.QtCore import QCoreApplication, QMimeData, QUrl
+from PyQt6.QtGui import QAction, QDesktopServices, QFont, QFontDatabase, QFontInfo
+from PyQt6.QtWidgets import QMenu, QMenuBar, QWidget
 
-from novelwriter.constants import nwConst, nwLabels, nwUnicode, trConst
+from novelwriter.constants import nwConst, nwLabels, nwQuotes, nwUnicode, trConst
 from novelwriter.enum import nwItemClass, nwItemLayout, nwItemType
 from novelwriter.error import logException
 
-if TYPE_CHECKING:  # pragma: no cover
-    from typing import TypeGuard  # Requires Python 3.10
+if TYPE_CHECKING:
+    from collections.abc import Callable
 
 logger = logging.getLogger(__name__)
 
@@ -298,6 +298,15 @@ def uniqueCompact(text: str) -> str:
     return "".join(sorted(set(compact(text))))
 
 
+def processDialogSymbols(symbols: str) -> str:
+    """Process dialogue line symbols."""
+    result = ""
+    for c in uniqueCompact(symbols):
+        if c in nwQuotes.ALLOWED:
+            result += c
+    return result
+
+
 def elide(text: str, length: int) -> str:
     """Elide a piece of text to a maximum length."""
     if len(text) > (cut := max(4, length)):
@@ -349,7 +358,7 @@ def fuzzyTime(seconds: int) -> str:
     elif seconds < 3300:  # 55 minutes
         return QCoreApplication.translate(
             "Common", "{0} minutes ago"
-        ).format(int(round(seconds/60)))
+        ).format(round(seconds/60))
     elif seconds < 5400:  # 90 minutes
         return QCoreApplication.translate(
             "Common", "an hour ago"
@@ -357,7 +366,7 @@ def fuzzyTime(seconds: int) -> str:
     elif seconds < 84600:  # 23.5 hours
         return QCoreApplication.translate(
             "Common", "{0} hours ago"
-        ).format(int(round(seconds/3600)))
+        ).format(round(seconds/3600))
     elif seconds < 129600:  # 1.5 days
         return QCoreApplication.translate(
             "Common", "a day ago"
@@ -365,7 +374,7 @@ def fuzzyTime(seconds: int) -> str:
     elif seconds < 561600:  # 6.5 days
         return QCoreApplication.translate(
             "Common", "{0} days ago"
-        ).format(int(round(seconds/86400)))
+        ).format(round(seconds/86400))
     elif seconds < 907200:  # 10.5 days
         return QCoreApplication.translate(
             "Common", "a week ago"
@@ -373,7 +382,7 @@ def fuzzyTime(seconds: int) -> str:
     elif seconds < 2419200:  # 28 days
         return QCoreApplication.translate(
             "Common", "{0} weeks ago"
-        ).format(int(round(seconds/604800)))
+        ).format(round(seconds/604800))
     elif seconds < 3888000:  # 45 days
         return QCoreApplication.translate(
             "Common", "a month ago"
@@ -381,7 +390,7 @@ def fuzzyTime(seconds: int) -> str:
     elif seconds < 29808000:  # 345 days
         return QCoreApplication.translate(
             "Common", "{0} months ago"
-        ).format(int(round(seconds/2592000)))
+        ).format(round(seconds/2592000))
     elif seconds < 47336400:  # 1.5 years
         return QCoreApplication.translate(
             "Common", "a year ago"
@@ -389,7 +398,7 @@ def fuzzyTime(seconds: int) -> str:
     else:
         return QCoreApplication.translate(
             "Common", "{0} years ago"
-        ).format(int(round(seconds/31557600)))
+        ).format(round(seconds/31557600))
 
 
 def numberToRoman(value: int, toLower: bool = False) -> str:
@@ -419,35 +428,29 @@ def numberToRoman(value: int, toLower: bool = False) -> str:
 #  Qt Helpers
 ##
 
-def cssCol(col: QColor, alpha: int | None = None) -> str:
-    """Convert a QColor object to an rgba entry to use in CSS."""
-    return f"rgba({col.red()}, {col.green()}, {col.blue()}, {alpha or col.alpha()})"
-
-
 def describeFont(font: QFont) -> str:
     """Describe a font in a way that can be displayed on the GUI."""
     if isinstance(font, QFont):
         info = QFontInfo(font)
         family = info.family()
         styles = [v for v in info.styleName().split() if v not in family]
-        return " ".join([f"{info.pointSize()} pt", family] + styles)
+        return " ".join([f"{info.pointSize()} pt", family, *styles])
     return "Error"
 
 
 def fontMatcher(font: QFont) -> QFont:
     """Make sure the font is the correct family, if possible. This
     ensures that Qt doesn't re-use another font under the hood. The
-    default Qt5 font matching algorithm doesn't handle well changing
+    default Qt font matching algorithm doesn't handle well changing
     application fonts at runtime.
     """
     info = QFontInfo(font)
     if (famRequest := font.family()) != (famActual := info.family()):
         logger.warning("Font mismatch: Requested '%s', but got '%s'", famRequest, famActual)
-        db = QFontDatabase()
-        if famRequest in db.families():
+        if famRequest in QFontDatabase.families():
             styleRequest, sizeRequest = font.styleName(), font.pointSize()
             logger.info("Lookup: %s, %s, %d pt", famRequest, styleRequest, sizeRequest)
-            temp = db.font(famRequest, styleRequest, sizeRequest)
+            temp = QFontDatabase.font(famRequest, styleRequest, sizeRequest)
             temp.setPointSize(sizeRequest)  # Make sure it isn't changed
             famFound, styleFound, sizeFound = temp.family(), temp.styleName(), temp.pointSize()
             if famFound == famRequest:
@@ -465,6 +468,20 @@ def qtLambda(func: Callable, *args: Any, **kwargs: Any) -> Callable:
     return wrapper
 
 
+def qtAddAction(parent: QWidget, label: str) -> QAction:
+    """Helper to add action to widget and always return the action."""
+    action = QAction(label, parent)
+    parent.addAction(action)
+    return action
+
+
+def qtAddMenu(parent: QMenuBar | QMenu, label: str) -> QMenu:
+    """Helper to add menu to menu and always return the menu."""
+    menu = QMenu(label, parent)
+    parent.addMenu(menu)
+    return menu
+
+
 def encodeMimeHandles(mimeData: QMimeData, handles: list[str]) -> None:
     """Encode handles into a mime data object."""
     mimeData.setData(nwConst.MIME_HANDLE, b"|".join(h.encode() for h in handles))
@@ -484,7 +501,7 @@ def jsonEncode(data: dict | list | tuple, n: int = 0, nmax: int = 0) -> str:
     """Encode a dictionary, list or tuple as a json object or array, and
     indent from level n up to a max level nmax if nmax is larger than 0.
     """
-    if not isinstance(data, (dict, list, tuple)):
+    if not isinstance(data, dict | list | tuple):
         return "[]"
 
     buffer = []
@@ -531,12 +548,11 @@ def jsonEncode(data: dict | list | tuple, n: int = 0, nmax: int = 0) -> str:
 #  XML Helpers
 ##
 
-def xmlIndent(tree: ET.Element | ET.ElementTree) -> None:
+def xmlIndent(xml: ET.Element | ET.ElementTree) -> None:
     """A modified version of the XML indent function in the standard
     library. It behaves more closely to how the one from lxml does.
     """
-    if isinstance(tree, ET.ElementTree):
-        tree = tree.getroot()
+    tree = xml.getroot() if isinstance(xml, ET.ElementTree) else xml
     if not isinstance(tree, ET.Element):
         return
 
@@ -664,11 +680,12 @@ class NWConfigParser(ConfigParser):
     """Common: Adapted Config Parser
 
     This is a subclass of the standard config parser that adds type safe
-    helper functions, and support for lists.
+    helper functions, and support for lists. It also turns off
+    interpolation, which would require % symbols to be escaped (#2455).
     """
 
     def __init__(self) -> None:
-        super().__init__()
+        super().__init__(interpolation=None)
         return
 
     def rdStr(self, section: str, option: str, default: str) -> str:
