@@ -29,33 +29,64 @@ import json
 import logging
 import sys
 
-from datetime import datetime
 from pathlib import Path
 from time import time
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Final
 
-from PyQt5.QtCore import (
-    PYQT_VERSION, PYQT_VERSION_STR, QT_VERSION, QT_VERSION_STR, QLibraryInfo,
-    QLocale, QStandardPaths, QSysInfo, QTranslator
+from PyQt6.QtCore import (
+    PYQT_VERSION, PYQT_VERSION_STR, QT_VERSION, QT_VERSION_STR, QDate,
+    QDateTime, QLibraryInfo, QLocale, QStandardPaths, QSysInfo, QTranslator
 )
-from PyQt5.QtGui import QFont, QFontDatabase
-from PyQt5.QtWidgets import QApplication
+from PyQt6.QtGui import QFont, QFontDatabase, QFontMetrics
+from PyQt6.QtWidgets import QApplication
 
 from novelwriter.common import (
     NWConfigParser, checkInt, checkPath, describeFont, fontMatcher,
-    formatTimeStamp
+    formatTimeStamp, processDialogSymbols, simplified
 )
-from novelwriter.constants import nwFiles, nwUnicode
+from novelwriter.constants import nwFiles, nwQuotes, nwUnicode
 from novelwriter.error import formatException, logException
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
+    from datetime import datetime
+
     from novelwriter.core.projectdata import NWProjectData
+    from novelwriter.splash import NSplashScreen
 
 logger = logging.getLogger(__name__)
 
+DEF_GUI = "default"
+DEF_SYNTAX = "default_light"
+DEF_ICONS = "material_rounded_normal"
+DEF_TREECOL = "theme"
+
 
 class Config:
 
+    __slots__ = (
+        "_appPath", "_appRoot", "_backPath", "_backupPath", "_confPath", "_dLocale", "_dShortDate",
+        "_dShortDateTime", "_dataPath", "_errData", "_hasError", "_homePath", "_lastAuthor",
+        "_manuals", "_nwLangPath", "_qLocale", "_qtLangPath", "_qtTrans", "_recentPaths",
+        "_recentProjects", "_splash", "allowOpenDial", "altDialogClose", "altDialogOpen",
+        "appHandle", "appName", "askBeforeBackup", "askBeforeExit", "autoSaveDoc", "autoSaveProj",
+        "autoScroll", "autoScrollPos", "autoSelect", "backupOnClose", "cursorWidth", "dialogLine",
+        "dialogStyle", "doJustify", "doReplace", "doReplaceDQuote", "doReplaceDash",
+        "doReplaceDots", "doReplaceSQuote", "emphLabels", "fmtApostrophe", "fmtDQuoteClose",
+        "fmtDQuoteOpen", "fmtPadAfter", "fmtPadBefore", "fmtPadThin", "fmtSQuoteClose",
+        "fmtSQuoteOpen", "focusWidth", "guiFont", "guiLocale", "guiSyntax", "guiTheme",
+        "hasEnchant", "hideFocusFooter", "hideHScroll", "hideVScroll", "highlightEmph", "hostName",
+        "iconColDocs", "iconColTree", "iconTheme", "incNotesWCount", "isDebug", "kernelVer",
+        "lastNotes", "mainPanePos", "mainWinSize", "memInfo", "narratorBreak", "narratorDialog",
+        "nativeFont", "osDarwin", "osLinux", "osType", "osUnknown", "osWindows", "outlinePanePos",
+        "prefsWinSize", "scrollPastEnd", "searchCase", "searchLoop", "searchMatchCap",
+        "searchNextFile", "searchProjCase", "searchProjRegEx", "searchProjWord", "searchRegEx",
+        "searchWord", "showEditToolBar", "showFullPath", "showLineEndings", "showMultiSpaces",
+        "showSessionTime", "showTabsNSpaces", "showViewerPanel", "spellLanguage", "stopWhenIdle",
+        "tabWidth", "textFont", "textMargin", "textWidth", "useCharCount", "userIdleTime",
+        "verPyQtString", "verPyQtValue", "verPyString", "verQtString", "verQtValue",
+        "viewComments", "viewPanePos", "viewSynopsis", "welcomeWinSize",
+    )
+
     LANG_NW   = 1
     LANG_PROJ = 2
 
@@ -64,6 +95,8 @@ class Config:
         # Initialisation
         # ==============
 
+        self._splash = None
+
         # Set Application Variables
         self.appName   = "novelWriter"
         self.appHandle = "novelwriter"
@@ -83,10 +116,10 @@ class Config:
 
         self._appPath = Path(__file__).parent.absolute()
         self._appRoot = self._appPath.parent
-        if self._appRoot.is_file():
-            # novelWriter is packaged as a single file
-            self._appRoot = self._appRoot.parent
-            self._appPath = self._appRoot
+        if getattr(sys, "frozen", False):  # pragma: no cover
+            # novelWriter is packaged as an exe
+            self._appPath = Path(__file__).parent.parent.absolute()
+            self._appRoot = self._appPath
 
         # Runtime Settings and Variables
         self._hasError = False  # True if the config class encountered an error
@@ -95,7 +128,7 @@ class Config:
         # Localisation
         # Note that these paths must be strings
         self._nwLangPath = self._appPath / "assets" / "i18n"
-        self._qtLangPath = QLibraryInfo.location(QLibraryInfo.LibraryLocation.TranslationsPath)
+        self._qtLangPath = QLibraryInfo.path(QLibraryInfo.LibraryPath.TranslationsPath)
 
         hasLocale = (self._nwLangPath / f"nw_{QLocale.system().name()}.qm").exists()
         self._qLocale = QLocale.system() if hasLocale else QLocale("en_GB")
@@ -116,25 +149,31 @@ class Config:
 
         self._recentProjects = RecentProjects(self)
         self._recentPaths = RecentPaths(self)
+        self._lastAuthor = ""
 
         # General GUI Settings
         self.guiLocale    = self._qLocale.name()
-        self.guiTheme     = "default_light"  # GUI theme
-        self.guiSyntax    = "default_light"  # Syntax theme
-        self.guiFont      = QFont()          # Main GUI font
-        self.guiScale     = 1.0              # Set automatically by Theme class
-        self.hideVScroll  = False            # Hide vertical scroll bars on main widgets
-        self.hideHScroll  = False            # Hide horizontal scroll bars on main widgets
-        self.lastNotes    = "0x0"            # The latest release notes that have been shown
-        self.nativeFont   = True             # Use native font dialog
+        self.guiTheme     = DEF_GUI     # GUI theme
+        self.guiSyntax    = DEF_SYNTAX  # Syntax theme
+        self.guiFont      = QFont()     # Main GUI font
+        self.hideVScroll  = False       # Hide vertical scroll bars on main widgets
+        self.hideHScroll  = False       # Hide horizontal scroll bars on main widgets
+        self.lastNotes    = "0x0"       # The latest release notes that have been shown
+        self.nativeFont   = True        # Use native font dialog
+        self.useCharCount = False       # Use character count as primary count
+
+        # Icons
+        self.iconTheme   = DEF_ICONS    # Icons theme
+        self.iconColTree = DEF_TREECOL  # Project tree icon colours
+        self.iconColDocs = False        # Keep theme colours on documents
 
         # Size Settings
-        self._mainWinSize  = [1200, 650]     # Last size of the main GUI window
-        self._welcomeSize  = [800, 550]      # Last size of the welcome window
-        self._prefsWinSize = [700, 615]      # Last size of the Preferences dialog
-        self._mainPanePos  = [300, 800]      # Last position of the main window splitter
-        self._viewPanePos  = [500, 150]      # Last position of the document viewer splitter
-        self._outlnPanePos = [500, 150]      # Last position of the outline panel splitter
+        self.mainWinSize    = [1200, 650]  # Last size of the main GUI window
+        self.welcomeWinSize = [800, 550]   # Last size of the welcome window
+        self.prefsWinSize   = [700, 615]   # Last size of the Preferences dialog
+        self.mainPanePos    = [300, 800]   # Last position of the main window splitter
+        self.viewPanePos    = [500, 150]   # Last position of the document viewer splitter
+        self.outlinePanePos = [500, 150]   # Last position of the outline panel splitter
 
         # Project Settings
         self.autoSaveProj    = 60     # Interval for auto-saving project, in seconds
@@ -149,6 +188,7 @@ class Config:
         self.textWidth       = 700      # Editor text width
         self.textMargin      = 40       # Editor/viewer text margin
         self.tabWidth        = 40       # Editor tabulator width
+        self.cursorWidth     = 1        # Editor cursor width
 
         self.focusWidth      = 800      # Focus Mode text width
         self.hideFocusFooter = False    # Hide document footer in Focus Mode
@@ -220,7 +260,7 @@ class Config:
         # System and App Information
         # ==========================
 
-        # Check Qt5 Versions
+        # Check Qt Versions
         self.verQtString   = QT_VERSION_STR
         self.verQtValue    = QT_VERSION
         self.verPyQtString = PYQT_VERSION_STR
@@ -267,7 +307,12 @@ class Config:
 
     @property
     def pdfDocs(self) -> Path | None:
-        return self._manuals.get(f"manual_{self.locale.name()}", self._manuals.get("manual"))
+        """Return the local manual PDF file, if any exist."""
+        return self._manuals.get(f"manual_{self.locale.bcp47Name()}", self._manuals.get("manual"))
+
+    @property
+    def nwLangPath(self) -> Path:
+        return self._nwLangPath
 
     @property
     def locale(self) -> QLocale:
@@ -278,28 +323,9 @@ class Config:
         return self._recentProjects
 
     @property
-    def mainWinSize(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._mainWinSize]
-
-    @property
-    def welcomeWinSize(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._welcomeSize]
-
-    @property
-    def preferencesWinSize(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._prefsWinSize]
-
-    @property
-    def mainPanePos(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._mainPanePos]
-
-    @property
-    def viewPanePos(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._viewPanePos]
-
-    @property
-    def outlinePanePos(self) -> list[int]:
-        return [int(x*self.guiScale) for x in self._outlnPanePos]
+    def lastAuthor(self) -> str:
+        """Return the last author name used."""
+        return simplified(self._lastAuthor)
 
     ##
     #  Getters
@@ -308,68 +334,46 @@ class Config:
     def getTextWidth(self, focusMode: bool = False) -> int:
         """Get the text with for the correct editor mode."""
         if focusMode:
-            return self.pxInt(max(self.focusWidth, 200))
+            return max(self.focusWidth, 200)
         else:
-            return self.pxInt(max(self.textWidth, 200))
-
-    def getTextMargin(self) -> int:
-        """Get the scaled text margin."""
-        return self.pxInt(max(self.textMargin, 0))
-
-    def getTabWidth(self) -> int:
-        """Get the scaled tab width."""
-        return self.pxInt(max(self.tabWidth, 0))
+            return max(self.textWidth, 200)
 
     ##
     #  Setters
     ##
 
+    def setLastAuthor(self, value: str) -> None:
+        """Set tle last used author name."""
+        self._lastAuthor = simplified(value)
+        return
+
     def setMainWinSize(self, width: int, height: int) -> None:
         """Set the size of the main window, but only if the change is
         larger than 5 pixels. The OS window manager will sometimes
         adjust it a bit, and we don't want the main window to shrink or
         grow each time the app is opened.
         """
-        width = int(width/self.guiScale)
-        height = int(height/self.guiScale)
-        if abs(self._mainWinSize[0] - width) > 5:
-            self._mainWinSize[0] = width
-        if abs(self._mainWinSize[1] - height) > 5:
-            self._mainWinSize[1] = height
+        if abs(self.mainWinSize[0] - width) > 5:
+            self.mainWinSize[0] = width
+        if abs(self.mainWinSize[1] - height) > 5:
+            self.mainWinSize[1] = height
         return
 
     def setWelcomeWinSize(self, width: int, height: int) -> None:
         """Set the size of the Preferences dialog window."""
-        self._welcomeSize[0] = int(width/self.guiScale)
-        self._welcomeSize[1] = int(height/self.guiScale)
+        self.welcomeWinSize = [width, height]
         return
 
     def setPreferencesWinSize(self, width: int, height: int) -> None:
         """Set the size of the Preferences dialog window."""
-        self._prefsWinSize[0] = int(width/self.guiScale)
-        self._prefsWinSize[1] = int(height/self.guiScale)
-        return
-
-    def setMainPanePos(self, pos: list[int]) -> None:
-        """Set the position of the main GUI splitter."""
-        self._mainPanePos = [int(x/self.guiScale) for x in pos]
-        return
-
-    def setViewPanePos(self, pos: list[int]) -> None:
-        """Set the position of the viewer meta data splitter."""
-        self._viewPanePos = [int(x/self.guiScale) for x in pos]
-        return
-
-    def setOutlinePanePos(self, pos: list[int]) -> None:
-        """Set the position of the outline details splitter."""
-        self._outlnPanePos = [int(x/self.guiScale) for x in pos]
+        self.prefsWinSize = [width, height]
         return
 
     def setLastPath(self, key: str, path: str | Path) -> None:
         """Set the last used path. Only the folder is saved, so if the
         path is not a folder, the parent of the path is used instead.
         """
-        if isinstance(path, (str, Path)):
+        if isinstance(path, str | Path):
             path = checkPath(path, self._homePath)
             if not path.is_dir():
                 path = path.parent
@@ -392,13 +396,12 @@ class Config:
             self.guiFont = fontMatcher(font)
         else:
             font = QFont()
-            fontDB = QFontDatabase()
-            if self.osWindows and "Arial" in fontDB.families():
+            if self.osWindows and "Arial" in QFontDatabase.families():
                 # On Windows we default to Arial if possible
                 font.setFamily("Arial")
                 font.setPointSize(10)
             else:
-                font = fontDB.systemFont(QFontDatabase.SystemFont.GeneralFont)
+                font = QFontDatabase.systemFont(QFontDatabase.SystemFont.GeneralFont)
             self.guiFont = fontMatcher(font)
             logger.debug("GUI font set to: %s", describeFont(font))
         QApplication.setFont(self.guiFont)
@@ -415,8 +418,7 @@ class Config:
             font.fromString(value)
             self.textFont = fontMatcher(font)
         else:
-            fontDB = QFontDatabase()
-            fontFam = fontDB.families()
+            fontFam = QFontDatabase.families()
             if self.osWindows and "Arial" in fontFam:
                 font = QFont()
                 font.setFamily("Arial")
@@ -426,7 +428,7 @@ class Config:
                 font.setFamily("Helvetica")
                 font.setPointSize(12)
             else:
-                font = fontDB.systemFont(QFontDatabase.SystemFont.GeneralFont)
+                font = QFontDatabase.systemFont(QFontDatabase.SystemFont.GeneralFont)
             self.textFont = fontMatcher(font)
             logger.debug("Text font set to: %s", describeFont(self.textFont))
         return
@@ -435,14 +437,6 @@ class Config:
     #  Methods
     ##
 
-    def pxInt(self, value: int) -> int:
-        """Scale fixed gui sizes by the screen scale factor."""
-        return int(value*self.guiScale)
-
-    def rpxInt(self, value: int) -> int:
-        """Un-scale fixed gui sizes by the screen scale factor."""
-        return int(value/self.guiScale)
-
     def homePath(self) -> Path:
         """The user's home folder."""
         return self._homePath
@@ -484,11 +478,16 @@ class Config:
 
     def localDate(self, value: datetime) -> str:
         """Return a localised date format."""
-        return self._dLocale.toString(value, self._dShortDate)
+        # Explicitly convert the date first, see bug #2325
+        return self._dLocale.toString(QDate(value.year, value.month, value.day), self._dShortDate)
 
     def localDateTime(self, value: datetime) -> str:
         """Return a localised datetime format."""
-        return self._dLocale.toString(value, self._dShortDateTime)
+        # Explicitly convert the datetime first, see bug #2325
+        return self._dLocale.toString(
+            QDateTime(value.year, value.month, value.day, value.hour, value.minute, value.second),
+            self._dShortDateTime,
+        )
 
     def listLanguages(self, lngSet: int) -> list[tuple[str, str]]:
         """List localisation files in the i18n folder. The default GUI
@@ -517,20 +516,27 @@ class Config:
 
         return sorted(langList.items(), key=lambda x: x[0])
 
+    def splashMessage(self, message: str) -> None:
+        """Send a message to the splash screen."""
+        if self._splash:
+            self._splash.showStatus(message)
+        return
+
     ##
     #  Config Actions
     ##
 
-    def initConfig(self, confPath: str | Path | None = None,
-                   dataPath: str | Path | None = None) -> None:
+    def initConfig(
+        self, confPath: str | Path | None = None, dataPath: str | Path | None = None
+    ) -> None:
         """Initialise the config class. The manual setting of confPath
         and dataPath is mainly intended for the test suite.
         """
         logger.debug("Initialising Config ...")
-        if isinstance(confPath, (str, Path)):
+        if isinstance(confPath, str | Path):
             logger.info("Setting alternative config path: %s", confPath)
             self._confPath = Path(confPath)
-        if isinstance(dataPath, (str, Path)):
+        if isinstance(dataPath, str | Path):
             logger.info("Setting alternative data path: %s", dataPath)
             self._dataPath = Path(dataPath)
 
@@ -562,6 +568,8 @@ class Config:
 
     def initLocalisation(self, nwApp: QApplication) -> None:
         """Initialise the localisation of the GUI."""
+        self.splashMessage("Loading localisation ...")
+
         self._qLocale = QLocale(self.guiLocale)
         QLocale.setDefault(self._qLocale)
         self._qtTrans = {}
@@ -572,13 +580,13 @@ class Config:
         self._dShortDateTime = self._dLocale.dateTimeFormat(QLocale.FormatType.ShortFormat)
 
         langList = [
-            (self._qtLangPath, "qtbase"),   # Qt 5.x
+            (self._qtLangPath, "qtbase"),   # Qt
             (str(self._nwLangPath), "nw"),  # novelWriter
         ]
         for lngPath, lngBase in langList:
             for lngCode in self._qLocale.uiLanguages():
                 qTrans = QTranslator()
-                lngFile = "%s_%s" % (lngBase, lngCode.replace("-", "_"))
+                lngFile = "{0}_{1}".format(lngBase, lngCode.replace("-", "_"))
                 if lngFile not in self._qtTrans:
                     if qTrans.load(lngFile, lngPath):
                         logger.debug("Loaded: %s.qm", lngFile)
@@ -587,8 +595,11 @@ class Config:
 
         return
 
-    def loadConfig(self) -> bool:
+    def loadConfig(self, splash: NSplashScreen | None = None) -> bool:
         """Load preferences from file and replace default settings."""
+        self._splash = splash
+        self.splashMessage("Loading user configuration ...")
+
         logger.debug("Loading config file")
 
         conf = NWConfigParser()
@@ -615,22 +626,26 @@ class Config:
         # Main
         sec = "Main"
         self.setGuiFont(conf.rdStr(sec, "font", ""))
-        self.guiTheme    = conf.rdStr(sec, "theme", self.guiTheme)
-        self.guiSyntax   = conf.rdStr(sec, "syntax", self.guiSyntax)
-        self.guiLocale   = conf.rdStr(sec, "localisation", self.guiLocale)
-        self.hideVScroll = conf.rdBool(sec, "hidevscroll", self.hideVScroll)
-        self.hideHScroll = conf.rdBool(sec, "hidehscroll", self.hideHScroll)
-        self.lastNotes   = conf.rdStr(sec, "lastnotes", self.lastNotes)
-        self.nativeFont  = conf.rdBool(sec, "nativefont", self.nativeFont)
+        self.guiTheme     = conf.rdStr(sec, "theme", self.guiTheme)
+        self.guiSyntax    = conf.rdStr(sec, "syntax", self.guiSyntax)
+        self.iconTheme    = conf.rdStr(sec, "icons", self.iconTheme)
+        self.iconColTree  = conf.rdStr(sec, "iconcoltree", self.iconColTree)
+        self.iconColDocs  = conf.rdBool(sec, "iconcoldocs", self.iconColDocs)
+        self.guiLocale    = conf.rdStr(sec, "localisation", self.guiLocale)
+        self.hideVScroll  = conf.rdBool(sec, "hidevscroll", self.hideVScroll)
+        self.hideHScroll  = conf.rdBool(sec, "hidehscroll", self.hideHScroll)
+        self.lastNotes    = conf.rdStr(sec, "lastnotes", self.lastNotes)
+        self.nativeFont   = conf.rdBool(sec, "nativefont", self.nativeFont)
+        self.useCharCount = conf.rdBool(sec, "usecharcount", self.useCharCount)
 
         # Sizes
         sec = "Sizes"
-        self._mainWinSize  = conf.rdIntList(sec, "mainwindow", self._mainWinSize)
-        self._welcomeSize  = conf.rdIntList(sec, "welcome", self._welcomeSize)
-        self._prefsWinSize = conf.rdIntList(sec, "preferences", self._prefsWinSize)
-        self._mainPanePos  = conf.rdIntList(sec, "mainpane", self._mainPanePos)
-        self._viewPanePos  = conf.rdIntList(sec, "viewpane", self._viewPanePos)
-        self._outlnPanePos = conf.rdIntList(sec, "outlinepane", self._outlnPanePos)
+        self.mainWinSize    = conf.rdIntList(sec, "mainwindow", self.mainWinSize)
+        self.welcomeWinSize = conf.rdIntList(sec, "welcome", self.welcomeWinSize)
+        self.prefsWinSize   = conf.rdIntList(sec, "preferences", self.prefsWinSize)
+        self.mainPanePos    = conf.rdIntList(sec, "mainpane", self.mainPanePos)
+        self.viewPanePos    = conf.rdIntList(sec, "viewpane", self.viewPanePos)
+        self.outlinePanePos = conf.rdIntList(sec, "outlinepane", self.outlinePanePos)
 
         # Project
         sec = "Project"
@@ -641,6 +656,7 @@ class Config:
         self.backupOnClose   = conf.rdBool(sec, "backuponclose", self.backupOnClose)
         self.askBeforeBackup = conf.rdBool(sec, "askbeforebackup", self.askBeforeBackup)
         self.askBeforeExit   = conf.rdBool(sec, "askbeforeexit", self.askBeforeExit)
+        self._lastAuthor     = conf.rdStr(sec, "lastauthor", self._lastAuthor)
 
         # Editor
         sec = "Editor"
@@ -648,6 +664,7 @@ class Config:
         self.textWidth       = conf.rdInt(sec, "width", self.textWidth)
         self.textMargin      = conf.rdInt(sec, "margin", self.textMargin)
         self.tabWidth        = conf.rdInt(sec, "tabwidth", self.tabWidth)
+        self.cursorWidth     = conf.rdInt(sec, "cursorwidth", self.cursorWidth)
         self.focusWidth      = conf.rdInt(sec, "focuswidth", self.focusWidth)
         self.hideFocusFooter = conf.rdBool(sec, "hidefocusfooter", self.hideFocusFooter)
         self.doJustify       = conf.rdBool(sec, "justify", self.doJustify)
@@ -675,9 +692,9 @@ class Config:
         self.showFullPath    = conf.rdBool(sec, "showfullpath", self.showFullPath)
         self.dialogStyle     = conf.rdInt(sec, "dialogstyle", self.dialogStyle)
         self.allowOpenDial   = conf.rdBool(sec, "allowopendial", self.allowOpenDial)
-        self.dialogLine      = conf.rdStr(sec, "dialogline", self.dialogLine)
-        self.narratorBreak   = conf.rdStr(sec, "narratorbreak", self.narratorBreak)
-        self.narratorDialog  = conf.rdStr(sec, "narratordialog", self.narratorDialog)
+        dialogLine           = conf.rdStr(sec, "dialogline", self.dialogLine)
+        narratorBreak        = conf.rdStr(sec, "narratorbreak", self.narratorBreak)
+        narratorDialog       = conf.rdStr(sec, "narratordialog", self.narratorDialog)
         self.altDialogOpen   = conf.rdStr(sec, "altdialogopen", self.altDialogOpen)
         self.altDialogClose  = conf.rdStr(sec, "altdialogclose", self.altDialogClose)
         self.highlightEmph   = conf.rdBool(sec, "highlightemph", self.highlightEmph)
@@ -704,6 +721,9 @@ class Config:
         # Check Values
         # ============
 
+        self._prepareFont(self.guiFont, "GUI")
+        self._prepareFont(self.textFont, "document")
+
         # If we're using straight quotes, disable auto-replace
         if self.fmtSQuoteOpen == self.fmtSQuoteClose == "'" and self.doReplaceSQuote:
             logger.info("Using straight single quotes, so disabling auto-replace")
@@ -713,6 +733,10 @@ class Config:
             logger.info("Using straight double quotes, so disabling auto-replace")
             self.doReplaceDQuote = False
 
+        self.dialogLine = processDialogSymbols(dialogLine)
+        self.narratorBreak = narratorBreak if narratorBreak in nwQuotes.DASHES else ""
+        self.narratorDialog = narratorDialog if narratorDialog in nwQuotes.DASHES else ""
+
         return True
 
     def saveConfig(self) -> bool:
@@ -729,20 +753,24 @@ class Config:
             "font":         self.guiFont.toString(),
             "theme":        str(self.guiTheme),
             "syntax":       str(self.guiSyntax),
+            "icons":        str(self.iconTheme),
+            "iconcoltree":  str(self.iconColTree),
+            "iconcoldocs":  str(self.iconColDocs),
             "localisation": str(self.guiLocale),
             "hidevscroll":  str(self.hideVScroll),
             "hidehscroll":  str(self.hideHScroll),
             "lastnotes":    str(self.lastNotes),
             "nativefont":   str(self.nativeFont),
+            "usecharcount": str(self.useCharCount),
         }
 
         conf["Sizes"] = {
-            "mainwindow":  self._packList(self._mainWinSize),
-            "welcome":     self._packList(self._welcomeSize),
-            "preferences": self._packList(self._prefsWinSize),
-            "mainpane":    self._packList(self._mainPanePos),
-            "viewpane":    self._packList(self._viewPanePos),
-            "outlinepane": self._packList(self._outlnPanePos),
+            "mainwindow":  self._packList(self.mainWinSize),
+            "welcome":     self._packList(self.welcomeWinSize),
+            "preferences": self._packList(self.prefsWinSize),
+            "mainpane":    self._packList(self.mainPanePos),
+            "viewpane":    self._packList(self.viewPanePos),
+            "outlinepane": self._packList(self.outlinePanePos),
         }
 
         conf["Project"] = {
@@ -753,6 +781,7 @@ class Config:
             "backuponclose":   str(self.backupOnClose),
             "askbeforebackup": str(self.askBeforeBackup),
             "askbeforeexit":   str(self.askBeforeExit),
+            "lastauthor":      str(self._lastAuthor),
         }
 
         conf["Editor"] = {
@@ -760,6 +789,7 @@ class Config:
             "width":           str(self.textWidth),
             "margin":          str(self.textMargin),
             "tabwidth":        str(self.tabWidth),
+            "cursorwidth":     str(self.cursorWidth),
             "focuswidth":      str(self.focusWidth),
             "hidefocusfooter": str(self.hideFocusFooter),
             "justify":         str(self.doJustify),
@@ -829,6 +859,11 @@ class Config:
 
         return True
 
+    def finishStartup(self) -> None:
+        """Call after startup is complete."""
+        self._splash = None
+        return
+
     ##
     #  Internal Functions
     ##
@@ -851,6 +886,17 @@ class Config:
             logger.debug("Checking package 'pyenchant': OK")
         return
 
+    def _prepareFont(self, font: QFont, kind: str) -> None:
+        """Check Unicode availability in font. This also initialises any
+        alternative character used for missing glyphs. See #2315.
+        """
+        self.splashMessage(f"Initialising {kind} font: {font.family()}")
+        metrics = QFontMetrics(font)
+        for char in nwUnicode.UI_SYMBOLS:
+            if not metrics.inFont(char):  # type: ignore
+                logger.warning("No glyph U+%04x in font", ord(char))  # pragma: no cover
+        return
+
 
 class RecentProjects:
 
@@ -873,9 +919,10 @@ class RecentProjects:
                     puuid = str(entry.get("uuid", ""))
                     title = str(entry.get("title", ""))
                     words = checkInt(entry.get("words", 0), 0)
+                    chars = checkInt(entry.get("chars", 0), 0)
                     saved = checkInt(entry.get("time", 0), 0)
                     if path and title:
-                        self._setEntry(puuid, path, title, words, saved)
+                        self._setEntry(puuid, path, title, words, chars, saved)
             except Exception:
                 logger.error("Could not load recent project cache")
                 logException()
@@ -908,7 +955,14 @@ class RecentProjects:
         try:
             if (remove := self._map.get(data.uuid)) and (remove != str(path)):
                 self.remove(remove)
-            self._setEntry(data.uuid, str(path), data.name, sum(data.currCounts), int(saved))
+            self._setEntry(
+                data.uuid,
+                str(path),
+                data.name,
+                sum(data.currCounts[:2]),
+                sum(data.currCounts[2:]),
+                int(saved),
+            )
             self.saveCache()
         except Exception:
             pass
@@ -921,9 +975,17 @@ class RecentProjects:
             self.saveCache()
         return
 
-    def _setEntry(self, puuid: str, path: str, title: str, words: int, saved: int) -> None:
+    def _setEntry(
+        self, puuid: str, path: str, title: str, words: int, chars: int, saved: int
+    ) -> None:
         """Set an entry in the recent projects record."""
-        self._data[path] = {"uuid": puuid, "title": title, "words": words, "time": saved}
+        self._data[path] = {
+            "uuid": puuid,
+            "title": title,
+            "words": words,
+            "chars": chars,
+            "time": saved,
+        }
         if puuid:
             self._map[puuid] = path
         return
@@ -931,7 +993,7 @@ class RecentProjects:
 
 class RecentPaths:
 
-    KEYS = ["default", "project", "import", "outline", "stats"]
+    KEYS: Final[list[str]] = ["default", "project", "import", "outline", "stats"]
 
     def __init__(self, config: Config) -> None:
         self._conf = config
