@@ -25,14 +25,13 @@ from __future__ import annotations
 
 import logging
 
-from PyQt5.QtCore import QSize, pyqtSlot
-from PyQt5.QtGui import QFontMetrics
-from PyQt5.QtWidgets import (
+from PyQt6.QtCore import QSize, pyqtSlot
+from PyQt6.QtGui import QFontMetrics
+from PyQt6.QtWidgets import (
     QDialogButtonBox, QFrame, QHBoxLayout, QLabel, QListWidget,
     QListWidgetItem, QVBoxLayout, QWidget
 )
 
-from novelwriter import CONFIG
 from novelwriter.constants import nwQuotes, trConst
 from novelwriter.extensions.modified import NDialog
 from novelwriter.types import (
@@ -62,18 +61,14 @@ class GuiQuoteSelect(NDialog):
 
         self._selected = current
 
-        qMetrics = QFontMetrics(self.font())
-        pxW = 7*qMetrics.boundingRectChar("M").width()
-        pxH = 7*qMetrics.boundingRectChar("M").height()
-        pxH = 7*qMetrics.boundingRectChar("M").height()
-
         lblFont = self.font()
         lblFont.setPointSizeF(4*lblFont.pointSizeF())
+        metrics = QFontMetrics(self.font())
 
         # Preview Label
         self.previewLabel = QLabel(current, self)
         self.previewLabel.setFont(lblFont)
-        self.previewLabel.setFixedSize(QSize(pxW, pxH))
+        self.previewLabel.setFixedSize(QSize(4*metrics.maxWidth(), 5*metrics.height()))
         self.previewLabel.setAlignment(QtAlignCenter)
         self.previewLabel.setFrameStyle(QFrame.Shape.Box | QFrame.Shadow.Plain)
 
@@ -83,16 +78,16 @@ class GuiQuoteSelect(NDialog):
 
         minSize = 100
         for sKey, sLabel in nwQuotes.SYMBOLS.items():
-            text = "[ %s ] %s" % (sKey, trConst(sLabel))
-            minSize = max(minSize, qMetrics.boundingRect(text).width())
+            text = f"[ {sKey} ] {trConst(sLabel)}"
+            minSize = max(minSize, metrics.boundingRect(text).width())
             qtItem = QListWidgetItem(text)
             qtItem.setData(self.D_KEY, sKey)
             self.listBox.addItem(qtItem)
             if sKey == current:
                 self.listBox.setCurrentItem(qtItem)
 
-        self.listBox.setMinimumWidth(minSize + CONFIG.pxInt(40))
-        self.listBox.setMinimumHeight(CONFIG.pxInt(150))
+        self.listBox.setMinimumWidth(minSize + 40)
+        self.listBox.setMinimumHeight(150)
 
         # Buttons
         self.buttonBox = QDialogButtonBox(QtDialogOk | QtDialogCancel, self)
@@ -127,11 +122,11 @@ class GuiQuoteSelect(NDialog):
     @classmethod
     def getQuote(cls, parent: QWidget, current: str = "") -> tuple[str, bool]:
         """Pop the dialog and return the result."""
-        cls = GuiQuoteSelect(parent, current=current)
-        cls.exec()
-        quote = cls._selected
-        accepted = cls.result() == QtAccepted
-        cls.softDelete()
+        dialog = cls(parent, current=current)
+        dialog.exec()
+        quote = dialog._selected
+        accepted = dialog.result() == QtAccepted
+        dialog.softDelete()
         return quote, accepted
 
     ##
