@@ -28,11 +28,10 @@ import logging
 import re
 
 from abc import ABC, abstractmethod
-from pathlib import Path
-from typing import NamedTuple
+from typing import TYPE_CHECKING, NamedTuple
 
-from PyQt5.QtCore import QLocale
-from PyQt5.QtGui import QColor, QFont
+from PyQt6.QtCore import QLocale
+from PyQt6.QtGui import QColor, QFont
 
 from novelwriter import CONFIG
 from novelwriter.common import checkInt, fontMatcher, numberToRoman
@@ -40,14 +39,18 @@ from novelwriter.constants import (
     nwHeadFmt, nwKeyWords, nwLabels, nwShortcode, nwStats, nwStyles, nwUnicode,
     trConst
 )
-from novelwriter.core.index import processComment
-from novelwriter.core.project import NWProject
 from novelwriter.enum import nwComment, nwItemLayout
 from novelwriter.formats.shared import (
     BlockFmt, BlockTyp, T_Block, T_Formats, T_Note, TextDocumentTheme, TextFmt
 )
+from novelwriter.text.comments import processComment
 from novelwriter.text.patterns import REGEX_PATTERNS, DialogParser
 
+if TYPE_CHECKING:
+    from pathlib import Path
+
+    from novelwriter.core.project import NWProject
+
 logger = logging.getLogger(__name__)
 
 
@@ -61,18 +64,18 @@ class ComStyle(NamedTuple):
 COMMENT_STYLE = {
     nwComment.PLAIN:    ComStyle("Comment", "comment", "comment"),
     nwComment.IGNORE:   ComStyle(),
-    nwComment.SYNOPSIS: ComStyle("Synopsis", "modifier", "synopsis"),
-    nwComment.SHORT:    ComStyle("Short Description", "modifier", "synopsis"),
+    nwComment.SYNOPSIS: ComStyle("Synopsis", "modifier", "note"),
+    nwComment.SHORT:    ComStyle("Short Description", "modifier", "note"),
     nwComment.NOTE:     ComStyle("Note", "modifier", "note"),
     nwComment.FOOTNOTE: ComStyle("", "modifier", "note"),
     nwComment.COMMENT:  ComStyle(),
-    nwComment.STORY:    ComStyle("", "modifier", "note"),
+    nwComment.STORY:    ComStyle("Story Structure", "modifier", "note"),
 }
 HEADINGS = [
     BlockTyp.TITLE, BlockTyp.PART, BlockTyp.HEAD1,
     BlockTyp.HEAD2, BlockTyp.HEAD3, BlockTyp.HEAD4,
 ]
-SKIP_INDENT = HEADINGS + [BlockTyp.SEP, BlockTyp.SKIP]
+SKIP_INDENT = [*HEADINGS, BlockTyp.SEP, BlockTyp.SKIP]
 B_EMPTY: T_Block = (BlockTyp.EMPTY, "", "", [], BlockFmt.NONE)
 
 
@@ -118,14 +121,16 @@ class Tokenizer(ABC):
         self._indentFirst  = False   # Indent first paragraph
         self._doJustify    = False   # Justify text
         self._doBodyText   = True    # Include body text
-        self._doSynopsis   = False   # Also process synopsis comments
-        self._doComments   = False   # Also process comments
+        self._doComments   = set()   # Comment styles to allow
         self._doKeywords   = False   # Also process keywords like tags and references
         self._keepBreaks   = True    # Keep line breaks in paragraphs
         self._defaultAlign = "left"  # The default text alignment
 
         self._skipKeywords: set[str] = set()  # Keywords to ignore
 
+        # Defaults
+        self._doComments.add(nwComment.FOOTNOTE)
+
         # Other Setting
         self._theme = TextDocumentTheme()
         self._classes: dict[str, QColor] = {}
@@ -393,14 +398,12 @@ class Tokenizer(ABC):
         self._doBodyText = state
         return
 
-    def setSynopsis(self, state: bool) -> None:
-        """Include synopsis comments in build."""
-        self._doSynopsis = state
-        return
-
-    def setComments(self, state: bool) -> None:
-        """Include comments in build."""
-        self._doComments = state
+    def setCommentType(self, comment: nwComment, state: bool) -> None:
+        """Toggle the inclusion og certain comment types."""
+        if state:
+            self._doComments.add(comment)
+        else:
+            self._doComments.discard(comment)
         return
 
     def setKeywords(self, state: bool) -> None:
@@ -437,7 +440,7 @@ class Tokenizer(ABC):
     def initDocument(self) -> None:
         """Initialise data after settings."""
         self._classes["modifier"] = self._theme.modifier
-        self._classes["synopsis"] = self._theme.note
+        self._classes["note"] = self._theme.note
         self._classes["comment"] = self._theme.comment
         self._classes["dialog"] = self._theme.dialog
         self._classes["altdialog"] = self._theme.altdialog
@@ -492,12 +495,10 @@ class Tokenizer(ABC):
     def doPreProcessing(self) -> None:
         """Run pre-processing jobs before the text is tokenized."""
         # Process the user's auto-replace dictionary
-        if autoReplace := self._project.data.autoReplace:
-            repDict = {}
-            for aKey, aVal in autoReplace.items():
-                repDict[f"<{aKey}>"] = aVal
-            xRep = re.compile("|".join([re.escape(k) for k in repDict.keys()]), flags=re.DOTALL)
-            self._text = xRep.sub(lambda x: repDict[x.group(0)], self._text)
+        if entry := self._project.data.autoReplace:
+            replace = {f"<{k}>": v for k, v in entry.items()}
+            rxRep = re.compile("|".join([re.escape(k) for k in replace]), flags=re.DOTALL)
+            self._text = rxRep.sub(lambda x: replace[x.group(0)], self._text)
         return
 
     def tokenizeText(self) -> None:
@@ -604,15 +605,16 @@ class Tokenizer(ABC):
                     continue
 
                 cStyle, cKey, cText, _, _ = processComment(aLine)
-                if cStyle in (nwComment.SYNOPSIS, nwComment.SHORT) and not self._doSynopsis:
-                    continue
-                if cStyle == nwComment.PLAIN and not self._doComments:
+                if cStyle not in self._doComments:
                     continue
 
                 if doJustify and not tStyle & BlockFmt.ALIGNED:
                     tStyle |= BlockFmt.JUSTIFY
 
-                if cStyle in (nwComment.SYNOPSIS, nwComment.SHORT, nwComment.PLAIN):
+                if cStyle in (
+                    nwComment.SYNOPSIS, nwComment.SHORT, nwComment.PLAIN,
+                    nwComment.STORY, nwComment.NOTE,
+                ):
                     bStyle = COMMENT_STYLE[cStyle]
                     tLine, tFmt = self._formatComment(bStyle, cKey, cText)
                     tBlocks.append((
@@ -651,7 +653,7 @@ class Tokenizer(ABC):
                 tText = aLine[2:].strip()
                 tType = BlockTyp.HEAD1 if isPlain else BlockTyp.TITLE
                 sHide = self._hidePart if isPlain else False
-                if not (isPlain or isNovel and sHide):
+                if not (isPlain or (isNovel and sHide)):
                     tStyle |= self._titleStyle
                 if isNovel:
                     tType = BlockTyp.PART if isPlain else BlockTyp.TITLE
@@ -878,31 +880,21 @@ class Tokenizer(ABC):
                 if nBlock[0] != BlockTyp.TEXT:
                     # Next block is not text, so we add the buffer to blocks
                     nLines = len(pLines)
-                    cStyle = pLines[0][4]
-                    if firstIndent and not (self._noIndent or cStyle & BlockFmt.ALIGNED):
-                        # If paragraph indentation is enabled, not temporarily
-                        # turned off, and the block is not aligned, we add the
-                        # text indentation flag
-                        cStyle |= BlockFmt.IND_T
+                    tFmt: T_Formats = []
+                    pTxt = ""
+                    cStyle = BlockFmt.NONE
 
                     if nLines == 1:
-                        # The paragraph contains a single line, so we just save
-                        # that directly to the blocks list. If justify is
-                        # enabled, and there is no alignment, we apply it.
-                        if doJustify and not cStyle & BlockFmt.ALIGNED:
-                            cStyle |= BlockFmt.JUSTIFY
-
+                        # The paragraph contains a single line
+                        tFmt = pLines[0][3]
                         pTxt = pLines[0][2].translate(transMapB)
-                        sBlocks.append((
-                            BlockTyp.TEXT, pLines[0][1], pTxt, pLines[0][3], cStyle
-                        ))
+                        cStyle = pLines[0][4]
 
                     elif nLines > 1:
                         # The paragraph contains multiple lines, so we need to
                         # join them according to the line break policy, and
                         # recompute all the formatting markers
                         tTxt = ""
-                        tFmt: T_Formats = []
                         for aBlock in pLines:
                             tLen = len(tTxt)
                             tTxt += f"{aBlock[2]}{lineSep}"
@@ -910,6 +902,18 @@ class Tokenizer(ABC):
                             cStyle |= aBlock[4]
 
                         pTxt = tTxt[:-1].translate(transMapB)
+
+                    if nLines:
+                        isAligned = cStyle & BlockFmt.ALIGNED
+                        if firstIndent and not (self._noIndent or isAligned):
+                            # If paragraph indentation is enabled, not temporarily
+                            # turned off, and the block is not aligned, we add the
+                            # text indentation flag
+                            cStyle |= BlockFmt.IND_T
+
+                        if doJustify and not isAligned:
+                            cStyle |= BlockFmt.JUSTIFY
+
                         sBlocks.append((
                             BlockTyp.TEXT, pLines[0][1], pTxt, tFmt, cStyle
                         ))
@@ -1034,10 +1038,12 @@ class Tokenizer(ABC):
 
     def _formatComment(self, style: ComStyle, key: str, text: str) -> tuple[str, T_Formats]:
         """Apply formatting to comments and notes."""
+        rFmt = []
         tTxt, tFmt = self._extractFormats(text)
         tFmt.insert(0, (0, TextFmt.COL_B, style.textClass))
         tFmt.append((len(tTxt), TextFmt.COL_E, ""))
-        if label := (self._localLookup(style.label) + (f" ({key})" if key else "")).strip():
+        term = f" ({key.title()})" if key else ""
+        if label := f"{self._localLookup(style.label)}{term}".strip():
             shift = len(label) + 2
             tTxt = f"{label}: {tTxt}"
             rFmt = [(0, TextFmt.B_B, ""), (shift - 1, TextFmt.B_E, "")]
@@ -1123,12 +1129,10 @@ class Tokenizer(ABC):
             temp.append((res.end(0), 0, TextFmt.HRF_E, ""))
 
         # Match Shortcodes
-        for res in REGEX_PATTERNS.shortcodePlain.finditer(text):
-            temp.append((
-                res.start(1), res.end(1),
-                self._shortCodeFmt.get(res.group(1).lower(), 0),
-                "",
-            ))
+        temp.extend(
+            (res.start(1), res.end(1), self._shortCodeFmt.get(res.group(1).lower(), 0), "")
+            for res in REGEX_PATTERNS.shortcodePlain.finditer(text)
+        )
 
         # Match Shortcode w/Values
         tHandle = self._handle or ""
@@ -1166,12 +1170,18 @@ class Tokenizer(ABC):
 
 class HeadingFormatter:
 
-    def __init__(self, project: NWProject) -> None:
+    def __init__(
+        self,
+        project: NWProject,
+        chapter: int = 0,
+        scene: int = 0,
+        absolute: int = 0,
+    ) -> None:
         self._project = project
         self._handle = None
-        self._chCount = 0
-        self._scChCount = 0
-        self._scAbsCount = 0
+        self._chapter = chapter
+        self._scene = scene
+        self._absolute = absolute
         return
 
     def setHandle(self, tHandle: str | None) -> None:
@@ -1181,42 +1191,42 @@ class HeadingFormatter:
 
     def incChapter(self) -> None:
         """Increment the chapter counter."""
-        self._chCount += 1
+        self._chapter += 1
         return
 
     def incScene(self) -> None:
         """Increment the scene counters."""
-        self._scChCount += 1
-        self._scAbsCount += 1
+        self._scene += 1
+        self._absolute += 1
         return
 
     def resetAll(self) -> None:
         """Reset all counters."""
-        self._chCount = 0
-        self._scChCount = 0
-        self._scAbsCount = 0
+        self._chapter = 0
+        self._scene = 0
+        self._absolute = 0
         return
 
     def resetScene(self) -> None:
         """Reset the chapter scene counter."""
-        self._scChCount = 0
+        self._scene = 0
         return
 
     def apply(self, hFormat: str, text: str, nHead: int) -> str:
         """Apply formatting to a specific heading."""
         hFormat = hFormat.replace(nwHeadFmt.TITLE, text)
         hFormat = hFormat.replace(nwHeadFmt.BR, "\n")
-        hFormat = hFormat.replace(nwHeadFmt.CH_NUM, str(self._chCount))
-        hFormat = hFormat.replace(nwHeadFmt.SC_NUM, str(self._scChCount))
-        hFormat = hFormat.replace(nwHeadFmt.SC_ABS, str(self._scAbsCount))
+        hFormat = hFormat.replace(nwHeadFmt.CH_NUM, str(self._chapter))
+        hFormat = hFormat.replace(nwHeadFmt.SC_NUM, str(self._scene))
+        hFormat = hFormat.replace(nwHeadFmt.SC_ABS, str(self._absolute))
         if nwHeadFmt.CH_WORD in hFormat:
-            chWord = self._project.localLookup(self._chCount)
+            chWord = self._project.localLookup(self._chapter)
             hFormat = hFormat.replace(nwHeadFmt.CH_WORD, chWord)
         if nwHeadFmt.CH_ROML in hFormat:
-            chRom = numberToRoman(self._chCount, toLower=True)
+            chRom = numberToRoman(self._chapter, toLower=True)
             hFormat = hFormat.replace(nwHeadFmt.CH_ROML, chRom)
         if nwHeadFmt.CH_ROMU in hFormat:
-            chRom = numberToRoman(self._chCount, toLower=False)
+            chRom = numberToRoman(self._chapter, toLower=False)
             hFormat = hFormat.replace(nwHeadFmt.CH_ROMU, chRom)
 
         if nwHeadFmt.CHAR_POV in hFormat or nwHeadFmt.CHAR_FOCUS in hFormat:
