@@ -29,8 +29,8 @@ import re
 
 from time import time
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtGui import (
+from PyQt6.QtCore import Qt
+from PyQt6.QtGui import (
     QBrush, QColor, QFont, QSyntaxHighlighter, QTextBlockUserData,
     QTextCharFormat, QTextDocument
 )
@@ -38,8 +38,8 @@ from PyQt5.QtGui import (
 from novelwriter import CONFIG, SHARED
 from novelwriter.common import checkInt
 from novelwriter.constants import nwStyles, nwUnicode
-from novelwriter.core.index import processComment
 from novelwriter.enum import nwComment
+from novelwriter.text.comments import processComment
 from novelwriter.text.patterns import REGEX_PATTERNS, DialogParser
 
 logger = logging.getLogger(__name__)
@@ -58,8 +58,8 @@ BLOCK_TITLE = 4
 class GuiDocHighlighter(QSyntaxHighlighter):
 
     __slots__ = (
-        "_tHandle", "_isNovel", "_isInactive", "_spellCheck", "_spellErr",
-        "_hStyles", "_minRules", "_txtRules", "_cmnRules", "_dialogParser",
+        "_cmnRules", "_dialogParser", "_hStyles", "_isInactive", "_isNovel",
+        "_minRules", "_spellCheck", "_spellErr", "_tHandle", "_txtRules",
     )
 
     def __init__(self, document: QTextDocument) -> None:
@@ -91,44 +91,45 @@ class GuiDocHighlighter(QSyntaxHighlighter):
         rules and building the RegExes.
         """
         logger.debug("Setting up highlighting rules")
+        syntax = SHARED.theme.syntaxTheme
 
-        colEmph = SHARED.theme.colEmph if CONFIG.highlightEmph else None
-        colBreak = QColor(SHARED.theme.colEmph)
+        colEmph = syntax.emph if CONFIG.highlightEmph else None
+        colBreak = QColor(syntax.emph)
         colBreak.setAlpha(64)
 
         # Create Character Formats
-        self._addCharFormat("text",      SHARED.theme.colText)
-        self._addCharFormat("header1",   SHARED.theme.colHead, "b", nwStyles.H_SIZES[1])
-        self._addCharFormat("header2",   SHARED.theme.colHead, "b", nwStyles.H_SIZES[2])
-        self._addCharFormat("header3",   SHARED.theme.colHead, "b", nwStyles.H_SIZES[3])
-        self._addCharFormat("header4",   SHARED.theme.colHead, "b", nwStyles.H_SIZES[4])
-        self._addCharFormat("head1h",    SHARED.theme.colHeadH, "b", nwStyles.H_SIZES[1])
-        self._addCharFormat("head2h",    SHARED.theme.colHeadH, "b", nwStyles.H_SIZES[2])
-        self._addCharFormat("head3h",    SHARED.theme.colHeadH, "b", nwStyles.H_SIZES[3])
-        self._addCharFormat("head4h",    SHARED.theme.colHeadH, "b", nwStyles.H_SIZES[4])
+        self._addCharFormat("text",      syntax.text)
+        self._addCharFormat("header1",   syntax.head, "b", nwStyles.H_SIZES[1])
+        self._addCharFormat("header2",   syntax.head, "b", nwStyles.H_SIZES[2])
+        self._addCharFormat("header3",   syntax.head, "b", nwStyles.H_SIZES[3])
+        self._addCharFormat("header4",   syntax.head, "b", nwStyles.H_SIZES[4])
+        self._addCharFormat("head1h",    syntax.headH, "b", nwStyles.H_SIZES[1])
+        self._addCharFormat("head2h",    syntax.headH, "b", nwStyles.H_SIZES[2])
+        self._addCharFormat("head3h",    syntax.headH, "b", nwStyles.H_SIZES[3])
+        self._addCharFormat("head4h",    syntax.headH, "b", nwStyles.H_SIZES[4])
         self._addCharFormat("bold",      colEmph, "b")
         self._addCharFormat("italic",    colEmph, "i")
-        self._addCharFormat("strike",    SHARED.theme.colHidden, "s")
-        self._addCharFormat("mspaces",   SHARED.theme.colError, "err")
+        self._addCharFormat("strike",    syntax.hidden, "s")
+        self._addCharFormat("mspaces",   syntax.error, "err")
         self._addCharFormat("nobreak",   colBreak, "bg")
-        self._addCharFormat("altdialog", SHARED.theme.colDialA)
-        self._addCharFormat("dialog",    SHARED.theme.colDialN)
-        self._addCharFormat("replace",   SHARED.theme.colRepTag)
-        self._addCharFormat("hidden",    SHARED.theme.colHidden)
-        self._addCharFormat("markup",    SHARED.theme.colHidden)
-        self._addCharFormat("link",      SHARED.theme.colLink, "u")
-        self._addCharFormat("note",      SHARED.theme.colNote)
-        self._addCharFormat("code",      SHARED.theme.colCode)
-        self._addCharFormat("keyword",   SHARED.theme.colKey)
-        self._addCharFormat("tag",       SHARED.theme.colTag, "u")
-        self._addCharFormat("modifier",  SHARED.theme.colMod)
-        self._addCharFormat("value",     SHARED.theme.colVal)
-        self._addCharFormat("optional",  SHARED.theme.colOpt)
+        self._addCharFormat("altdialog", syntax.dialA)
+        self._addCharFormat("dialog",    syntax.dialN)
+        self._addCharFormat("replace",   syntax.repTag)
+        self._addCharFormat("hidden",    syntax.hidden)
+        self._addCharFormat("markup",    syntax.hidden)
+        self._addCharFormat("link",      syntax.link, "u")
+        self._addCharFormat("note",      syntax.note)
+        self._addCharFormat("code",      syntax.code)
+        self._addCharFormat("keyword",   syntax.key)
+        self._addCharFormat("tag",       syntax.tag, "u")
+        self._addCharFormat("modifier",  syntax.mod)
+        self._addCharFormat("value",     syntax.val)
+        self._addCharFormat("optional",  syntax.opt)
         self._addCharFormat("invalid",   None, "err")
 
         # Cache Spell Error Format
         self._spellErr = QTextCharFormat()
-        self._spellErr.setUnderlineColor(SHARED.theme.colSpell)
+        self._spellErr.setUnderlineColor(syntax.spell)
         self._spellErr.setUnderlineStyle(QTextCharFormat.UnderlineStyle.SpellCheckUnderline)
 
         self._txtRules.clear()
@@ -271,14 +272,14 @@ class GuiDocHighlighter(QSyntaxHighlighter):
         """Loop through all blocks and re-highlight those of a given
         content type.
         """
-        qDoc = self.document()
-        nBlocks = qDoc.blockCount()
-        tStart = time()
-        for i in range(nBlocks):
-            block = qDoc.findBlockByNumber(i)
-            if block.userState() & cType > 0:
-                self.rehighlightBlock(block)
-        logger.debug("Document highlighted in %.3f ms" % (1000*(time() - tStart)))
+        if document := self.document():
+            nBlocks = document.blockCount()
+            tStart = time()
+            for i in range(nBlocks):
+                block = document.findBlockByNumber(i)
+                if block.userState() & cType > 0:
+                    self.rehighlightBlock(block)
+            logger.debug("Document highlighted in %.3f ms" % (1000*(time() - tStart)))
         return
 
     ##
@@ -392,7 +393,7 @@ class GuiDocHighlighter(QSyntaxHighlighter):
         else:  # Text Paragraph
             self.setCurrentBlockState(BLOCK_TEXT)
             hRules = self._txtRules if self._isNovel else self._minRules
-            if self._dialogParser.enabled:
+            if self._isNovel and self._dialogParser.enabled:
                 for pos, end in self._dialogParser(text):
                     length = end - pos
                     self.setFormat(pos, length, self._hStyles["dialog"])
@@ -450,7 +451,7 @@ class GuiDocHighlighter(QSyntaxHighlighter):
             if "s" in styles:
                 charFormat.setFontStrikeOut(True)
             if "err" in styles:
-                charFormat.setUnderlineColor(SHARED.theme.colError)
+                charFormat.setUnderlineColor(SHARED.theme.syntaxTheme.error)
                 charFormat.setUnderlineStyle(QTextCharFormat.UnderlineStyle.SpellCheckUnderline)
             if "bg" in styles and color is not None:
                 charFormat.setBackground(QBrush(color, Qt.BrushStyle.SolidPattern))
@@ -465,14 +466,14 @@ class GuiDocHighlighter(QSyntaxHighlighter):
 
 class TextBlockData(QTextBlockUserData):
 
-    __slots__ = ("_text", "_offset", "_metaData", "_spellErrors")
+    __slots__ = ("_metaData", "_offset", "_spellErrors", "_text")
 
     def __init__(self) -> None:
         super().__init__()
         self._text = ""
         self._offset = 0
         self._metaData: list[tuple[int, int, str, str]] = []
-        self._spellErrors: list[tuple[int, int,]] = []
+        self._spellErrors: list[tuple[int, int]] = []
         return
 
     @property
@@ -504,7 +505,7 @@ class TextBlockData(QTextBlockUserData):
                     text = f"{text[:s]}{pad}{text[e:]}"
                     self._metaData.append((s, e, res.group(0), "url"))
 
-        self._text = text
+        self._text = text.replace("\u02bc", "'")
         self._offset = offset
 
         return
