@@ -32,15 +32,15 @@ import logging
 
 from enum import Enum
 
-from PyQt5.QtCore import QModelIndex, QPoint, Qt, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QIcon, QMouseEvent, QPainter, QPalette
-from PyQt5.QtWidgets import (
-    QAbstractItemView, QAction, QFrame, QHBoxLayout, QLabel, QMenu, QShortcut,
+from PyQt6.QtCore import QModelIndex, QPoint, Qt, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QAction, QIcon, QMouseEvent, QPainter, QPalette, QShortcut
+from PyQt6.QtWidgets import (
+    QAbstractItemView, QFrame, QHBoxLayout, QLabel, QMenu,
     QStyleOptionViewItem, QTreeView, QVBoxLayout, QWidget
 )
 
 from novelwriter import CONFIG, SHARED
-from novelwriter.common import qtLambda
+from novelwriter.common import qtAddAction, qtAddMenu, qtLambda
 from novelwriter.constants import nwLabels, nwStyles, nwUnicode, trConst
 from novelwriter.core.coretools import DocDuplicator, DocMerger, DocSplitter
 from novelwriter.core.item import NWItem
@@ -244,9 +244,9 @@ class GuiProjectToolBar(QWidget):
         self.projTree = projView.projTree
 
         iSz = SHARED.theme.baseIconSize
-        mPx = CONFIG.pxInt(2)
 
         self.setContentsMargins(0, 0, 0, 0)
+        self.setBackgroundRole(QPalette.ColorRole.Base)
         self.setAutoFillBackground(True)
 
         # Widget Label
@@ -254,48 +254,54 @@ class GuiProjectToolBar(QWidget):
         self.viewLabel.setFont(SHARED.theme.guiFontB)
         self.viewLabel.setContentsMargins(0, 0, 0, 0)
         self.viewLabel.setSizePolicy(QtSizeExpanding, QtSizeExpanding)
+        self.projTree.setAccessibleName(self.viewLabel.text())
 
         # Quick Links
         self.mQuick = QMenu(self)
 
         self.tbQuick = NIconToolButton(self, iSz)
-        self.tbQuick.setToolTip("%s [Ctrl+L]" % self.tr("Quick Links"))
+        self.tbQuick.setToolTip("{0} [Ctrl+L]".format(self.tr("Quick Links")))
         self.tbQuick.setShortcut("Ctrl+L")
         self.tbQuick.setMenu(self.mQuick)
 
         # Move Buttons
         self.tbMoveU = NIconToolButton(self, iSz)
-        self.tbMoveU.setToolTip("%s [Ctrl+Up]" % self.tr("Move Up"))
+        self.tbMoveU.setToolTip("{0} [Ctrl+Up]".format(self.tr("Move Up")))
         self.tbMoveU.clicked.connect(self.projTree.moveItemUp)
 
         self.tbMoveD = NIconToolButton(self, iSz)
-        self.tbMoveD.setToolTip("%s [Ctrl+Down]" % self.tr("Move Down"))
+        self.tbMoveD.setToolTip("{0} [Ctrl+Down]".format(self.tr("Move Down")))
         self.tbMoveD.clicked.connect(self.projTree.moveItemDown)
 
         # Add Item Menu
         self.mAdd = QMenu(self)
 
-        self.aAddEmpty = self.mAdd.addAction(trConst(nwLabels.ITEM_DESCRIPTION["document"]))
-        self.aAddEmpty.triggered.connect(
-            qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=0, isNote=False)
-        )
-
-        self.aAddChap = self.mAdd.addAction(trConst(nwLabels.ITEM_DESCRIPTION["doc_h2"]))
-        self.aAddChap.triggered.connect(
-            qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=2, isNote=False)
-        )
-
-        self.aAddScene = self.mAdd.addAction(trConst(nwLabels.ITEM_DESCRIPTION["doc_h3"]))
+        self.aAddScene = qtAddAction(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["doc_h3"]))
         self.aAddScene.triggered.connect(
             qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=3, isNote=False)
         )
 
-        self.aAddNote = self.mAdd.addAction(trConst(nwLabels.ITEM_DESCRIPTION["note"]))
+        self.aAddChap = qtAddAction(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["doc_h2"]))
+        self.aAddChap.triggered.connect(
+            qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=2, isNote=False)
+        )
+
+        self.aAddPart = qtAddAction(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["doc_h1"]))
+        self.aAddPart.triggered.connect(
+            qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=1, isNote=False)
+        )
+
+        self.aAddEmpty = qtAddAction(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["document"]))
+        self.aAddEmpty.triggered.connect(
+            qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=0, isNote=False)
+        )
+
+        self.aAddNote = qtAddAction(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["note"]))
         self.aAddNote.triggered.connect(
             qtLambda(self.projTree.newTreeItem, nwItemType.FILE, hLevel=1, isNote=True)
         )
 
-        self.aAddFolder = self.mAdd.addAction(trConst(nwLabels.ITEM_DESCRIPTION["folder"]))
+        self.aAddFolder = qtAddAction(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["folder"]))
         self.aAddFolder.triggered.connect(
             qtLambda(self.projTree.newTreeItem, nwItemType.FOLDER)
         )
@@ -305,24 +311,24 @@ class GuiProjectToolBar(QWidget):
         self.mTemplates.menuItemTriggered.connect(lambda h: self.newDocumentFromTemplate.emit(h))
         self.mAdd.addMenu(self.mTemplates)
 
-        self.mAddRoot = self.mAdd.addMenu(trConst(nwLabels.ITEM_DESCRIPTION["root"]))
+        self.mAddRoot = qtAddMenu(self.mAdd, trConst(nwLabels.ITEM_DESCRIPTION["root"]))
         self._buildRootMenu()
 
         self.tbAdd = NIconToolButton(self, iSz)
-        self.tbAdd.setToolTip("%s [Ctrl+N]" % self.tr("Add Item"))
+        self.tbAdd.setToolTip("{0} [Ctrl+N]".format(self.tr("Add Item")))
         self.tbAdd.setShortcut("Ctrl+N")
         self.tbAdd.setMenu(self.mAdd)
 
         # More Options Menu
         self.mMore = QMenu(self)
 
-        self.aExpand = self.mMore.addAction(self.tr("Expand All"))
+        self.aExpand = qtAddAction(self.mMore, self.tr("Expand All"))
         self.aExpand.triggered.connect(self.projTree.expandAll)
 
-        self.aCollapse = self.mMore.addAction(self.tr("Collapse All"))
+        self.aCollapse = qtAddAction(self.mMore, self.tr("Collapse All"))
         self.aCollapse.triggered.connect(self.projTree.collapseAll)
 
-        self.aEmptyTrash = self.mMore.addAction(self.tr("Empty Trash"))
+        self.aEmptyTrash = qtAddAction(self.mMore, self.tr("Empty Trash"))
         self.aEmptyTrash.triggered.connect(self.projTree.emptyTrash)
 
         self.tbMore = NIconToolButton(self, iSz)
@@ -337,7 +343,7 @@ class GuiProjectToolBar(QWidget):
         self.outerBox.addWidget(self.tbMoveD)
         self.outerBox.addWidget(self.tbAdd)
         self.outerBox.addWidget(self.tbMore)
-        self.outerBox.setContentsMargins(mPx, mPx, 0, mPx)
+        self.outerBox.setContentsMargins(4, 2, 0, 2)
         self.outerBox.setSpacing(0)
 
         self.setLayout(self.outerBox)
@@ -353,10 +359,6 @@ class GuiProjectToolBar(QWidget):
 
     def updateTheme(self) -> None:
         """Update theme elements."""
-        qPalette = self.palette()
-        qPalette.setBrush(QPalette.ColorRole.Window, qPalette.base())
-        self.setPalette(qPalette)
-
         buttonStyle = SHARED.theme.getStyleSheet(STYLES_MIN_TOOLBUTTON)
         self.tbQuick.setStyleSheet(buttonStyle)
         self.tbMoveU.setStyleSheet(buttonStyle)
@@ -364,17 +366,18 @@ class GuiProjectToolBar(QWidget):
         self.tbAdd.setStyleSheet(buttonStyle)
         self.tbMore.setStyleSheet(buttonStyle)
 
-        self.tbQuick.setThemeIcon("bookmark")
-        self.tbMoveU.setThemeIcon("up")
-        self.tbMoveD.setThemeIcon("down")
-        self.tbAdd.setThemeIcon("add")
-        self.tbMore.setThemeIcon("menu")
+        self.tbQuick.setThemeIcon("bookmarks", "blue")
+        self.tbMoveU.setThemeIcon("chevron_up", "blue")
+        self.tbMoveD.setThemeIcon("chevron_down", "blue")
+        self.tbAdd.setThemeIcon("add", "green")
+        self.tbMore.setThemeIcon("more_vertical")
 
-        self.aAddEmpty.setIcon(SHARED.theme.getIcon("proj_document"))
-        self.aAddChap.setIcon(SHARED.theme.getIcon("proj_chapter"))
-        self.aAddScene.setIcon(SHARED.theme.getIcon("proj_scene"))
-        self.aAddNote.setIcon(SHARED.theme.getIcon("proj_note"))
-        self.aAddFolder.setIcon(SHARED.theme.getIcon("proj_folder"))
+        self.aAddScene.setIcon(SHARED.theme.getIcon("prj_scene", "scene"))
+        self.aAddChap.setIcon(SHARED.theme.getIcon("prj_chapter", "chapter"))
+        self.aAddPart.setIcon(SHARED.theme.getIcon("prj_title", "title"))
+        self.aAddEmpty.setIcon(SHARED.theme.getIcon("prj_document", "file"))
+        self.aAddNote.setIcon(SHARED.theme.getIcon("prj_note", "note"))
+        self.aAddFolder.setIcon(SHARED.theme.getIcon("prj_folder", "folder"))
 
         self.buildTemplatesMenu()
         self.buildQuickLinksMenu()
@@ -393,9 +396,9 @@ class GuiProjectToolBar(QWidget):
         logger.debug("Rebuilding quick links menu")
         self.mQuick.clear()
         for tHandle, nwItem in SHARED.project.tree.iterRoots(None):
-            action = self.mQuick.addAction(nwItem.itemName)
+            action = qtAddAction(self.mQuick, nwItem.itemName)
             action.setData(tHandle)
-            action.setIcon(SHARED.theme.getIcon(nwLabels.CLASS_ICON[nwItem.itemClass]))
+            action.setIcon(SHARED.theme.getIcon(nwLabels.CLASS_ICON[nwItem.itemClass], "root"))
             action.triggered.connect(
                 qtLambda(self.projView.setSelectedHandle, tHandle, doScroll=True)
             )
@@ -429,9 +432,10 @@ class GuiProjectToolBar(QWidget):
         """
         nwItem = SHARED.project.tree[tHandle]
         allowDoc = isinstance(nwItem, NWItem) and nwItem.documentAllowed()
-        self.aAddEmpty.setVisible(allowDoc)
-        self.aAddChap.setVisible(allowDoc)
         self.aAddScene.setVisible(allowDoc)
+        self.aAddChap.setVisible(allowDoc)
+        self.aAddPart.setVisible(allowDoc)
+        self.aAddEmpty.setVisible(allowDoc)
         return
 
     ##
@@ -441,8 +445,8 @@ class GuiProjectToolBar(QWidget):
     def _buildRootMenu(self) -> None:
         """Build the rood folder menu."""
         def addClass(itemClass: nwItemClass) -> None:
-            aNew = self.mAddRoot.addAction(trConst(nwLabels.CLASS_NAME[itemClass]))
-            aNew.setIcon(SHARED.theme.getIcon(nwLabels.CLASS_ICON[itemClass]))
+            aNew = qtAddAction(self.mAddRoot, trConst(nwLabels.CLASS_NAME[itemClass]))
+            aNew.setIcon(SHARED.theme.getIcon(nwLabels.CLASS_ICON[itemClass], "root"))
             aNew.triggered.connect(
                 qtLambda(self.projTree.newTreeItem, nwItemType.ROOT, itemClass)
             )
@@ -507,7 +511,6 @@ class GuiProjectTree(QTreeView):
         self.customContextMenuRequested.connect(self.openContextMenu)
 
         # Connect signals
-        self.clicked.connect(self._onSingleClick)
         self.doubleClicked.connect(self._onDoubleClick)
         self.collapsed.connect(self._onNodeCollapsed)
         self.expanded.connect(self._onNodeExpanded)
@@ -521,7 +524,6 @@ class GuiProjectTree(QTreeView):
 
     def initSettings(self) -> None:
         """Set or update tree widget settings."""
-        # Scroll bars
         if CONFIG.hideVScroll:
             self.setVerticalScrollBarPolicy(QtScrollAlwaysOff)
         else:
@@ -558,21 +560,26 @@ class GuiProjectTree(QTreeView):
 
     def loadModel(self) -> None:
         """Load and prepare a new project model."""
+        if selectModelOld := self.selectionModel():
+            selectModelOld.disconnect()
+
         self.setModel(SHARED.project.tree.model)
 
         # Lock the column sizes
         iPx = SHARED.theme.baseIconHeight
-        cMg = CONFIG.pxInt(6)
 
-        treeHeader = self.header()
-        treeHeader.setStretchLastSection(False)
-        treeHeader.setMinimumSectionSize(iPx + cMg)
-        treeHeader.setSectionResizeMode(ProjectNode.C_NAME, QtHeaderStretch)
-        treeHeader.setSectionResizeMode(ProjectNode.C_COUNT, QtHeaderToContents)
-        treeHeader.setSectionResizeMode(ProjectNode.C_ACTIVE, QtHeaderFixed)
-        treeHeader.setSectionResizeMode(ProjectNode.C_STATUS, QtHeaderFixed)
-        treeHeader.resizeSection(ProjectNode.C_ACTIVE, iPx + cMg)
-        treeHeader.resizeSection(ProjectNode.C_STATUS, iPx + cMg)
+        if header := self.header():
+            header.setStretchLastSection(False)
+            header.setMinimumSectionSize(iPx + 6)
+            header.setSectionResizeMode(ProjectNode.C_NAME, QtHeaderStretch)
+            header.setSectionResizeMode(ProjectNode.C_COUNT, QtHeaderToContents)
+            header.setSectionResizeMode(ProjectNode.C_ACTIVE, QtHeaderFixed)
+            header.setSectionResizeMode(ProjectNode.C_STATUS, QtHeaderFixed)
+            header.resizeSection(ProjectNode.C_ACTIVE, iPx + 6)
+            header.resizeSection(ProjectNode.C_STATUS, iPx + 6)
+
+        if selectModelNew := self.selectionModel():
+            selectModelNew.currentChanged.connect(self._onSelectionChange)
 
         self.restoreExpandedState()
 
@@ -612,12 +619,12 @@ class GuiProjectTree(QTreeView):
         tHandle = None
         if itemType == nwItemType.ROOT and isinstance(itemClass, nwItemClass):
 
-            pos = -1
+            sPos = -1
             if (node := self._getNode(self.currentIndex())) and (itemRoot := node.item.itemRoot):
                 if root := SHARED.project.tree.nodes.get(itemRoot):
-                    pos = root.row() + 1
+                    sPos = root.row() + 1
 
-            tHandle = SHARED.project.newRoot(itemClass, pos)
+            tHandle = SHARED.project.newRoot(itemClass, sPos)
             self.restoreExpandedState()
 
         elif itemType in (nwItemType.FILE, nwItemType.FOLDER):
@@ -630,52 +637,43 @@ class GuiProjectTree(QTreeView):
                 SHARED.error(self.tr("Cannot add new files or folders to the Trash folder."))
                 return
 
-            # Collect some information about the selected item
-            sLevel = nwStyles.H_LEVEL.get(node.item.mainHeading, 0)
-            sIsParent = node.childCount() > 0
-
-            # Set default label and determine if new item is to be added
-            # as child or sibling to the selected item
+            # Set default label and determine where to put the new item
+            nNote = isNote
+            nLevel = hLevel
             if itemType == nwItemType.FILE:
                 if copyDoc and (cItem := SHARED.project.tree[copyDoc]):
+                    nNote = cItem.isNoteLayout()
+                    nLevel = nwStyles.H_LEVEL.get(cItem.mainHeading, 0)
                     newLabel = cItem.itemName
-                    asChild = sIsParent and node.item.isDocumentLayout()
                 elif isNote:
                     newLabel = self.tr("New Note")
-                    asChild = sIsParent
+                elif hLevel == 1:
+                    newLabel = self.tr("New Part")
                 elif hLevel == 2:
                     newLabel = self.tr("New Chapter")
-                    asChild = sIsParent and node.item.isDocumentLayout() and sLevel < 2
                 elif hLevel == 3:
                     newLabel = self.tr("New Scene")
-                    asChild = sIsParent and node.item.isDocumentLayout() and sLevel < 3
                 else:
                     newLabel = self.tr("New Document")
-                    asChild = sIsParent and node.item.isDocumentLayout()
             else:
                 newLabel = self.tr("New Folder")
-                asChild = False
+                nLevel = 0
 
-            pos = -1
-            sHandle = None
-            if not (asChild or node.item.isFolderType() or node.item.isRootType()):
-                pos = node.row() + 1
-                sHandle = node.item.itemParent
-
-            sHandle = sHandle or node.item.itemHandle
-            newLabel, dlgOk = GuiEditLabel.getLabel(self, text=newLabel)
-            if dlgOk:
-                # Add the file or folder
-                if itemType == nwItemType.FILE:
-                    if tHandle := SHARED.project.newFile(newLabel, sHandle, pos):
-                        if copyDoc:
-                            SHARED.project.copyFileContent(tHandle, copyDoc)
-                        elif hLevel > 0:
-                            SHARED.project.writeNewFile(tHandle, hLevel, not isNote)
-                        SHARED.project.index.reIndexHandle(tHandle)
-                        SHARED.project.tree.refreshItems([tHandle])
-                else:
-                    tHandle = SHARED.project.newFolder(newLabel, sHandle, pos)
+            sHandle, sPos = SHARED.project.tree.pickParent(node, nLevel, nNote)
+            if sHandle:
+                newLabel, dlgOk = GuiEditLabel.getLabel(self, text=newLabel)
+                if dlgOk:
+                    # Add the file or folder
+                    if itemType == nwItemType.FILE:
+                        if tHandle := SHARED.project.newFile(newLabel, sHandle, sPos):
+                            if copyDoc:
+                                SHARED.project.copyFileContent(tHandle, copyDoc)
+                            elif hLevel > 0:
+                                SHARED.project.writeNewFile(tHandle, hLevel, not nNote)
+                            SHARED.project.index.reIndexHandle(tHandle)
+                            SHARED.project.tree.refreshItems([tHandle])
+                    else:
+                        tHandle = SHARED.project.newFolder(newLabel, sHandle, sPos)
 
         # Select the new item automatically
         if tHandle:
@@ -966,7 +964,8 @@ class GuiProjectTree(QTreeView):
                         ctxMenu.buildMultiSelectMenu()
                     else:
                         ctxMenu.buildSingleSelectMenu()
-                    ctxMenu.exec(self.viewport().mapToGlobal(point))
+                    if viewport := self.viewport():
+                        ctxMenu.exec(viewport.mapToGlobal(point))
                     ctxMenu.setParent(None)
         return
 
@@ -974,10 +973,10 @@ class GuiProjectTree(QTreeView):
     #  Private Slots
     ##
 
-    @pyqtSlot(QModelIndex)
-    def _onSingleClick(self, index: QModelIndex) -> None:
+    @pyqtSlot(QModelIndex, QModelIndex)
+    def _onSelectionChange(self, current: QModelIndex, previous: QModelIndex) -> None:
         """The user changed which item is selected."""
-        if node := self._getNode(index):
+        if node := self._getNode(current):
             self.projView.selectedItemChanged.emit(node.item.itemHandle)
         return
 
@@ -1026,7 +1025,7 @@ class GuiProjectTree(QTreeView):
         return [i for i in self.selectedIndexes() if i.column() == 0]
 
     def _getModel(self) -> ProjectModel | None:
-        """Return a project node corresponding to a model index."""
+        """Return the model, if it exists."""
         if isinstance(model := self.model(), ProjectModel):
             return model
         return None
@@ -1087,7 +1086,8 @@ class _UpdatableMenu(QMenu):
 
     def setActionsVisible(self, value: bool) -> None:
         """Set the visibility of root action."""
-        self.menuAction().setVisible(value)
+        if action := self.menuAction():
+            action.setVisible(value)
         return
 
     ##
@@ -1103,7 +1103,7 @@ class _UpdatableMenu(QMenu):
 
 class _TreeContextMenu(QMenu):
 
-    __slots__ = ("_tree", "_view", "_node", "_item", "_model", "_handle", "_indices", "_children")
+    __slots__ = ("_children", "_handle", "_indices", "_item", "_model", "_node", "_tree", "_view")
 
     def __init__(
         self, projTree: GuiProjectTree, model: ProjectModel,
@@ -1131,7 +1131,7 @@ class _TreeContextMenu(QMenu):
 
     def buildTrashMenu(self) -> None:
         """Build the special menu for the Trash folder."""
-        action = self.addAction(self.tr("Empty Trash"))
+        action = qtAddAction(self, self.tr("Empty Trash"))
         action.triggered.connect(self._tree.emptyTrash)
         if self._children:
             self._expandCollapse()
@@ -1152,7 +1152,7 @@ class _TreeContextMenu(QMenu):
         self.addSeparator()
 
         # Edit Item Settings
-        action = self.addAction(self.tr("Rename"))
+        action = qtAddAction(self, self.tr("Rename"))
         action.triggered.connect(qtLambda(self._view.renameTreeItem, self._handle))
         if isFile:
             self._itemHeader()
@@ -1167,7 +1167,7 @@ class _TreeContextMenu(QMenu):
         # Process Item
         if self._children:
             self._expandCollapse()
-        action = self.addAction(self.tr("Duplicate"))
+        action = qtAddAction(self, self.tr("Duplicate"))
         action.triggered.connect(qtLambda(self._tree.duplicateFromHandle, self._handle))
         self._deleteOrTrash()
 
@@ -1187,12 +1187,12 @@ class _TreeContextMenu(QMenu):
 
     def _docActions(self) -> None:
         """Add document actions."""
-        action = self.addAction(self.tr("Open Document"))
+        action = qtAddAction(self, self.tr("Open Document"))
         action.triggered.connect(qtLambda(
             self._view.openDocumentRequest.emit,
             self._handle, nwDocMode.EDIT, "", True
         ))
-        action = self.addAction(self.tr("View Document"))
+        action = qtAddAction(self, self.tr("View Document"))
         action.triggered.connect(qtLambda(
             self._view.openDocumentRequest.emit,
             self._handle, nwDocMode.VIEW, "", False
@@ -1201,10 +1201,11 @@ class _TreeContextMenu(QMenu):
 
     def _itemCreation(self) -> None:
         """Add create item actions."""
-        menu = self.addMenu(self.tr("Create New ..."))
-        menu.addAction(self._view.projBar.aAddEmpty)
-        menu.addAction(self._view.projBar.aAddChap)
+        menu = qtAddMenu(self, self.tr("Create New ..."))
         menu.addAction(self._view.projBar.aAddScene)
+        menu.addAction(self._view.projBar.aAddChap)
+        menu.addAction(self._view.projBar.aAddPart)
+        menu.addAction(self._view.projBar.aAddEmpty)
         menu.addAction(self._view.projBar.aAddNote)
         menu.addAction(self._view.projBar.aAddFolder)
         return
@@ -1213,7 +1214,7 @@ class _TreeContextMenu(QMenu):
         """Check if there is a header that can be used for rename."""
         SHARED.saveEditor()
         if hItem := SHARED.project.index.getItemHeading(self._handle, "T0001"):
-            action = self.addAction(self.tr("Rename to Heading"))
+            action = qtAddAction(self, self.tr("Rename to Heading"))
             action.triggered.connect(
                 qtLambda(self._view.renameTreeItem, self._handle, hItem.title)
             )
@@ -1222,50 +1223,54 @@ class _TreeContextMenu(QMenu):
     def _itemActive(self) -> None:
         """Add Active/Inactive actions."""
         if len(self._indices) > 1:
-            mSub = self.addMenu(self.tr("Set Active to ..."))
-            aOne = mSub.addAction(SHARED.theme.getIcon("checked"), self._tree.trActive)
+            mSub = qtAddMenu(self, self.tr("Set Active to ..."))
+            aOne = qtAddAction(mSub, self._tree.trActive)
+            aOne.setIcon(SHARED.theme.getIcon("checked", "green"))
             aOne.triggered.connect(qtLambda(self._iterItemActive, True))
-            aTwo = mSub.addAction(SHARED.theme.getIcon("unchecked"), self._tree.trInactive)
+            aTwo = qtAddAction(mSub, self._tree.trInactive)
+            aTwo.setIcon(SHARED.theme.getIcon("unchecked", "red"))
             aTwo.triggered.connect(qtLambda(self._iterItemActive, False))
         else:
-            action = self.addAction(self.tr("Toggle Active"))
+            action = qtAddAction(self, self.tr("Toggle Active"))
             action.triggered.connect(self._toggleItemActive)
         return
 
     def _itemStatusImport(self, multi: bool) -> None:
         """Add actions for changing status or importance."""
         if self._item.isNovelLike():
-            menu = self.addMenu(self.tr("Set Status to ..."))
+            menu = qtAddMenu(self, self.tr("Set Status to ..."))
             current = self._item.itemStatus
             for key, entry in SHARED.project.data.itemStatus.iterItems():
                 name = entry.name
                 if not multi and current == key:
                     name += f" ({nwUnicode.U_CHECK})"
-                action = menu.addAction(entry.icon, name)
+                action = qtAddAction(menu, name)
+                action.setIcon(entry.icon)
                 if multi:
                     action.triggered.connect(qtLambda(self._iterSetItemStatus, key))
                 else:
                     action.triggered.connect(qtLambda(self._changeItemStatus, key))
             menu.addSeparator()
-            action = menu.addAction(self.tr("Manage Labels ..."))
+            action = qtAddAction(menu, self.tr("Manage Labels ..."))
             action.triggered.connect(qtLambda(
                 self._view.projectSettingsRequest.emit,
                 GuiProjectSettings.PAGE_STATUS
             ))
         else:
-            menu = self.addMenu(self.tr("Set Importance to ..."))
+            menu = qtAddMenu(self, self.tr("Set Importance to ..."))
             current = self._item.itemImport
             for key, entry in SHARED.project.data.itemImport.iterItems():
                 name = entry.name
                 if not multi and current == key:
                     name += f" ({nwUnicode.U_CHECK})"
-                action = menu.addAction(entry.icon, name)
+                action = qtAddAction(menu, name)
+                action.setIcon(entry.icon)
                 if multi:
                     action.triggered.connect(qtLambda(self._iterSetItemImport, key))
                 else:
                     action.triggered.connect(qtLambda(self._changeItemImport, key))
             menu.addSeparator()
-            action = menu.addAction(self.tr("Manage Labels ..."))
+            action = qtAddAction(menu, self.tr("Manage Labels ..."))
             action.triggered.connect(qtLambda(
                 self._view.projectSettingsRequest.emit,
                 GuiProjectSettings.PAGE_IMPORT
@@ -1274,7 +1279,7 @@ class _TreeContextMenu(QMenu):
 
     def _itemTransform(self, isFile: bool, isFolder: bool) -> None:
         """Add actions for the Transform menu."""
-        menu = self.addMenu(self.tr("Transform ..."))
+        menu = qtAddMenu(self, self.tr("Transform ..."))
 
         trDoc = trConst(nwLabels.LAYOUT_NAME[nwItemLayout.DOCUMENT])
         trNote = trConst(nwLabels.LAYOUT_NAME[nwItemLayout.NOTE])
@@ -1284,42 +1289,42 @@ class _TreeContextMenu(QMenu):
         isNoteFile = isFile and self._item.isNoteLayout()
 
         if isNoteFile and self._item.documentAllowed():
-            action = menu.addAction(self.tr("Convert to {0}").format(trDoc))
+            action = qtAddAction(menu, self.tr("Convert to {0}").format(trDoc))
             action.triggered.connect(qtLambda(self._changeItemLayout, loDoc))
 
         if isDocFile:
-            action = menu.addAction(self.tr("Convert to {0}").format(trNote))
+            action = qtAddAction(menu, self.tr("Convert to {0}").format(trNote))
             action.triggered.connect(qtLambda(self._changeItemLayout, loNote))
 
         if isFolder and self._item.documentAllowed():
-            action = menu.addAction(self.tr("Convert to {0}").format(trDoc))
+            action = qtAddAction(menu, self.tr("Convert to {0}").format(trDoc))
             action.triggered.connect(qtLambda(self._convertFolderToFile, loDoc))
 
         if isFolder:
-            action = menu.addAction(self.tr("Convert to {0}").format(trNote))
+            action = qtAddAction(menu, self.tr("Convert to {0}").format(trNote))
             action.triggered.connect(qtLambda(self._convertFolderToFile, loNote))
 
         if self._children and isFile:
-            action = menu.addAction(self.tr("Merge Child Items into Self"))
+            action = qtAddAction(menu, self.tr("Merge Child Items into Self"))
             action.triggered.connect(qtLambda(self._tree.mergeDocuments, self._handle, False))
-            action = menu.addAction(self.tr("Merge Child Items into New"))
+            action = qtAddAction(menu, self.tr("Merge Child Items into New"))
             action.triggered.connect(qtLambda(self._tree.mergeDocuments, self._handle, True))
 
         if self._children and isFolder:
-            action = menu.addAction(self.tr("Merge Documents in Folder"))
+            action = qtAddAction(menu, self.tr("Merge Documents in Folder"))
             action.triggered.connect(qtLambda(self._tree.mergeDocuments, self._handle, True))
 
         if isFile:
-            action = menu.addAction(self.tr("Split Document by Headings"))
+            action = qtAddAction(menu, self.tr("Split Document by Headings"))
             action.triggered.connect(qtLambda(self._tree.splitDocument, self._handle))
 
         return
 
     def _expandCollapse(self) -> None:
         """Add actions for expand and collapse."""
-        action = self.addAction(self.tr("Expand All"))
+        action = qtAddAction(self, self.tr("Expand All"))
         action.triggered.connect(qtLambda(self._tree.expandFromIndex, self._indices[0]))
-        action = self.addAction(self.tr("Collapse All"))
+        action = qtAddAction(self, self.tr("Collapse All"))
         action.triggered.connect(qtLambda(self._tree.collapseFromIndex, self._indices[0]))
         return
 
@@ -1327,12 +1332,12 @@ class _TreeContextMenu(QMenu):
         """Add move to Trash action."""
         if (
             self._model.trashSelection(self._indices)
-            or len(self._indices) == 1 and self._item.isRootType()
+            or (len(self._indices) == 1 and self._item.isRootType())
         ):
             text = self.tr("Delete Permanently")
         else:
             text = self.tr("Move to Trash")
-        action = self.addAction(text)
+        action = qtAddAction(self, text)
         action.triggered.connect(self._tree.processDeleteRequest)
         return
 
@@ -1399,6 +1404,7 @@ class _TreeContextMenu(QMenu):
         if itemLayout == nwItemLayout.DOCUMENT and self._item.documentAllowed():
             self._item.setLayout(nwItemLayout.DOCUMENT)
             self._item.notifyToRefresh()
+            self._item.notifyNovelStructureChange()
         elif itemLayout == nwItemLayout.NOTE:
             self._item.setLayout(nwItemLayout.NOTE)
             self._item.notifyToRefresh()
@@ -1415,6 +1421,7 @@ class _TreeContextMenu(QMenu):
                 self._item.setType(nwItemType.FILE)
                 self._item.setLayout(nwItemLayout.DOCUMENT)
                 self._item.notifyToRefresh()
+                self._item.notifyNovelStructureChange()
             elif msgYes and itemLayout == nwItemLayout.NOTE:
                 self._item.setType(nwItemType.FILE)
                 self._item.setLayout(nwItemLayout.NOTE)
