@@ -31,16 +31,16 @@ from pathlib import Path
 from time import time
 from typing import TYPE_CHECKING, TypeVar
 
-from PyQt5.QtCore import QObject, QRunnable, QThreadPool, QTimer, QUrl, pyqtSignal, pyqtSlot
-from PyQt5.QtGui import QDesktopServices, QFont
-from PyQt5.QtWidgets import QFileDialog, QFontDialog, QMessageBox, QWidget
+from PyQt6.QtCore import QObject, QRunnable, QThreadPool, QTimer, QUrl, pyqtSignal, pyqtSlot
+from PyQt6.QtGui import QDesktopServices, QFont
+from PyQt6.QtWidgets import QFileDialog, QFontDialog, QMessageBox, QWidget
 
 from novelwriter.common import formatFileFilter
 from novelwriter.constants import nwFiles
 from novelwriter.core.spellcheck import NWSpellEnchant
 from novelwriter.enum import nwChange, nwItemClass
 
-if TYPE_CHECKING:  # pragma: no cover
+if TYPE_CHECKING:
     from novelwriter.core.project import NWProject
     from novelwriter.core.status import T_StatusKind
     from novelwriter.gui.theme import GuiTheme
@@ -54,8 +54,8 @@ NWWidget = TypeVar("NWWidget", bound=QWidget)
 class SharedData(QObject):
 
     __slots__ = (
-        "_gui", "_theme", "_project", "_spelling", "_lockedBy", "_lastAlert",
-        "_idleTime", "_idleRefTime",
+        "_gui", "_idleRefTime", "_idleTime", "_lastAlert", "_lockedBy",
+        "_project", "_spelling", "_theme",
     )
 
     focusModeChanged = pyqtSignal(bool)
@@ -63,10 +63,11 @@ class SharedData(QObject):
     indexChangedTags = pyqtSignal(list, list)
     indexCleared = pyqtSignal()
     mainClockTick = pyqtSignal()
+    novelStructureChanged = pyqtSignal(str)
     projectItemChanged = pyqtSignal(str, Enum)
-    rootFolderChanged = pyqtSignal(str, Enum)
     projectStatusChanged = pyqtSignal(bool)
     projectStatusMessage = pyqtSignal(str)
+    rootFolderChanged = pyqtSignal(str, Enum)
     spellLanguageChanged = pyqtSignal(str, str)
     statusLabelsChanged = pyqtSignal(str)
 
@@ -100,28 +101,28 @@ class SharedData(QObject):
     def mainGui(self) -> GuiMain:
         """Return the Main GUI instance."""
         if self._gui is None:
-            raise Exception("SharedData class not fully initialised")
+            raise RuntimeError("SharedData class not fully initialised")
         return self._gui
 
     @property
     def theme(self) -> GuiTheme:
         """Return the GUI Theme instance."""
         if self._theme is None:
-            raise Exception("SharedData class not fully initialised")
+            raise RuntimeError("SharedData class not fully initialised")
         return self._theme
 
     @property
     def project(self) -> NWProject:
         """Return the active NWProject instance."""
         if self._project is None:
-            raise Exception("SharedData class not fully initialised")
+            raise RuntimeError("SharedData class not fully initialised")
         return self._project
 
     @property
     def spelling(self) -> NWSpellEnchant:
         """Return the active NWProject instance."""
         if self._spelling is None:
-            raise Exception("SharedData class not fully initialised")
+            raise RuntimeError("SharedData class not fully initialised")
         return self._spelling
 
     @property
@@ -164,17 +165,24 @@ class SharedData(QObject):
     #  Methods
     ##
 
-    def initSharedData(self, gui: GuiMain, theme: GuiTheme) -> None:
+    def initTheme(self, theme: GuiTheme) -> None:
+        """Initialise the GUI theme. This must be called before the GUI
+        is created.
+        """
+        self._theme = theme
+        return
+
+    def initSharedData(self, gui: GuiMain) -> None:
         """Initialise the SharedData instance. This must be called as
         soon as the Main GUI is created to ensure the SHARED singleton
         has the properties needed for operation.
         """
         self._clock.start()
         self._gui = gui
-        self._theme = theme
         self._resetProject()
         logger.debug("Ready: SharedData")
-        logger.debug("Thread Pool Max Count: %d", QThreadPool.globalInstance().maxThreadCount())
+        if pool := QThreadPool.globalInstance():
+            logger.debug("Thread Pool Max Count: %d", pool.maxThreadCount())
         return
 
     def closeDocument(self, tHandle: str | None = None) -> None:
@@ -266,7 +274,8 @@ class SharedData(QObject):
 
     def runInThreadPool(self, runnable: QRunnable, priority: int = 0) -> None:
         """Queue a runnable in the application thread pool."""
-        QThreadPool.globalInstance().start(runnable, priority=priority)
+        if pool := QThreadPool.globalInstance():
+            pool.start(runnable, priority=priority)
         return
 
     def getProjectPath(
@@ -278,13 +287,13 @@ class SharedData(QObject):
         label = (self.tr("novelWriter Project File or Zip File")
                  if allowZip else self.tr("novelWriter Project File"))
         ext = f"{nwFiles.PROJ_FILE} *.zip" if allowZip else nwFiles.PROJ_FILE
-        ffilter = formatFileFilter([(label, ext), "*"])
+        fFilter = formatFileFilter([(label, ext), "*"])
         selected, _ = QFileDialog.getOpenFileName(
-            parent, self.tr("Open Project"), str(path or ""), filter=ffilter
+            parent, self.tr("Open Project"), str(path or ""), filter=fFilter
         )
         return Path(selected) if selected else None
 
-    def getFont(self, current: QFont, native: bool) -> tuple[QFont, bool]:
+    def getFont(self, current: QFont, native: bool) -> tuple[QFont, bool | None]:
         """Open the font dialog and select a font."""
         kwargs = {}
         if not native:
@@ -471,7 +480,7 @@ class _GuiAlert(QMessageBox):
     def setException(self, exception: Exception) -> None:
         """Add exception details."""
         info = self.informativeText()
-        text = f"<b>{type(exception).__name__}</b>: {str(exception)}"
+        text = f"<b>{type(exception).__name__}</b>: {exception!s}"
         self.setInformativeText(f"{info}<br>{text}" if info else text)
         return
 
@@ -485,15 +494,15 @@ class _GuiAlert(QMessageBox):
             self.setStandardButtons(QMessageBox.StandardButton.Ok)
         pSz = 2*self._theme.baseIconHeight
         if level == self.INFO:
-            self.setIconPixmap(self._theme.getPixmap("alert_info", (pSz, pSz)))
+            self.setIconPixmap(self._theme.getPixmap("alert_info", (pSz, pSz), "blue"))
             self.setWindowTitle(self.tr("Information"))
         elif level == self.WARN:
-            self.setIconPixmap(self._theme.getPixmap("alert_warn", (pSz, pSz)))
+            self.setIconPixmap(self._theme.getPixmap("alert_warn", (pSz, pSz), "orange"))
             self.setWindowTitle(self.tr("Warning"))
         elif level == self.ERROR:
-            self.setIconPixmap(self._theme.getPixmap("alert_error", (pSz, pSz)))
+            self.setIconPixmap(self._theme.getPixmap("alert_error", (pSz, pSz), "red"))
             self.setWindowTitle(self.tr("Error"))
         elif level == self.ASK:
-            self.setIconPixmap(self._theme.getPixmap("alert_question", (pSz, pSz)))
+            self.setIconPixmap(self._theme.getPixmap("alert_question", (pSz, pSz), "blue"))
             self.setWindowTitle(self.tr("Question"))
         return
